/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  GSM Generator
 *  VXIpnp Instrument Driver
 *  Original Release: August 2008
 *  By: Jiri Kominek
 *****************************************************************************/

#ifndef __RSCMWGG_HEADER
#define __RSCMWGG_HEADER

#include "rsidr_core.h"
#include "rscmwgg_attributes.h"
#include "rscmwgg_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/
/* Class Driver Identification */

#define RSCMWGG_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWGG_CLASS_DRIVER_PREFIX                ""
#define RSCMWGG_CLASS_DRIVER_VENDOR                ""
#define RSCMWGG_CLASS_DRIVER_REVISION              ""
#define RSCMWGG_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWGG_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWGG_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWGG_SPECIFIC_DRIVER_PREFIX             "RSCMWGG"
#define RSCMWGG_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWGG_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWGG_MAJOR_VERSION                      2L    /* Instrument driver major version          */
#define RSCMWGG_MINOR_VERSION                      0L    /* Instrument driver minor version          */
#define RSCMWGG_MINOR_MINOR_VERSION                111L   /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSCMWGG_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWGG_GROUP_CAPABILITIES                 ""
#define RSCMWGG_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWGG_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWGG_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWGG_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWGG_IO_BUFFER_SIZE           1024L   /* I/O buffer size */
#define RSCMWGG_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
//#define IEEE_488_2_ERROR_MASK             0x3C    /* 488.2 Event Status Register (ESR) Bits */
#define IEEE_488_2_ERROR_MASK             0x4    /* 488.2 STB Bits */   
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */
#define IEEE_488_2_SRE_MASK               0x24   /* 488.2 Event Status Register (ESR) Bits */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWGG_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWGG_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWGG_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWGG_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWGG_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWGG_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWGG_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWGG_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWGG_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWGG_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWGG_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWGG_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWGG_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWGG_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWGG_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */   
#define RSCMWGG_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWGG_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWGG_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWGG_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWGG_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWGG_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWGG_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWGG_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWGG_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWGG_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWGG_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWGG_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWGG_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWGG_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWGG_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWGG_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSCMWGG_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */  
#define RSCMWGG_ATTR_GENERATOR_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSCMWGG_ATTR_QUERY_GENERATOR_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWGG_ATTR_GENERATOR_EXTERNAL_ATTENUATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWGG_ATTR_GENERATOR_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWGG_ATTR_GENERATOR_CHANNEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWGG_ATTR_GENERATOR_BAND                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWGG_ATTR_GENERATOR_RMS_LEVEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWGG_ATTR_QUERY_GENERATOR_PEP                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWGG_ATTR_SYSTEM_VERSION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWGG_ATTR_SYSTEM_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWGG_ATTR_SYSTEM_ALL_ERRORS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSCMWGG_ATTR_SYSTEM_PRESET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWGG_ATTR_ID_QUERY_RESPONSE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWGG_ATTR_GENERATOR_OUTPUT_CONNECTOR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 14

// rscmwgg_rngGeneratorState
#define RSCMWGG_VAL_GEN_OFF                                                 0
#define RSCMWGG_VAL_GEN_ON                                                  1
#define RSCMWGG_VAL_GEN_PEND                                                2

// rscmwgg_rngOutputConnector
#define RSCMWGG_VAL_CONN_RF1C                                               0
#define RSCMWGG_VAL_CONN_RF2C                                               1
#define RSCMWGG_VAL_CONN_RF3C                                               2
#define RSCMWGG_VAL_CONN_RF4C                                               3
#define RSCMWGG_VAL_CONN_RF1O                                               4
#define RSCMWGG_VAL_CONN_RF3O                                               5
#define RSCMWGG_VAL_CONN_RFAC                                               6
#define RSCMWGG_VAL_CONN_RFBC                                               7
#define RSCMWGG_VAL_CONN_RFAO                                               8

// rscmwgg_rngGeneratorBand
#define RSCMWGG_VAL_BAND_G400                                               0
#define RSCMWGG_VAL_BAND_GGT8                                               1
#define RSCMWGG_VAL_BAND_G850                                               2
#define RSCMWGG_VAL_BAND_G900                                               3
#define RSCMWGG_VAL_BAND_G1800                                              4
#define RSCMWGG_VAL_BAND_G1900                                              5

// rscmwgg_rngScenario
#define RSCMWGG_ATTR_STANDALONE                                             0
/* END GENERATE */  

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWGG_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWGG_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWGG_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWGG_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

    /*- Instrument specific attribute value definitions --------------------*/

#define RSCMWGG_VAL_SLOT_BTYPE_NORMAL  0
#define RSCMWGG_VAL_SLOT_BTYPE_EDGE    1
#define RSCMWGG_VAL_SLOT_BTYPE_SYNC    2
#define RSCMWGG_VAL_SLOT_BTYPE_FCOR    3
#define RSCMWGG_VAL_SLOT_BTYPE_DUMMY   4
#define RSCMWGG_VAL_SLOT_BTYPE_ACCESS  5
#define RSCMWGG_VAL_SLOT_BTYPE_BRDCAST 6
#define RSCMWGG_VAL_SLOT_BTYPE_TRAFFIC 7	
	
#define RSCMWGG_VAL_SLOT_DATA_ALL0 0
#define RSCMWGG_VAL_SLOT_DATA_ALL1 1
#define RSCMWGG_VAL_SLOT_DATA_PR9  2
#define RSCMWGG_VAL_SLOT_DATA_PR11 3
#define RSCMWGG_VAL_SLOT_DATA_PR15 4
#define RSCMWGG_VAL_SLOT_DATA_PR16 5
#define RSCMWGG_VAL_SLOT_DATA_PR20 6
#define RSCMWGG_VAL_SLOT_DATA_PR21 7
#define RSCMWGG_VAL_SLOT_DATA_PR23 8
#define RSCMWGG_VAL_SLOT_DATA_ALT  9
#define RSCMWGG_VAL_SLOT_DATA_PRBS 10
	
#define RSCMWGG_VAL_SLOT_MODE_TFS  0
#define RSCMWGG_VAL_SLOT_MODE_TFS2 1
#define RSCMWGG_VAL_SLOT_MODE_SM5  2
#define RSCMWGG_VAL_SLOT_MODE_SM52 3
#define RSCMWGG_VAL_SLOT_MODE_SM9  4
#define RSCMWGG_VAL_SLOT_MODE_SM92 5
	
#define RSCMWGG_VAL_TX1 1
#define RSCMWGG_VAL_TX2 2

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWGG_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWGG_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWGG_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWGG_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWGG_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSCMWGG_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWGG_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWGG_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSCMWGG_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSCMWGG_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSCMWGG_ERROR_CODES_AND_MSGS \
    {RSCMWGG_WARN_MEASURE_UNCALIBRATED,  RSCMWGG_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWGG_WARN_OVER_RANGE,            RSCMWGG_WARNMSG_OVER_RANGE},\
    {RSCMWGG_ERROR_INCORRECT_STATE ,   RSCMWGG_ERRMSG_INCORRECT_STATE },\
    {RSCMWGG_ERROR_INCORRECT_RESPONSE,     RSCMWGG_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWGG_ERROR_MAX_TIME_EXCEEDED,    RSCMWGG_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC rscmwgg_init (ViRsrc resourceName, ViBoolean IDQuery,
                                ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwgg_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                           ViBoolean resetDevice,
                                           ViString optionString,
                                           ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorState (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViBoolean state);
ViStatus _VI_FUNC rscmwgg_QueryGeneratorState (ViSession instrumentHandle,
                                               ViInt32 instance, ViInt32* state);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSignalRouting
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 RFConnector, ViInt32 RFConverter,
              ViReal64 externalAttenuation);

ViStatus _VI_FUNC rscmwgg_QueryGeneratorSignalRouting (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32 *scenario,
                                                       ViChar controller[],
                                                       ViInt32 *RFConnector,
                                                       ViInt32 *RFConverter);

ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorFrequency (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViReal64 frequency);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorChannel (ViSession instrumentHandle,
                                                     ViInt32 instance, ViInt32 band,
                                                     ViInt32 channel);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorRMSLevel (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViReal64 level);
ViStatus _VI_FUNC rscmwgg_QueryGeneratorPEP (ViSession instrumentHandle,
                                             ViInt32 instance, ViReal64* PEP);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSlotLevel (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32 _VI_FAR slotLevel[]);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSlotBurstType
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 _VI_FAR burstType[]);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSlotDataSource
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 _VI_FAR dataSource[]);
ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSlotTestSequence
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 _VI_FAR testSequence[]);

ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSlotModulationScheme (ViSession instrumentHandle,
                                                                      ViInt32 instance,
                                                                      ViInt32 modulationScheme[]);

ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSlotAttenuations
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64 _VI_FAR attenuations[]);

ViStatus _VI_FUNC rscmwgg_ConfigureGeneratorSlotPowerControlLevel (ViSession instrumentHandle,
                                                                   ViInt32 instance,
                                                                   ViInt32 powerControlLevel[]);

ViStatus _VI_FUNC rscmwgg_SetAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwgg_SetAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwgg_SetAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViString attributeValue);
ViStatus _VI_FUNC rscmwgg_SetAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwgg_SetAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViSession attributeValue);
ViStatus _VI_FUNC rscmwgg_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rscmwgg_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rscmwgg_GetAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViInt32* attributeValue);
ViStatus _VI_FUNC rscmwgg_GetAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViReal64* attributeValue);
ViStatus _VI_FUNC rscmwgg_GetAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32 bufferSize,
                                                ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rscmwgg_GetAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViBoolean* attributeValue);
ViStatus _VI_FUNC rscmwgg_GetAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViSession* attributeValue);
ViStatus _VI_FUNC rscmwgg_CheckAttributeViInt32 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwgg_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwgg_CheckAttributeViString (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViString attributeValue);
ViStatus _VI_FUNC rscmwgg_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwgg_CheckAttributeViSession (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViSession attributeValue);
ViStatus _VI_FUNC rscmwgg_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwgg_self_test (ViSession instrumentHandle,
                                     ViInt16* selfTestResult,
                                     ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rscmwgg_SelfTestResults (ViSession instrumentHandle,
                                           ViInt32 bufferSize,
                                           ViChar _VI_FAR results[]);
ViStatus _VI_FUNC rscmwgg_revision_query (ViSession instrumentHandle,
                                          ViChar _VI_FAR instrumentDriverRevision[],
                                          ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rscmwgg_SystemVersion (ViSession instrumentHandle, ViInt32 length,
                                         ViChar _VI_FAR systemVersion[]);
ViStatus _VI_FUNC rscmwgg_error_query (ViSession instrumentHandle,
                                       ViInt32* errorCode,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwgg_ErrorList (ViSession instrumentHandle, ViInt32 bufferSize,
                                     ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC rscmwgg_error_message (ViSession instrumentHandle,
                                         ViStatus errorCode,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwgg_Preset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwgg_GetError (ViSession instrumentHandle, ViStatus* code,
                                    ViInt32 bufferSize,
                                    ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rscmwgg_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwgg_WriteInstrData (ViSession instrumentHandle,
                                          ViString writeBuffer);
ViStatus _VI_FUNC rscmwgg_ReadInstrData (ViSession instrumentHandle,
                                         ViInt32 number_ofBytesToRead,
                                         ViChar _VI_FAR readBuffer[],
                                         ViUInt32* numBytesRead);
ViStatus _VI_FUNC rscmwgg_QueryViBoolean (ViSession instrumentHandle,
                                          ViString command, ViBoolean* value);
ViStatus _VI_FUNC rscmwgg_QueryViInt32 (ViSession instrumentHandle,
                                        ViString command, ViInt32* value);
ViStatus _VI_FUNC rscmwgg_QueryViReal64 (ViSession instrumentHandle,
                                         ViString command, ViReal64* value);
ViStatus _VI_FUNC rscmwgg_QueryViString (ViSession instrumentHandle,
                                         ViString command, ViInt32 bufferSize,
                                         ViChar _VI_FAR value[]);
ViStatus _VI_FUNC rscmwgg_close (ViSession instrumentHandle);

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWGG_HEADER */
