/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  GSM Measurements
 *  VXIpnp Instrument Driver
 *  Original Release: February 2008
 *  By: Helena Kominkova
 *****************************************************************************/

#ifndef __RSCMWGM_HEADER
#define __RSCMWGM_HEADER

#include "rscore.h"
#include "rscmwgm_attributes.h"
#include "rscmwgm_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/
/* Class Driver Identification */

#define RSCMWGM_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWGM_CLASS_DRIVER_PREFIX                ""
#define RSCMWGM_CLASS_DRIVER_VENDOR                ""
#define RSCMWGM_CLASS_DRIVER_REVISION              ""
#define RSCMWGM_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWGM_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWGM_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWGM_SPECIFIC_DRIVER_PREFIX             "RSCMWGM"
#define RSCMWGM_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWGM_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWGM_MAJOR_VERSION                      3L    /* Instrument driver major version          */
#define RSCMWGM_MINOR_VERSION                      7L    /* Instrument driver minor version          */
#define RSCMWGM_MINOR_MINOR_VERSION                220L   /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSCMWGM_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWGM_GROUP_CAPABILITIES                 ""
#define RSCMWGM_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWGM_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWGM_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWGM_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWGM_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWGM_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWGM_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWGM_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWGM_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWGM_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWGM_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWGM_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWGM_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWGM_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWGM_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWGM_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWGM_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWGM_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWGM_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWGM_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMWGM_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWGM_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWGM_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWGM_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWGM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWGM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWGM_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWGM_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWGM_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWGM_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWGM_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWGM_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWGM_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWGM_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWGM_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWGM_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSCMWGM_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSCMWGM_ATTR_INPUT_EXTERNAL_ATTENUTATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWGM_ATTR_COMBINED_SIGNAL_PATH_SCENARIO                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWGM_ATTR_MEASURE_PROTOCOL_SCENARIO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWGM_ATTR_MEASURE_PROTOCOL_SCENARIO_APPLICATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWGM_ATTR_ANALYZER_EXPECTED_NOMINAL_POWER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWGM_ATTR_ANALYZER_USER_MARGIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWGM_ATTR_ANALYZER_CENTER_FREQUENCY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWGM_ATTR_ANALYZER_MIXER_INPUT_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWGM_ATTR_ANALYZER_FREQUENCY_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSCMWGM_ATTR_ANALYZER_BAND                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWGM_ATTR_ANALYZER_CHANNEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_OFFSET_FREQUENCY                RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_AVERAGE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_REPETITION_MODE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_COUNT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_STOP_CONDITION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_RESULTS_REJECTION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TIMEOUT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_FREQUENCY_RANGE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_SIGNAL_LEVEL_RELATIVE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_SIGNAL_LEVEL_RELATIVE_STATE     RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_ACCESS_BURST                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRAINING_SEQUENCE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SOURCE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SLOPE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_THRESHOLD               RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_DELAY                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_TIMEOUT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_TIMEOUT_STATE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_FRAME_SYNCHRONIZATION_METHOD    RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_GAP_LENGTH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_GAP                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_REFERENCE_POWER_MODE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_IF_FILTER_BANDWIDTH             RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_PEAK_HOLD_MODE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_BER_LOOP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_BER_THRESHOLD_START             RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_BER_THRESHOLD_RUN               RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_IQ_ROTATION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_IQ_FILTER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_16QAM_NB_SEARCH                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_PCL_MODE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_VAMOS_TSC                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_DECODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_IGNORE_INITIAL_OFF_FRAMES       RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSCMWGM_ATTR_LIST_MODE_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWGM_ATTR_LIST_MODE_TRIGGER_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSCMWGM_ATTR_LIST_MODE_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWGM_ATTR_LIST_MODE_IGNORE_IDLE_FRAMES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWGM_ATTR_LIST_MODE_STEP_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWGM_ATTR_LIST_MODE_STEP_LENGTH_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSCMWGM_ATTR_LIST_MODE_CONNECTOR_MODE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSCMWGM_ATTR_LIST_MODE_CMWS_CONNECTOR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_INIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_ABORT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWGM_ATTR_MULTI_EVAL_MEASUREMENT_STOP                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWGM_ATTR_SYSTEM_VERSION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSCMWGM_ATTR_SYSTEM_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSCMWGM_ATTR_SYSTEM_ALL_ERRORS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWGM_ATTR_ID_QUERY_RESPONSE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWGM_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSCMWGM_ATTR_SYSTEM_PRESET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 50

// rscmwgm_rngRepMode
#define RSCMWGM_VAL_REPETITION_SINGLE                                       0
#define RSCMWGM_VAL_REPETITION_CONT                                         1

// rscmwgm_rngStopCond
#define RSCMWGM_VAL_NONE                                                    0
#define RSCMWGM_VAL_LIM_FAIL                                                1

// rscmwgm_rngFreqRangeWidth
#define RSCMWGM_VAL_FRANGE_NORMAL                                           0
#define RSCMWGM_VAL_FRANGE_WIDE                                             1

// rscmwgm_rngTrainingSeq
#define RSCMWGM_VAL_TSEQ_OFF                                                0
#define RSCMWGM_VAL_TSEQ_TSCA                                               1
#define RSCMWGM_VAL_TSEQ_DUMM                                               2
#define RSCMWGM_VAL_TSEQ_TSC0                                               3
#define RSCMWGM_VAL_TSEQ_TSC1                                               4
#define RSCMWGM_VAL_TSEQ_TSC2                                               5
#define RSCMWGM_VAL_TSEQ_TSC3                                               6
#define RSCMWGM_VAL_TSEQ_TSC4                                               7
#define RSCMWGM_VAL_TSEQ_TSC5                                               8
#define RSCMWGM_VAL_TSEQ_TSC6                                               9
#define RSCMWGM_VAL_TSEQ_TSC7                                               10

// rscmwgm_rngTrigSlope
#define RSCMWGM_VAL_TRIGSLOPE_RISING                                        0
#define RSCMWGM_VAL_TRIGSLOPE_FALLING                                       1

// rscmwgm_rngFrameSync
#define RSCMWGM_VAL_AMODE_GAP                                               0
#define RSCMWGM_VAL_AMODE_PATT                                              1

// rscmwgm_rngRefPowerMode
#define RSCMWGM_VAL_RPOWER_MODE_CURR                                        0
#define RSCMWGM_VAL_RPOWER_MODE_AVER                                        1
#define RSCMWGM_VAL_RPOWER_MODE_DCOM                                        2

// rscmwgm_rngIFFiltBwid
#define RSCMWGM_VAL_IF_FILT_BW_G05M                                         0
#define RSCMWGM_VAL_IF_FILT_BW_G10M                                         1

// rscmwgm_rngHoldMode
#define RSCMWGM_VAL_HOLD_PHOL                                               0
#define RSCMWGM_VAL_HOLD_SCO                                                1

// rscmwgm_rngBERLoop
#define RSCMWGM_VAL_BER_C                                                   0
#define RSCMWGM_VAL_BER_SRB                                                 1

// rscmwgm_rngIQRotation
#define RSCMWGM_VAL_IQ_ROTATION_P38R                                        0
#define RSCMWGM_VAL_IQ_ROTATION_P38                                         1

// rscmwgm_rngIQFilter
#define RSCMWGM_VAL_IQ_FILTER_ISIR                                          0
#define RSCMWGM_VAL_IQ_FILTER_UNF                                           1
#define RSCMWGM_VAL_IQ_FILTER_F90K                                          2

// rscmwgm_rngLinLog
#define RSCMWGM_VAL_LIN                                                     0
#define RSCMWGM_VAL_LOG                                                     1

// rscmwgm_rngPLCMode
#define RSCMWGM_VAL_AUTO                                                    0
#define RSCMWGM_VAL_PCL                                                     1
#define RSCMWGM_VAL_SIGN                                                    2

// rscmwgm_rngDecode
#define RSCMWGM_VAL_DECODE_GTBITS                                           0
#define RSCMWGM_VAL_DECODE_STANDARD                                         1

// rscmwgm_rngAnalyzerBand
#define RSCMWGM_VAL_BAND_G04                                                0
#define RSCMWGM_VAL_BAND_G085                                               1
#define RSCMWGM_VAL_BAND_G09                                                2
#define RSCMWGM_VAL_BAND_G18                                                3
#define RSCMWGM_VAL_BAND_G19                                                4
#define RSCMWGM_VAL_BAND_GG08                                               5

// rscmwgm_rngConnectorMode
#define RSCMWGM_VAL_CMWS_CMODE_GLOBAL                                       0
#define RSCMWGM_VAL_CMWS_CMODE_LIST                                         1

// rscmwgm_rngCMWSConnector
#define RSCMWGM_VAL_CONN_R11                                                0
#define RSCMWGM_VAL_CONN_R12                                                1
#define RSCMWGM_VAL_CONN_R13                                                2
#define RSCMWGM_VAL_CONN_R14                                                3
#define RSCMWGM_VAL_CONN_R15                                                4
#define RSCMWGM_VAL_CONN_R16                                                5
#define RSCMWGM_VAL_CONN_R17                                                6
#define RSCMWGM_VAL_CONN_R18                                                7
#define RSCMWGM_VAL_CONN_R21                                                8
#define RSCMWGM_VAL_CONN_R22                                                9
#define RSCMWGM_VAL_CONN_R23                                                10
#define RSCMWGM_VAL_CONN_R24                                                11
#define RSCMWGM_VAL_CONN_R25                                                12
#define RSCMWGM_VAL_CONN_R26                                                13
#define RSCMWGM_VAL_CONN_R27                                                14
#define RSCMWGM_VAL_CONN_R28                                                15
#define RSCMWGM_VAL_CONN_R31                                                16
#define RSCMWGM_VAL_CONN_R32                                                17
#define RSCMWGM_VAL_CONN_R33                                                18
#define RSCMWGM_VAL_CONN_R34                                                19
#define RSCMWGM_VAL_CONN_R35                                                20
#define RSCMWGM_VAL_CONN_R36                                                21
#define RSCMWGM_VAL_CONN_R37                                                22
#define RSCMWGM_VAL_CONN_R38                                                23
#define RSCMWGM_VAL_CONN_R41                                                24
#define RSCMWGM_VAL_CONN_R42                                                25
#define RSCMWGM_VAL_CONN_R43                                                26
#define RSCMWGM_VAL_CONN_R44                                                27
#define RSCMWGM_VAL_CONN_R45                                                28
#define RSCMWGM_VAL_CONN_R46                                                29
#define RSCMWGM_VAL_CONN_R47                                                30
#define RSCMWGM_VAL_CONN_R48                                                31
#define RSCMWGM_VAL_CONN_RA1                                                32
#define RSCMWGM_VAL_CONN_RA2                                                33
#define RSCMWGM_VAL_CONN_RA3                                                34
#define RSCMWGM_VAL_CONN_RA4                                                35
#define RSCMWGM_VAL_CONN_RA5                                                36
#define RSCMWGM_VAL_CONN_RA6                                                37
#define RSCMWGM_VAL_CONN_RA7                                                38
#define RSCMWGM_VAL_CONN_RA8                                                39
#define RSCMWGM_VAL_CONN_RB1                                                40
#define RSCMWGM_VAL_CONN_RB2                                                41
#define RSCMWGM_VAL_CONN_RB3                                                42
#define RSCMWGM_VAL_CONN_RB4                                                43
#define RSCMWGM_VAL_CONN_RB5                                                44
#define RSCMWGM_VAL_CONN_RB6                                                45
#define RSCMWGM_VAL_CONN_RB7                                                46
#define RSCMWGM_VAL_CONN_RB8                                                47

// rscmwgm_rngListModeTriggerMode
#define RSCMWGM_VAL_TRIGGER_ONCE                                            0
#define RSCMWGM_VAL_TRIGGER_SEGMENT                                         1
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWGM_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWGM_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWGM_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWGM_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

    /*- Instrument specific attribute value definitions --------------------*/

#define RSCMWGM_VAL_PVT  0
#define RSCMWGM_VAL_MOD  1
#define RSCMWGM_VAL_SMOD 2
#define RSCMWGM_VAL_SSW  3
#define RSCMWGM_VAL_BER  4

#define RSCMWGM_VAL_RES_PVT  0
#define RSCMWGM_VAL_RES_EVM  1
#define RSCMWGM_VAL_RES_MERR 2
#define RSCMWGM_VAL_RES_PERR 3
#define RSCMWGM_VAL_RES_SMFR 4
#define RSCMWGM_VAL_RES_SMT  5
#define RSCMWGM_VAL_RES_SSFR 6
#define RSCMWGM_VAL_RES_SST  7
#define RSCMWGM_VAL_RES_AMPM 8
#define RSCMWGM_VAL_RES_BER  9
#define RSCMWGM_VAL_RES_IQ   10
#define RSCMWGM_VAL_RES_MSC  11

#define RSCMWGM_VAL_MVI_OFF  0
#define RSCMWGM_VAL_MVI_ANY  1
#define RSCMWGM_VAL_MVI_GMSK 2
#define RSCMWGM_VAL_MVI_EPSK 3
#define RSCMWGM_VAL_MVI_ACC  4
#define RSCMWGM_VAL_MVI_Q16  5

#define RSCMWGM_VAL_MOD_GMSK  0
#define RSCMWGM_VAL_MOD_EPSK  1
#define RSCMWGM_VAL_MOD_QAM16 2

#define RSCMWGM_VAL_APAT_OFF  0
#define RSCMWGM_VAL_APAT_GMSK 1
#define RSCMWGM_VAL_APAT_EPSK 2

#define RSCMWGM_VAL_LIM_SECTION_REDG     0
#define RSCMWGM_VAL_LIM_SECTION_UPAR     1
#define RSCMWGM_VAL_LIM_SECTION_FEDG     2

#define RSCMWGM_VAL_RESULT_CURRENT 0
#define RSCMWGM_VAL_RESULT_AVERAGE 1
#define RSCMWGM_VAL_RESULT_MAX     2
#define RSCMWGM_VAL_RESULT_MIN     3
#define RSCMWGM_VAL_RESULT_SDEV    4

#define RSCMWGM_VAL_TYPE_RMS  0
#define RSCMWGM_VAL_TYPE_PEAK 1

#define RSCMWGM_VAL_RESULT_BER          0
#define RSCMWGM_VAL_RESULT_BER_ERRORS   1
#define RSCMWGM_VAL_RESULT_BER_BURSTS   2

#define RSCMWGM_VAL_BURST_POSITION_NEG_28  1
#define RSCMWGM_VAL_BURST_POSITION_NEG_18  2
#define RSCMWGM_VAL_BURST_POSITION_NEG_10  3
#define RSCMWGM_VAL_BURST_POSITION_0       4
#define RSCMWGM_VAL_BURST_POSITION_2       5
#define RSCMWGM_VAL_BURST_POSITION_4       6
#define RSCMWGM_VAL_BURST_POSITION_538_2   7
#define RSCMWGM_VAL_BURST_POSITION_540_2   8
#define RSCMWGM_VAL_BURST_POSITION_542_8   9
#define RSCMWGM_VAL_BURST_POSITION_552_8  10
#define RSCMWGM_VAL_BURST_POSITION_560_8  11
#define RSCMWGM_VAL_BURST_POSITION_570_8  12

#define RSCMWGM_VAL_SLOT_LEVEL_OFF  0
#define RSCMWGM_VAL_SLOT_LEVEL_FULL 1
#define RSCMWGM_VAL_SLOT_LEVEL_A1   2
#define RSCMWGM_VAL_SLOT_LEVEL_A2   3
#define RSCMWGM_VAL_SLOT_LEVEL_A3   4
#define RSCMWGM_VAL_SLOT_LEVEL_A4   5
#define RSCMWGM_VAL_SLOT_LEVEL_A5   6
#define RSCMWGM_VAL_SLOT_LEVEL_A6   7
#define RSCMWGM_VAL_SLOT_LEVEL_A7   8

#define RSCMWGM_VAL_SLOT_BTYPE_NORMAL 0
#define RSCMWGM_VAL_SLOT_BTYPE_EDGE   1
#define RSCMWGM_VAL_SLOT_BTYPE_SYNC   2
#define RSCMWGM_VAL_SLOT_BTYPE_FCOR   3
#define RSCMWGM_VAL_SLOT_BTYPE_DUMMY  4
#define RSCMWGM_VAL_SLOT_BTYPE_ACCESS 5

#define RSCMWGM_VAL_SLOT_DATA_ALL0 0
#define RSCMWGM_VAL_SLOT_DATA_ALL1 1
#define RSCMWGM_VAL_SLOT_DATA_PR9  2
#define RSCMWGM_VAL_SLOT_DATA_PR11 3
#define RSCMWGM_VAL_SLOT_DATA_PR15 4
#define RSCMWGM_VAL_SLOT_DATA_PR16 5
#define RSCMWGM_VAL_SLOT_DATA_PR20 6
#define RSCMWGM_VAL_SLOT_DATA_PR21 7
#define RSCMWGM_VAL_SLOT_DATA_PR23 8

#define RSCMWGM_VAL_SLOT_TSEQ_STANDARD 0
#define RSCMWGM_VAL_SLOT_TSEQ_TS0      1
#define RSCMWGM_VAL_SLOT_TSEQ_TS1      2
#define RSCMWGM_VAL_SLOT_TSEQ_TS2      3
#define RSCMWGM_VAL_SLOT_TSEQ_TSC0     4
#define RSCMWGM_VAL_SLOT_TSEQ_TSC1     5
#define RSCMWGM_VAL_SLOT_TSEQ_TSC2     6
#define RSCMWGM_VAL_SLOT_TSEQ_TSC3     7
#define RSCMWGM_VAL_SLOT_TSEQ_TSC4     8
#define RSCMWGM_VAL_SLOT_TSEQ_TSC5     9
#define RSCMWGM_VAL_SLOT_TSEQ_TSC6     10
#define RSCMWGM_VAL_SLOT_TSEQ_TSC7     11

#define RSCMWGM_VAL_TRSH_START          0
#define RSCMWGM_VAL_TRSH_RUN            1

#define RSCMWGM_VAL_BER_LOOP_C          0
#define RSCMWGM_VAL_BER_LOOP_SRB        1

#define RSCMWGM_VAL_ANALYZER_CONN_RF1C  0
#define RSCMWGM_VAL_ANALYZER_CONN_RF2C  1
#define RSCMWGM_VAL_ANALYZER_CONN_RF3C  2
#define RSCMWGM_VAL_ANALYZER_CONN_RF4C  3
#define RSCMWGM_VAL_ANALYZER_CONN_RFAC  4
#define RSCMWGM_VAL_ANALYZER_CONN_RFBC  5
#define RSCMWGM_VAL_ANALYZER_CONN_RF2I  6
#define RSCMWGM_VAL_ANALYZER_CONN_RF4I  7
#define RSCMWGM_VAL_ANALYZER_CONN_RFBI  8
#define RSCMWGM_VAL_ANALYZER_CONN_IQ1I  9
#define RSCMWGM_VAL_ANALYZER_CONN_IQ3I  10
#define RSCMWGM_VAL_ANALYZER_CONN_IQ5I  11
#define RSCMWGM_VAL_ANALYZER_CONN_IQ7I  12
#define RSCMWGM_VAL_ANALYZER_CONN_R11   13
#define RSCMWGM_VAL_ANALYZER_CONN_R12   14
#define RSCMWGM_VAL_ANALYZER_CONN_R13   15
#define RSCMWGM_VAL_ANALYZER_CONN_R14   16
#define RSCMWGM_VAL_ANALYZER_CONN_R15   17
#define RSCMWGM_VAL_ANALYZER_CONN_R16   18
#define RSCMWGM_VAL_ANALYZER_CONN_R17   19
#define RSCMWGM_VAL_ANALYZER_CONN_R18   20
#define RSCMWGM_VAL_ANALYZER_CONN_R21   21
#define RSCMWGM_VAL_ANALYZER_CONN_R22   22
#define RSCMWGM_VAL_ANALYZER_CONN_R23   23
#define RSCMWGM_VAL_ANALYZER_CONN_R24   24
#define RSCMWGM_VAL_ANALYZER_CONN_R25   25
#define RSCMWGM_VAL_ANALYZER_CONN_R26   26
#define RSCMWGM_VAL_ANALYZER_CONN_R27   27
#define RSCMWGM_VAL_ANALYZER_CONN_R28   28
#define RSCMWGM_VAL_ANALYZER_CONN_R31   29
#define RSCMWGM_VAL_ANALYZER_CONN_R32   30
#define RSCMWGM_VAL_ANALYZER_CONN_R33   31
#define RSCMWGM_VAL_ANALYZER_CONN_R34   32
#define RSCMWGM_VAL_ANALYZER_CONN_R35   33
#define RSCMWGM_VAL_ANALYZER_CONN_R36   34
#define RSCMWGM_VAL_ANALYZER_CONN_R37   35
#define RSCMWGM_VAL_ANALYZER_CONN_R38   36
#define RSCMWGM_VAL_ANALYZER_CONN_R41   37
#define RSCMWGM_VAL_ANALYZER_CONN_R42   38
#define RSCMWGM_VAL_ANALYZER_CONN_R43   39
#define RSCMWGM_VAL_ANALYZER_CONN_R44   40
#define RSCMWGM_VAL_ANALYZER_CONN_R45   41
#define RSCMWGM_VAL_ANALYZER_CONN_R46   42
#define RSCMWGM_VAL_ANALYZER_CONN_R47   43
#define RSCMWGM_VAL_ANALYZER_CONN_R48   44
#define RSCMWGM_VAL_ANALYZER_CONN_RA1   45
#define RSCMWGM_VAL_ANALYZER_CONN_RA2   46
#define RSCMWGM_VAL_ANALYZER_CONN_RA3   47
#define RSCMWGM_VAL_ANALYZER_CONN_RA4   48
#define RSCMWGM_VAL_ANALYZER_CONN_RA5   49
#define RSCMWGM_VAL_ANALYZER_CONN_RA6   50
#define RSCMWGM_VAL_ANALYZER_CONN_RA7   51
#define RSCMWGM_VAL_ANALYZER_CONN_RA8   52
#define RSCMWGM_VAL_ANALYZER_CONN_RB1   53
#define RSCMWGM_VAL_ANALYZER_CONN_RB2   54
#define RSCMWGM_VAL_ANALYZER_CONN_RB3   55
#define RSCMWGM_VAL_ANALYZER_CONN_RB4   56

#define RSCMWGM_VAL_ANALYZER_SAL_CONV_RX1 0
#define RSCMWGM_VAL_ANALYZER_SAL_CONV_RX2 1
#define RSCMWGM_VAL_ANALYZER_SAL_CONV_RX3 2
#define RSCMWGM_VAL_ANALYZER_SAL_CONV_RX4 3

#define RSCMWGM_VAL_BURST_TYPE_OFF  0
#define RSCMWGM_VAL_BURST_TYPE_GMSK 1
#define RSCMWGM_VAL_BURST_TYPE_EPSK 2
#define RSCMWGM_VAL_BURST_TYPE_ACC  3
#define RSCMWGM_VAL_BURST_TYPE_Q16  4

#define RSCMWGM_VAL_TSC_OFF  0
#define RSCMWGM_VAL_TSC_NB0  1
#define RSCMWGM_VAL_TSC_NB1  2
#define RSCMWGM_VAL_TSC_NB2  3
#define RSCMWGM_VAL_TSC_NB3  4
#define RSCMWGM_VAL_TSC_NB4  5
#define RSCMWGM_VAL_TSC_NB5  6
#define RSCMWGM_VAL_TSC_NB6  7
#define RSCMWGM_VAL_TSC_NB7  8
#define RSCMWGM_VAL_TSC_DUM  9
#define RSCMWGM_VAL_TSC_AB0  10
#define RSCMWGM_VAL_TSC_AB1  11
#define RSCMWGM_VAL_TSC_AB2  12

/* Fast Mode */
#define RSCMWGM_VAL_FAST_SWEEP_NORMAL 0
#define RSCMWGM_VAL_FAST_SWEEP_FAST   1

/* Retrigger */
#define RSCMWGM_VAL_RETRIGGER_OFF          0
#define RSCMWGM_VAL_RETRIGGER_ON	       1
#define RSCMWGM_VAL_RETRIGGER_IFPOWER	   2

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC rscmwgm_init(ViRsrc     resourceName,
                               ViBoolean  IDQuery,
                               ViBoolean  resetDevice,
                               ViSession* instrumentHandle);

ViStatus _VI_FUNC rscmwgm_InitWithOptions(ViRsrc     resourceName,
                                          ViBoolean  IDQuery,
                                          ViBoolean  resetDevice,
                                          ViString   optionString,
                                          ViSession* instrumentHandle);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerStandAloneScenario(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   RFConnector,
							ViInt32   RFConverter);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerCombinedSignalPathScenario(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViString  master);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerMeasureProtocolScenario(
							ViSession instrumentHandle,
							ViInt32   instance);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerMeasureProtocolScenarioApplication(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViString  application);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerExternalAttenuation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  externalAttenuation);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzer(ViSession instrumentHandle,
                                            ViInt32   instance,
                                            ViReal64  expectedNominalPower,
                                            ViReal64  margin,
                                            ViReal64  centerFrequency);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerChannelAndBand(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   band,
                                                          ViInt32   channel);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerMixerInputLevel(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViReal64  mixerLevelOffset);

ViStatus _VI_FUNC rscmwgm_ConfigureAnalyzerFrequencyOffset(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViReal64  frequencyOffset);

ViStatus _VI_FUNC rscmwgm_QuerySignalRouting(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViInt32*  scenario,
                                             ViChar    _VI_FAR controller[],
                                             ViInt32*  RFConnector,
                                             ViInt32*  RFConverter);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasStatistics(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   repetition,
                                                       ViInt32   stopCondition);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasStatisticsCount(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   measurement,
                                                            ViInt32   statisticCount);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasMeasuredSlot(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   slotOffset,
                                                         ViInt32   noOfSlot,
                                                         ViInt32   measuredSlot);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasResults(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   measurement,
                                                    ViBoolean state);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasParameters(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   frequencyRange,
                                                       ViBoolean signalLevelState,
                                                       ViReal64  signalLevel,
                                                       ViBoolean accessBurstMeasurement,
                                                       ViInt32   trainingSequence,
                                                       ViBoolean measureOnException);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasTimeout(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViReal64  timeout);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasModulationScheme(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   slot0,
                                                             ViInt32   slot1,
                                                             ViInt32   slot2,
                                                             ViInt32   slot3,
                                                             ViInt32   slot4,
                                                             ViInt32   slot5,
                                                             ViInt32   slot6,
                                                             ViInt32   slot7);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasIgnoreInitialOffFrames(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean ignoreInitialOffFrames);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasFramePattern(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   pattern0,
                                                         ViInt32   pattern1,
                                                         ViInt32   pattern2,
                                                         ViInt32   pattern3,
                                                         ViInt32   pattern4,
                                                         ViInt32   pattern5,
                                                         ViInt32   pattern6,
                                                         ViInt32   pattern7);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasPVT(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   refPowerMode,
                                                ViInt32   IFFilterBandwidth);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasPVTPCL(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   PCLMode,
                                                   ViInt32   _VI_FAR PCLValues[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasBER(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   loop);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasBERThreshold(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   thresholdType,
                                                         ViReal64  threshold);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasIQConstellation(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   rotation,
                                                            ViInt32   filter);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeas16QAMNBSearch(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViBoolean NBSearchState);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasVAMOSTSC(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   TSCSet);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasDecode(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   type);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasTrigger(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViString  source,
                                                    ViInt32   delay,
                                                    ViBoolean timeoutState,
                                                    ViReal64  timeout,
                                                    ViReal64  threshold,
                                                    ViInt32   slope);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasTriggerSourceCatalog(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViChar    _VI_FAR catalog[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasFrameMethod(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   method);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasFrameGapLength(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   gapLength);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasTriggerGap(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   gap);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasSpecModFOffset(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   arraySize,
                                                           ViBoolean _VI_FAR status[],
                                                           ViReal64  _VI_FAR frequencyOffset[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasSpecModEvalAreas(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViBoolean _VI_FAR status[],
                                                             ViInt32   _VI_FAR startOfArea[],
                                                             ViInt32   _VI_FAR stopOfArea[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasSpecModTimeFreqOffset(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   frequencyOffset);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasSpecModPwrAverMode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   powerAverageMode);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasSpecSwitchFOffset(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViBoolean _VI_FAR status[],
							ViReal64  _VI_FAR frequencyOffset[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasSpecSwitching(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   frequencyOffset,
                                                          ViInt32   holdMode);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeState(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean state);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeTriggerMode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   triggerMode);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalMeasListModeCMWSConnector(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   connectorMode,
							ViInt32   CMWSConnector);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeRange(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   firstMeasuredSegment,
							ViInt32   numberOfSegments);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeSegmentCount(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   measuredSegments,
							ViInt32   displayedSegments);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeStateIgnoreIdleFrames(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean ignore);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeStepLength(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   stepLength,
							ViBoolean stepLengthState);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeSegment(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   steps,
							ViReal64  nominalPower,
							ViReal64  frequency,
							ViInt32   powerControlLevel,
							ViInt32   retrigger,
							ViInt32   offset);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeModulationResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   statistics,
							ViBoolean EVMState,
							ViBoolean magnitudeErrorState,
							ViBoolean phaseErrorState,
							ViBoolean AMPMDelayState,
							ViString  framePattern);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModePVTResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   statistics,
							ViBoolean PVTState,
							ViString  framePattern);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeSpectrumModulationResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   statistics,
							ViBoolean spectrumModulationState,
							ViString  framePattern);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeSpectrumSwitchingResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   statistics,
							ViBoolean spectrumSwitchingState,
							ViString  framePattern);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiEvalMeasurementListModeBER(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   statistics,
							ViBoolean BERState,
							ViInt32   BERLoop,
							ViString  framePattern);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsEVM(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   modulationScheme,
                                                  ViReal64  RMSLimit,
                                                  ViBoolean _VI_FAR RMSLimitStatus[],
                                                  ViReal64  peakLimit,
                                                  ViBoolean _VI_FAR peakLimitStatus[],
                                                  ViReal64  _95Limit,
                                                  ViBoolean _95LimitStatus);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsMagnitudeError(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   modulationScheme,
                                                             ViReal64  RMSLimit,
                                                             ViBoolean _VI_FAR RMSLimitStatus[],
                                                             ViReal64  peakLimit,
                                                             ViBoolean _VI_FAR peakLimitStatus[],
                                                             ViReal64  _95Limit,
                                                             ViBoolean _95LimitStatus);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsPhaseError(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   modulationScheme,
                                                         ViReal64  RMSLimit,
                                                         ViBoolean _VI_FAR RMSLimitStatus[],
                                                         ViReal64  peakLimit,
                                                         ViBoolean _VI_FAR peakLimitStatus[],
                                                         ViReal64  _95Limit,
                                                         ViBoolean _95LimitStatus);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsIQOffset(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   modulationScheme,
                                                       ViReal64  limit,
                                                       ViBoolean _VI_FAR limitStatus[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsIQImbalance(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   modulationScheme,
                                                          ViReal64  limit,
                                                          ViBoolean _VI_FAR limitStatus[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsTimingError(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   modulationScheme,
                                                          ViInt32   limit,
                                                          ViBoolean _VI_FAR limitStatus[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsFreqError(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   modulationScheme,
                                                        ViReal64  limit,
                                                        ViBoolean _VI_FAR limitStatus[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsPVTBurstPower(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   groupNumber,
                                                            ViInt32   startPCL,
                                                            ViInt32   stopPCL,
                                                            ViReal64  lowerLimit,
                                                            ViReal64  upperLimit,
                                                            ViBoolean status);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsPVTGuardPeriod(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViReal64  level);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsPVTUpperLines(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   modulationScheme,
                                                            ViInt32   section,
                                                            ViInt32   area,
                                                            ViReal64  _VI_FAR time[],
                                                            ViReal64  _VI_FAR relativeLimitLevel[],
                                                            ViReal64  _VI_FAR absoluteLimitLevel[],
                                                            ViBoolean _VI_FAR absoluteLimitLevelStatus[],
                                                            ViBoolean statusArea);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsPVTLowerLines(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   modulationScheme,
                                                            ViInt32   area,
                                                            ViReal64  _VI_FAR time[],
                                                            ViReal64  _VI_FAR relativeLimitLevel[],
                                                            ViReal64  _VI_FAR absoluteLimitLevel[],
                                                            ViBoolean _VI_FAR absoluteLimitLevelStatus[],
                                                            ViBoolean statusArea);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsPVTUpperLinesDynamic(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   modulationScheme,
							ViInt32   section,
							ViInt32   area,
							ViInt32   range,
							ViBoolean status,
							ViInt32   startPCL,
							ViInt32   stopPCL,
							ViReal64  correction);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsPVTLowerLinesDynamic(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   modulationScheme,
							ViInt32   area,
							ViInt32   range,
							ViBoolean status,
							ViInt32   startPCL,
							ViInt32   stopPCL,
							ViReal64  correction);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsSpecModRefPower(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   modulationScheme,
							ViReal64  lowPower,
							ViReal64  highPower);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsSpecModFreqOffset(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   modulationScheme,
							ViInt32   frequencyOffset,
							ViReal64  lowPowerLimit,
							ViReal64  highPowerLimit,
							ViReal64  absoluteLimit,
							ViBoolean limitStatus);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsSpecSwitchRefPower(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   modulationScheme,
							ViBoolean _VI_FAR status[],
							ViReal64  _VI_FAR powerLevel[]);

ViStatus _VI_FUNC rscmwgm_ConfigureMEvalLimitsSpecSwitchFreqOffset(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   modulationScheme,
							ViInt32   frequencyOffset,
							ViReal64  _VI_FAR powerLimit[],
							ViBoolean limitStatus);

ViStatus _VI_FUNC rscmwgm_MEvalMeasInit(ViSession instrumentHandle,
                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwgm_MEvalMeasAbort(ViSession instrumentHandle,
                                         ViInt32   instance);

ViStatus _VI_FUNC rscmwgm_MEvalMeasStop(ViSession instrumentHandle,
                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasurementStatus(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32*  mainState,
                                                      ViInt32*  syncState,
                                                      ViInt32*  resourcesState);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasEVMTrace(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   resultType,
                                                ViInt32   arraySize,
                                                ViInt32*  reliability,
                                                ViReal64  _VI_FAR results[],
                                                ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasEVMTrace(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   resultType,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViReal64  _VI_FAR results[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasMagnErrTrace(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViReal64  _VI_FAR results[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasMagnErrTrace(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  _VI_FAR results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasPhaseErrTrace(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  _VI_FAR results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasPhaseErrTrace(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   resultType,
                                                      ViInt32   arraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  _VI_FAR results[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasModulationResults(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   resultType,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  _VI_FAR results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasModulationResults(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  _VI_FAR results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasModulationCheckLimitResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   resultType,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasModulationStandardDeviation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasModulationStandardDeviation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasModulationStandardDeviationCheckLimitResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasModulationPercentile(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  _VI_FAR results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasModulationPercentile(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  _VI_FAR results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasModulationPercentileCheckLimitResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllDemodulatedBits(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32*  results,
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasPVTTrace(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   resultType,
                                                ViInt32   arraySize,
                                                ViInt32*  reliability,
                                                ViReal64  _VI_FAR results[],
                                                ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasPVTTrace(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   resultType,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViReal64  _VI_FAR results[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasPVTResults(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   arraySize,
                                                  ViInt32*  reliability,
                                                  ViReal64  _VI_FAR results[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasPVTResults(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViReal64  _VI_FAR results[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasPVTCheckLimitResults(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViInt32   _VI_FAR results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasPVTSubvector(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  _VI_FAR results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasPVTSubvectorCheckLimitResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   resultType,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasPVTBurstType(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViInt32   _VI_FAR results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasPVTRealtiveSlotTiming(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasPVTTrainingSequenceCode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecModulationBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecModulationBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasSpecModulationBurstPowerCheckLimitResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecModulationFrequencyLimitsResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecModulationFrequencyLimitsResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecModulationTrace(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  _VI_FAR results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecModulationTrace(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  _VI_FAR results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecModulationResult(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  _VI_FAR results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecModulationResult(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  _VI_FAR results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasSpecModulationCheckLimitResult(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecSwitchBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecSwitchBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasSpecSwitchBurstPowerCheckLimitResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecSwitchFrequencyLimitsResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecSwitchFrequencyLimitsResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecSwitchTrace(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViReal64  _VI_FAR results[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecSwitchTrace(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   arraySize,
                                                        ViInt32*  reliability,
                                                        ViReal64  _VI_FAR results[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasSpecSwitchResult(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   arraySize,
                                                        ViInt32*  reliability,
                                                        ViReal64  _VI_FAR results[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasSpecSwitchResult(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  _VI_FAR results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasSpecSwitchCheckLimitResult(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasIQConstellationResult(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  _VI_FAR i[],
                                                             ViReal64  _VI_FAR q[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasIQConstellationResult(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViReal64  _VI_FAR i[],
							ViReal64  _VI_FAR q[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_ReadMEvalMeasBERResult(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32*  reliability,
                                                 ViInt32*  errors,
                                                 ViInt32*  bursts);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasBERResult(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32*  reliability,
                                                  ViInt32*  errors,
                                                  ViInt32*  bursts);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasBERCheckLimitResult(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32*  reliability,
                                                            ViInt32*  errors,
                                                            ViInt32*  bursts);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeModulationResults(
							ViSession  instrumentHandle,
							ViInt32    instance,
							ViInt32    segment,
							ViInt32    resultType,
							ViInt32    arraySize,
							ViInt32*   reliability,
							ViInt32*   returnCode,
							ViReal64*  statisticsExpired,
							ViInt32*   burstType,
							ViBoolean* slotStatistics,
							ViReal64*  outOfTolerance,
							ViReal64   _VI_FAR results[],
							ViInt32*   returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitModulationResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   resultType,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  outOfTolerance,
							ViInt32*  results,
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeModulationStandardDeviation(
							ViSession  instrumentHandle,
							ViInt32    instance,
							ViInt32    segment,
							ViInt32    arraySize,
							ViInt32*   reliability,
							ViInt32*   returnCode,
							ViReal64*  statisticsExpired,
							ViInt32*   burstType,
							ViBoolean* slotStatistics,
							ViReal64*  outOfTolerance,
							ViReal64   _VI_FAR results[],
							ViInt32*   returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitModulationStandardDeviation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  outOfTolerance,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeModulationPercentile(
							ViSession  instrumentHandle,
							ViInt32    instance,
							ViInt32    segment,
							ViInt32    arraySize,
							ViInt32*   reliability,
							ViInt32*   returnCode,
							ViReal64*  statisticsExpired,
							ViInt32*   burstType,
							ViBoolean* slotStatistics,
							ViReal64*  outOfTolerance,
							ViReal64   _VI_FAR results[],
							ViInt32*   returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitModulationPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  outOfTolerance,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeSpectrumModulation(
							ViSession  instrumentHandle,
							ViInt32    instance,
							ViInt32    segment,
							ViInt32    arraySize,
							ViInt32*   reliability,
							ViInt32*   returnCode,
							ViReal64*  statisticsExpired,
							ViInt32*   burstType,
							ViBoolean* slotStatistics,
							ViReal64*  outOfTolerance,
							ViReal64*  carrierPower,
							ViReal64   _VI_FAR powerOffset[],
							ViInt32*   returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitSpectrumModulation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  outOfTolerance,
							ViInt32*  carrierPower,
							ViInt32   _VI_FAR powerOffset[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeSpectrumSwitching(
							ViSession  instrumentHandle,
							ViInt32    instance,
							ViInt32    segment,
							ViInt32    arraySize,
							ViInt32*   reliability,
							ViInt32*   returnCode,
							ViReal64*  statisticsExpired,
							ViInt32*   burstType,
							ViBoolean* slotStatistics,
							ViReal64*  outOfTolerance,
							ViReal64*  carrierPower,
							ViReal64   _VI_FAR powerOffset[],
							ViInt32*   returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitSpectrumSwitching(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  outOfTolerance,
							ViInt32*  carrierPower,
							ViInt32   _VI_FAR powerOffset[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeSpectrumBER(ViSession  instrumentHandle,
                                                            ViInt32    instance,
                                                            ViInt32    segment,
                                                            ViInt32*   reliability,
                                                            ViInt32*   returnCode,
                                                            ViReal64*  statisticsExpired,
                                                            ViInt32*   burstType,
                                                            ViBoolean* slotStatistics,
                                                            ViInt32*   ber,
                                                            ViInt32*   errors,
                                                            ViInt32*   bursts);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitSpectrumBER(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  ber,
							ViInt32*  errors,
							ViInt32*  bursts);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModePVTResults(ViSession  instrumentHandle,
                                                           ViInt32    instance,
                                                           ViInt32    segment,
                                                           ViInt32    resultType,
                                                           ViInt32*   reliability,
                                                           ViInt32*   returnCode,
                                                           ViReal64*  statisticsExpired,
                                                           ViInt32*   burstType,
                                                           ViBoolean* slotStatistics,
                                                           ViReal64*  outOfTolerance,
                                                           ViReal64*  averageBurstPower);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitPVTResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  outOfTolerance,
							ViInt32*  averageBurstPower);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModePVTSubvector(ViSession  instrumentHandle,
                                                             ViInt32    instance,
                                                             ViInt32    segment,
                                                             ViInt32    resultType,
                                                             ViInt32    arraySize,
                                                             ViInt32*   reliability,
                                                             ViInt32*   returnCode,
                                                             ViReal64*  statisticsExpired,
                                                             ViInt32*   burstType,
                                                             ViBoolean* slotStatistics,
                                                             ViReal64*  outOfTolerance,
                                                             ViReal64*  usefulPartMin,
                                                             ViReal64*  usefulPartMax,
                                                             ViReal64   _VI_FAR subvector[],
                                                             ViInt32*   returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeCheckLimitPVTSubvector(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   segment,
							ViInt32   resultType,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32*  returnCode,
							ViInt32*  statisticsExpired,
							ViInt32*  burstType,
							ViInt32*  slotStatistics,
							ViInt32*  outOfTolerance,
							ViInt32*  usefulPartMin,
							ViInt32*  usefulPartMax,
							ViInt32   _VI_FAR subvector[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllModulationResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViReal64  _VI_FAR outOfTolerance[],
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitModulationResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR outOfTolerance[],
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllModulationStandardDeviation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViReal64  _VI_FAR outOfTolerance[],
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitModulationStandardDeviation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR outOfTolerance[],
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllModulationPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViReal64  _VI_FAR outOfTolerance[],
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitModulationPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR outOfTolerance[],
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllSpectrumModulation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViReal64  _VI_FAR outOfTolerance[],
							ViReal64  _VI_FAR carrierPower[],
							ViReal64  _VI_FAR powerOffset[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitSpectrumModulation(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR outOfTolerance[],
							ViInt32   _VI_FAR carrierPower[],
							ViInt32   _VI_FAR powerOffset[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllSpectrumSwitching(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViReal64  _VI_FAR outOfTolerance[],
							ViReal64  _VI_FAR carrierPower[],
							ViReal64  _VI_FAR powerOffset[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitSpectrumSwitching(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR outOfTolerance[],
							ViInt32   _VI_FAR carrierPower[],
							ViInt32   _VI_FAR powerOffset[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllSpectrumBER(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR BER[],
							ViInt32   _VI_FAR errors[],
							ViInt32   _VI_FAR bursts[]);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitSpectrumBER(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR BER[],
							ViInt32   _VI_FAR errors[],
							ViInt32   _VI_FAR bursts[]);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllPVTResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViReal64  _VI_FAR outOfTolerance[],
							ViReal64  _VI_FAR averageBurstPower[]);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitPVTResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR outOfTolerance[],
							ViInt32   _VI_FAR averageBurstPower[]);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllPVTSubvector(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViBoolean _VI_FAR slotStatistics[],
							ViReal64  _VI_FAR outOfTolerance[],
							ViReal64  _VI_FAR usefulPartMin[],
							ViReal64  _VI_FAR usefulPartMax[],
							ViReal64  _VI_FAR subvector[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitPVTSubvector(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR statisticsExpired[],
							ViInt32   _VI_FAR burstType[],
							ViInt32   _VI_FAR slotStatistics[],
							ViInt32   _VI_FAR outOfTolerance[],
							ViInt32   _VI_FAR usefulPartMin[],
							ViInt32   _VI_FAR usefulPartMax[],
							ViInt32   _VI_FAR subvector[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllReliabilityResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllOverviewResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMEvalMeasListModeAllCheckLimitOverviewResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   arraySize,
							ViInt32*  reliability,
							ViInt32   _VI_FAR returnCode[],
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllIQOffsetResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitIQOffsetResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllIQImbalanceResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitIQImbalanceResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllCarrierFrequencyErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitCarrierFrequencyErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllTransmitTimeErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitTransmitTimeErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllAMPMDelayResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitAMPMDelayResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllEVMResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   type,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitEVMResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   type,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllEVMPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitEVMPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllMagnitudeErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   type,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitMagnitudeErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   type,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllMagnitudeErrorPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitMagnitudeErrorPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllPhaseErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   type,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitPhaseErrorResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   type,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllPhaseErrorPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitPhaseErrorPercentile(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllSpectrumModulationCarrierPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitSpectrumModulationCarrierPower(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllSpectrumModulationBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   frequencyOffset,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitSpectrumModulationBurstPower(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   frequencyOffset,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllSpectrumSwitchingCarrierPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitSpectrumSwitchingCarrierPower(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMultiEvalListModeAllSpectrumSwitchingBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   frequencyOffset,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitSpectrumSwitchingBurstPower(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   frequencyOffset,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllBERResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllPVTAverageBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_QueryMultiEvalListModeAllCheckLimitPVTAverageBurstPowerResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32*  reliability,
							ViInt32   _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllPVTUsefulPartResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   powerType,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasListModeAllPVTSubvectorAtPositionResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfActiveSegments,
							ViInt32   resultType,
							ViInt32   burstPosition,
							ViInt32*  reliability,
							ViReal64  _VI_FAR results[],
							ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwgm_FetchMEvalMeasModulationViewThroughput(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32*  reliability,
							ViReal64* result);

ViStatus _VI_FUNC rscmwgm_SetAttributeViInt32(ViSession instrumentHandle,
                                              ViString  repeatedCapabilityName,
                                              ViUInt32  attributeID,
                                              ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwgm_SetAttributeViReal64(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwgm_SetAttributeViString(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViString  attributeValue);

ViStatus _VI_FUNC rscmwgm_SetAttributeViBoolean(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwgm_SetAttributeViSession(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViSession attributeValue);

ViStatus _VI_FUNC rscmwgm_GetAttributeRepCapName(ViSession instrumentHandle,
                                                 ViUInt32  attributeID,
                                                 ViString  repCapNameID,
                                                 ViInt32   index,
                                                 ViInt32   bufferSize,
                                                 ViChar    _VI_FAR repCapName[]);

ViStatus _VI_FUNC rscmwgm_GetAttributeRepeatedCapabilityIds(ViSession instrumentHandle,
                                                            ViUInt32  attributeID,
                                                            ViInt32   bufferSize,
                                                            ViChar    _VI_FAR repeatedCapabilityId_s[]);

ViStatus _VI_FUNC rscmwgm_GetAttributeRepeatedCapabilityIdNames(
							ViSession instrumentHandle,
							ViUInt32  attributeID,
							ViString  repeatedCapabilityId,
							ViInt32   bufferSize,
							ViChar    _VI_FAR repeatedCapabilityIdName_s[]);

ViStatus _VI_FUNC rscmwgm_GetAttributeViInt32(ViSession instrumentHandle,
                                              ViString  repeatedCapabilityName,
                                              ViUInt32  attributeID,
                                              ViInt32*  attributeValue);

ViStatus _VI_FUNC rscmwgm_GetAttributeViReal64(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViReal64* attributeValue);

ViStatus _VI_FUNC rscmwgm_GetAttributeViString(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViInt32   bufferSize,
                                               ViChar    _VI_FAR attributeValue[]);

ViStatus _VI_FUNC rscmwgm_GetAttributeViBoolean(ViSession  instrumentHandle,
                                                ViString   repeatedCapabilityName,
                                                ViUInt32   attributeID,
                                                ViBoolean* attributeValue);

ViStatus _VI_FUNC rscmwgm_GetAttributeViSession(ViSession  instrumentHandle,
                                                ViString   repeatedCapabilityName,
                                                ViUInt32   attributeID,
                                                ViSession* attributeValue);

ViStatus _VI_FUNC rscmwgm_CheckAttributeViInt32(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwgm_CheckAttributeViReal64(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwgm_CheckAttributeViString(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViString  attributeValue);

ViStatus _VI_FUNC rscmwgm_CheckAttributeViBoolean(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwgm_CheckAttributeViSession(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViSession attributeValue);

ViStatus _VI_FUNC rscmwgm_reset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgm_self_test(ViSession instrumentHandle,
                                    ViInt16*  selfTestResult,
                                    ViChar    _VI_FAR selfTestMessage[]);

ViStatus _VI_FUNC rscmwgm_SelfTestResults(ViSession instrumentHandle,
                                          ViInt32   bufferSize,
                                          ViChar    _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgm_revision_query(ViSession instrumentHandle,
                                         ViChar    _VI_FAR instrumentDriverRevision[],
                                         ViChar    _VI_FAR firmwareRevision[]);

ViStatus _VI_FUNC rscmwgm_SystemVersion(ViSession instrumentHandle,
                                        ViInt32   length,
                                        ViChar    _VI_FAR systemVersion[]);

ViStatus _VI_FUNC rscmwgm_error_query(ViSession instrumentHandle,
                                      ViInt32*  errorCode,
                                      ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwgm_ErrorList(ViSession instrumentHandle,
                                    ViInt32   bufferSize,
                                    ViChar    _VI_FAR errors[]);

ViStatus _VI_FUNC rscmwgm_error_message(ViSession instrumentHandle,
                                        ViStatus  errorCode,
                                        ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwgm_ReliabilityIndicator(ViSession instrumentHandle,
                                               ViInt32   reliabilityCode,
                                               ViChar    _VI_FAR reliabilityMessage[]);

ViStatus _VI_FUNC rscmwgm_Preset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgm_SetTimeout(ViSession instrumentHandle,
                                     ViInt32   timeout);

ViStatus _VI_FUNC rscmwgm_GetTimeout(ViSession instrumentHandle,
                                     ViInt32*  timeout);

ViStatus _VI_FUNC rscmwgm_SetOPCTimeout(ViSession instrumentHandle,
                                        ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rscmwgm_GetOPCTimeout(ViSession instrumentHandle,
                                        ViUInt32* timeout);

ViStatus _VI_FUNC rscmwgm_SetVISATimeout(ViSession instrumentHandle,
                                         ViUInt32  VISATimeout);

ViStatus _VI_FUNC rscmwgm_GetVISATimeout(ViSession instrumentHandle,
                                         ViUInt32* VISATimeout);

ViStatus _VI_FUNC rscmwgm_ClearStatus(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgm_IDQueryResponse(ViSession instrumentHandle,
                                          ViUInt32  bufferSize,
                                          ViChar    _VI_FAR IDQueryResponse[]);

ViStatus _VI_FUNC rscmwgm_ProcessAllPreviousCommands(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgm_QueryOPC(ViSession instrumentHandle,
                                   ViInt32*  OPC);

ViStatus _VI_FUNC rscmwgm_ConfigureErrorChecking(ViSession instrumentHandle,
                                                 ViBoolean optionChecking,
                                                 ViBoolean rangeChecking,
                                                 ViBoolean statusChecking);

ViStatus _VI_FUNC rscmwgm_ConfigureAutoSystemErrQuery(ViSession instrumentHandle,
                                                      ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rscmwgm_ConfigureMultiThreadLocking(ViSession instrumentHandle,
                                                      ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rscmwgm_GetError(ViSession instrumentHandle,
                                   ViStatus* code,
                                   ViInt32   bufferSize,
                                   ViChar    _VI_FAR description[]);

ViStatus _VI_FUNC rscmwgm_ClearError(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgm_ReadToFileFromInstrument(ViSession instrumentHandle,
                                                   ViString  source,
                                                   ViString  destination);

ViStatus _VI_FUNC rscmwgm_WriteFromFileToInstrument(ViSession instrumentHandle,
                                                    ViString  source,
                                                    ViString  destination);

ViStatus _VI_FUNC rscmwgm_WriteInstrData(ViSession instrumentHandle,
                                         ViString  writeBuffer);

ViStatus _VI_FUNC rscmwgm_ReadInstrData(ViSession instrumentHandle,
                                        ViInt32   numberOfBytesToRead,
                                        ViChar    _VI_FAR readBuffer[],
                                        ViUInt32* numBytesRead);

ViStatus _VI_FUNC rscmwgm_WriteCommandWithOPCSync(ViSession instrumentHandle,
                                                  ViString  writeBuffer,
                                                  ViUInt32  timeout);

ViStatus _VI_FUNC rscmwgm_QueryWithOPCSync(ViSession instrumentHandle,
                                           ViString  writeBuffer,
                                           ViUInt32  timeout,
                                           ViInt32   bufferSize,
                                           ViChar    _VI_FAR readBuffer[],
                                           ViUInt32* numBytesRead);

ViStatus _VI_FUNC rscmwgm_QueryViBoolean(ViSession  instrumentHandle,
                                         ViString   command,
                                         ViBoolean* value);

ViStatus _VI_FUNC rscmwgm_QueryViInt32(ViSession instrumentHandle,
                                       ViString  command,
                                       ViInt32*  value);

ViStatus _VI_FUNC rscmwgm_QueryViReal64(ViSession instrumentHandle,
                                        ViString  command,
                                        ViReal64* value);

ViStatus _VI_FUNC rscmwgm_QueryViString(ViSession instrumentHandle,
                                        ViString  command,
                                        ViInt32   bufferSize,
                                        ViChar    _VI_FAR value[]);

ViStatus _VI_FUNC rscmwgm_close(ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWGM_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWGM_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWGM_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWGM_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWGM_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWGM_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWGM_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWGM_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWGM_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSCMWGM_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSCMWGM_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWGM_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWGM_ERROR_CODES_AND_MSGS \
    {RSCMWGM_WARN_MEASURE_UNCALIBRATED,  RSCMWGM_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWGM_WARN_OVER_RANGE,            RSCMWGM_WARNMSG_OVER_RANGE},\
    {RSCMWGM_ERROR_INCORRECT_STATE ,   RSCMWGM_ERRMSG_INCORRECT_STATE },\
    {RSCMWGM_ERROR_INCORRECT_RESPONSE,     RSCMWGM_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWGM_ERROR_MAX_TIME_EXCEEDED,    RSCMWGM_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWGM_ERROR_RELIABILITY_INDICATOR, RSCMWGM_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWGM_HEADER */
