/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rscmwgm.h"

#pragma warning( disable : 4152 )

/*****************************************************************************
 * Function: rscmwgm_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rscmwgm_InitAttributes(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    // - Class Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_DESCRIPTION, 0, RSCMWGM_CLASS_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_PREFIX, 0, RSCMWGM_CLASS_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_VENDOR, 0, RSCMWGM_CLASS_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_REVISION, 0, RSCMWGM_CLASS_DRIVER_REVISION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSCMWGM_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSCMWGM_CLASS_SPEC_MINOR_VERSION));

    // - Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSCMWGM_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSCMWGM_SPECIFIC_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSCMWGM_SPECIFIC_DRIVER_LOCATOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSCMWGM_SPECIFIC_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSCMWGM_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSCMWGM_CLASS_SPEC_MINOR_VERSION));

    // - Driver Capabilities -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSCMWGM_SUPPORTED_INSTRUMENT_MODELS));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSCMWGM_GROUP_CAPABILITIES));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSCMWGM_FUNCTION_CAPABILITIES));

    // - Version Info -
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, RSCMWGM_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, RSCMWGM_MINOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, RSCMWGM_MINOR_MINOR_VERSION));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, RSCMWGM_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, RSCMWGM_CLASS_SPEC_MINOR_VERSION));

    checkErr(RsCore_SetSpecificDriverRevision(instrSession, RS_ATTR_SPECIFIC_DRIVER_REVISION));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwgm_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rscmwgm_reset function calls this function. The
 *           rscmwgm_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwgm_DefaultInstrSetup(ViSession instrSession)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    // Set all the attributes to the default state. Do not update inherent attributes!
    checkErr(RsCore_ApplyAttributeDefaults(instrSession, VI_FALSE));

    // Init attributes
    checkErr(rscmwgm_InitAttributes(instrSession));

    rsSession->fastSweepInstrument = 0;
    checkErr(RsCore_ResetRegistersEseSre(instrSession));
    checkErr(RsCore_Write(instrSession, ":FORM:BASE ASC,10"));
    checkErr(RsCore_Write(instrSession, ":SYST:DISP:UPD OFF"));
    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", NULL));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwgm_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rscmwgm_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwgm_CheckStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    if (RsCore_QueryInstrStatus(instrSession) && !RsCore_Simulating(instrSession))
    {
        checkErr(RsCore_CheckStatus(instrSession, VI_SUCCESS));
    }

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwgm_instanceRepCap
 * Purpose:  This function checks instance repeated capability and
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwgm_instanceRepCap(ViSession instrSession,
                                ViInt32   instance,
                                ViChar    repCap[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwgm_QueryMeasStatus
 * Purpose:  This function queries measurement status
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgm_QueryMeasStatus(ViSession instrSession,
                                          ViString  cmd,
                                          ViInt32*  mainState,
                                          ViInt32*  syncState,
                                          ViInt32*  resourcesState)
{
	ViStatus error = VI_SUCCESS;
	ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
	ViChar*  p2buf;
	ViString mainStateArr[] = { "OFF","RDY","RUN",NULL };
	ViString syncStateArr[] = { "PEND","ADJ","INV",NULL };
	ViString resStateArr[] = { "QUE","ACT","INV",NULL };

	checkErr(RsCore_QueryViString(instrSession, cmd, response));

	p2buf = strtok(response, ",");
	if (p2buf == NULL)
		return RSCMWGM_ERROR_INCORRECT_STATE;
	*mainState = RsCore_FindStringIndex(mainStateArr, p2buf);
	if (*mainState < 0)
		return RSCMWGM_ERROR_INCORRECT_STATE;

	p2buf = strtok(NULL, ",");
	if (p2buf == NULL)
		return RSCMWGM_ERROR_INCORRECT_STATE;
	*syncState = RsCore_FindStringIndex(syncStateArr, p2buf);
	if (*syncState < 0)
		return RSCMWGM_ERROR_INCORRECT_STATE;

	p2buf = strtok(NULL, ",\n");
	if (p2buf == NULL)
		return RSCMWGM_ERROR_INCORRECT_STATE;
	*resourcesState = RsCore_FindStringIndex(resStateArr, p2buf);
	if (*resourcesState < 0)
		return RSCMWGM_ERROR_INCORRECT_STATE;

Error:
	return error;
}

/*****************************************************************************
 * Function: rscmwgm_GetMeasTrace
 * Purpose:  This function queries measurement data trace
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgm_GetMeasTrace(ViSession instrSession,
                                       ViString  cmd,
                                       ViInt32   timeout,
                                       ViInt32   arraySize,
                                       ViInt32*  reliability,
                                       ViReal64  result[],
                                       ViInt32   *returnedValues)
{
	ViStatus error = VI_SUCCESS;
	ViChar*  ext_buf = NULL;
	ViChar*  p2buf;
	ViInt32  i = 0;

	if (timeout == 0)
	{
		checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, NULL));
	}
	else
	{
		checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, NULL));
	}

	p2buf = strtok(ext_buf, ",");
	if (p2buf == NULL)
		return RSCMWGM_ERROR_INCORRECT_RESPONSE;

	if (reliability != NULL)
		*reliability = RsCore_Convert_String_To_ViInt32(p2buf);

	p2buf = strtok(NULL, ",\n");
	while (p2buf != NULL)
	{
		if (i < arraySize)
		{
			result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
		}
		p2buf = strtok(NULL, ",\n");
	}

	if (returnedValues)
		*returnedValues = i;

	checkErr(rscmwgm_CheckStatus(instrSession));

Error:
	if (ext_buf) free(ext_buf);
	return error;
}

/*****************************************************************************
 * Function: rscmwgm_GetMeasIntValues
 * Purpose:  This function queries measurement data trace
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgm_GetMeasIntValues(ViSession instrSession,
                                           ViString  cmd,
                                           ViInt32   timeout,
                                           ViInt32   arraySize,
                                           ViInt32*  reliability,
                                           ViInt32   result[],
                                           ViInt32*  returnedValues)
{
	ViStatus error = VI_SUCCESS;
	ViChar*  ext_buf = NULL;
	ViChar*  p2buf;
	ViInt32  i = 0;

	if (timeout == 0)
	{
		checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, NULL));
	}
	else
	{
		checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, NULL));
	}

	p2buf = strtok(ext_buf, ",");
	if (p2buf == NULL)
		return RSCMWGM_ERROR_INCORRECT_RESPONSE;

	if (reliability != NULL)
		*reliability = RsCore_Convert_String_To_ViInt32(p2buf);

	p2buf = strtok(NULL, ",\n");
	while (p2buf != NULL)
	{
		if (i < arraySize)
		{
			result[i++] = RsCore_Convert_String_To_ViInt32(p2buf);
		}
		p2buf = strtok(NULL, ",\n");
	}

	if (returnedValues)
		*returnedValues = i;

	checkErr(rscmwgm_CheckStatus(instrSession));

Error:
	if (ext_buf) free(ext_buf);
	return error;
}

/*****************************************************************************
 * Function: rscmwgm_GetMeasErrorCodes
 * Purpose:  This function queries reability and limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgm_GetMeasErrorCodes(ViSession instrSession,
                                            ViString  cmd,
                                            ViInt32   *reliability,
                                            ViInt32   arraySize,
                                            ViInt32   codes[],
                                            ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    static   ViString list[] = {"OK","ULEU","ULEL","OFL","UFL","INV","NAV",NULL};

    viCheckParm(RsCore_InvalidNullPointer(instrSession, codes),
    	6, "Results Codes");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, returnedValues),
    	6, "Returned Values");

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwgm_CheckStatus(instrSession));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWGM_ERROR_INCORRECT_RESPONSE;

    if (reliability != NULL)
        *reliability = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok (NULL, ",\n");

    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            codes[i++] = RsCore_FindStringIndex(list, p2buf);
        }
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues)
		*returnedValues=i;

Error:
    if (ext_buf) free (ext_buf);
    return error;
}


/*****************************************************************************
 * Function: rscmwgm_GetMeasErrorCodesQuery
 * Purpose:  This function queries measurement data (Queries in List Mode Segment)
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgm_GetMeasErrorCodesQuery(ViSession instrSession,
                                                 ViString  cmd,
                                                 ViInt32   *reliability,
                                                 ViInt32   arraySize,
                                                 ViInt32   codes[],
                                                 ViInt32   *returnCode,
                                                 ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    static   ViString list[] = {"OK","ULEU","ULEL","OFL","UFL","INV","NAV",NULL};

    viCheckParm(RsCore_InvalidNullPointer(instrSession, codes),
    	6, "Results Codes");

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwgm_CheckStatus(instrSession));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWGM_ERROR_INCORRECT_RESPONSE;

    if (reliability != NULL)
        *reliability = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok (NULL, ",\n");
    if (returnCode != NULL)
    {
        *returnCode = RsCore_Convert_String_To_ViInt32(p2buf);
    }
    else
    {
        viCheckParm(RsCore_InvalidNullPointer(instrSession, returnCode), 7, "Return Code");
    }

    p2buf = strtok (NULL, ",\n");

    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            codes[i++] = RsCore_FindStringIndex(list, p2buf);
        }
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues)
		*returnedValues=i;

Error:
    if (ext_buf) free (ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwgm_instance_mevMeasRepCap
 * Purpose:  This function checks mevMeas repeated capability and
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwgm_instance_mevMeasRepCap(ViSession instrSession,
                                        ViInt32   instance,
                                        ViInt32   measurement,
                                        ViChar    repCap[])
{
	ViStatus error = VI_SUCCESS;
	ViString mevMeasArr[] = { "mevMeasPVT","mevMeasMOD","mevMeasSMOD","mevMeasSSW","mevMeasBER" };

	viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
			2, "Instance");
	viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 0, 4),
			3, "Measurement");

	snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,%s", instance, mevMeasArr[measurement]);

Error:
	return error;
}