/****************************************************************************
 *
 * Rohde & Schwarz CMW Communication tester GSM Signaling instrument
 *  driver include file
 ****************************************************************************/

#ifndef __RSCMWGS_HEADER
#define __RSCMWGS_HEADER

#include "rscore.h"
#include "rscmwgs_attributes.h"
#include "rscmwgs_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWGS_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWGS_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWGS_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWGS_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWGS_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWGS_CLASS_DRIVER_PREFIX                ""
#define RSCMWGS_CLASS_DRIVER_VENDOR                ""
#define RSCMWGS_CLASS_DRIVER_REVISION              ""
#define RSCMWGS_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWGS_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWGS_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWGS_SPECIFIC_DRIVER_PREFIX             "RSCMWGS"
#define RSCMWGS_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWGS_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWGS_MAJOR_VERSION                      3L    /* Instrument driver major version          */
#define RSCMWGS_MINOR_VERSION                      7L   /* Instrument driver minor version          */
#define RSCMWGS_MINOR_MINOR_VERSION                220L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSCMWGS_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWGS_GROUP_CAPABILITIES                 ""
#define RSCMWGS_FUNCTION_CAPABILITIES              ""

#define RSCMWGS_VAL_VALUE 2
/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWGS_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWGS_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWGS_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWGS_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWGS_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWGS_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWGS_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWGS_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWGS_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWGS_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWGS_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWGS_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWGS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWGS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWGS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMWGS_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWGS_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWGS_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWGS_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWGS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWGS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWGS_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWGS_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWGS_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWGS_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWGS_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWGS_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWGS_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWGS_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWGS_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWGS_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSCMWGS_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSCMWGS_ATTR_EXTERNAL_ATTENUATION_INPUT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSCMWGS_ATTR_EXTERNAL_ATTENUATION_OUTPUT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWGS_ATTR_EXTERNAL_ATTENUATION_BCCH_OUTPUT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSCMWGS_ATTR_BCCH_BAND                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWGS_ATTR_BCCH_CHANNEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWGS_ATTR_BCCH_ENABLE_LOWER_LIMIT_CHECK                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define RSCMWGS_ATTR_PMAX_BCCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWGS_ATTR_TCH_CIRCUIT_SWITCHED_PCL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWGS_ATTR_EXPECTED_NOMINAL_POWER_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWGS_ATTR_EXPECTED_NOMINAL_POWER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWGS_ATTR_EXPECTED_NOMINAL_POWER_MARGIN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWGS_ATTR_RF_MIXER_LEVEL_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSCMWGS_ATTR_BCCH_LEVEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSCMWGS_ATTR_FREQUENCY_OFFSET_DL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSCMWGS_ATTR_FREQUENCY_OFFSET_UL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSCMWGS_ATTR_EXTERNAL_DELAY_COMPENSATION_DL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 225
#define RSCMWGS_ATTR_EXTERNAL_DELAY_COMPENSATION_UL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSCMWGS_ATTR_TCH_CHANNEL_NUMBER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWGS_ATTR_TCH_LEVEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWGS_ATTR_TCH_HOPPING_ENABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWGS_ATTR_HOPPING_MAIO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWGS_ATTR_HOPPING_HSN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSCMWGS_ATTR_EXTERNAL_ATTENUATION_PATH_OUTPUT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSCMWGS_ATTR_FADING_SIMULATOR_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSCMWGS_ATTR_FADING_SIMULATOR_STANDARD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSCMWGS_ATTR_FADING_SIMULATOR_RESTART_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSCMWGS_ATTR_FADING_SIMULATOR_RESTART                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSCMWGS_ATTR_FADING_SIMULATOR_GLOBAL_SEED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS_MODE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS_USER_VALUE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSCMWGS_ATTR_FADING_SIMULATOR_CLIPPING_COUNTER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSCMWGS_ATTR_FADING_SIMULATOR_DOPPLER_FREQUENCY_MODE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSCMWGS_ATTR_FADING_SIMULATOR_DOPPLER_FREQUENCY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSCMWGS_ATTR_NOISE_BW_POWER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSCMWGS_ATTR_NOISE_TOTAL_POWER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSCMWGS_ATTR_SIGNAL_PLUS_NOISE_POWER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSCMWGS_ATTR_FADING_AWGN_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSCMWGS_ATTR_FADING_AWGN_BANDWIDTH_RATIO                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 182
#define RSCMWGS_ATTR_FADING_AWGN_SIGNAL_TO_NOISE_RATIO                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSCMWGS_ATTR_FADING_AWGN_NOISE_BANDWIDTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSCMWGS_ATTR_SIGNALING_END_TO_END                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSCMWGS_ATTR_SIGNALING_CONNECTION_ACTION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWGS_ATTR_SIGNALING_CONNECTION_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWGS_ATTR_SIGNALING_PACKET_SWITCHED_CONNECTION_ACTION            RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWGS_ATTR_SIGNALING_PACKET_SWITCHED_CONNECTION_STATE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWGS_ATTR_SIGNALING_SPEECH_CODEC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSCMWGS_ATTR_GENERATOR_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWGS_ATTR_CLEAN_EVENT_LOG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_LEVEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_QUALITY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_LEVEL_SUB                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_QUALITY_SUB                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_COUNT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_RECEIVED_BLOCKS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_C_VALUE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_BEP                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_GMSK_BEP                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_8PSK_BEP                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_QAM_BEP                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_BEP                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_GMSK_BEP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_8PSK_BEP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_QAM_BEP                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSCMWGS_ATTR_MEASUREMENT_REPORTS_SIGNAL_VARIANCE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_RX_POWER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_IMEI                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_IMSI                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_DIALED_NUMBER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_MULTISLOT_CLASS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_IP_ADDRESS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_APN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_EGPRS2                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 279
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_GPRS_AND_EGPRS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_SSCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSCMWGS_ATTR_MOBILE_CAPABILITIES_VAMOS_LEVEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSCMWGS_ATTR_NETWORK_IDENTITY_CELL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWGS_ATTR_NETWORK_IDENTITY_MCC                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWGS_ATTR_NETWORK_IDENTITY_MNC_DIGITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWGS_ATTR_NETWORK_IDENTITY_MNC                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWGS_ATTR_NETWORK_IDENTITY_LAC                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWGS_ATTR_NETWORK_IDENTITY_RAC                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWGS_ATTR_NETWORK_IDENTITY_NCC                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSCMWGS_ATTR_NETWORK_IDENTITY_BCC                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSCMWGS_ATTR_NETWORK_REQUESTED_IMEI                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWGS_ATTR_NETWORK_REQUESTED_AUTHENTICATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWGS_ATTR_NETWORK_REQUESTED_IMSI                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSCMWGS_ATTR_NETWORK_REQUESTED_CLASSMARK                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSCMWGS_ATTR_NETWORK_CELL_EC_GSM_IOT_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSCMWGS_ATTR_NETWORK_CELL_LOCATION_UPDATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWGS_ATTR_NETWORK_CELL_BS_AG_BLKS_RES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSCMWGS_ATTR_NETWORK_CELL_BS_PA_MFRMS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWGS_ATTR_NETWORK_CELL_MS_DTX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSCMWGS_ATTR_NETWORK_CELL_BAND_INDICATOR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWGS_ATTR_NETWORK_CELL_EARLY_CLASSMARK_SENDING                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSCMWGS_ATTR_NETWORK_CELL_PAGE_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSCMWGS_ATTR_NETWORK_CELL_NCC_PERMITTED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSCMWGS_ATTR_NETWORK_CELL_MAX_RETRANS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSCMWGS_ATTR_NETWORK_CELL_PAGING_WITH_MS_IDENTITY                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSCMWGS_ATTR_NETWORK_CELL_INITIAL_POWER_REDUCTION_ENABLED           RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSCMWGS_ATTR_NETWORK_CELL_INITIAL_POWER_REDUCTION_VALUE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSCMWGS_ATTR_NETWORK_CELL_BARING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSCMWGS_ATTR_NETWORK_CELL_SIM_CARD_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSCMWGS_ATTR_NETWORK_CELL_CIRCUIT_SWITCHED_EARLY_CLASSMARK_SENDING  RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSCMWGS_ATTR_NETWORK_CELL_CIRCUIT_SWITCHED_ENHANCED_MEASUREMENT_REPORT RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_PDP_CONTEXT_ACTIVATION    RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_SIGNAL_LEVEL_FILTER_PERIOD RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_BEP_PERIOD                RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_PC_MEAS_CHANNEL           RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_CONECTIONS_ENABLE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_QUALITY_RXLEVMIN_ACCESS       RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_HYSTERESIS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 233
#define RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_QUALITY_RXLEVMIN_EUTRAN       RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_QUALITY_RXLEVMIN_UTRAN        RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_TRESELECTION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSCMWGS_ATTR_NETWORK_CELL_IMSI_FILTER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 310
#define RSCMWGS_ATTR_NETWORK_CELL_SUPPORT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 311
#define RSCMWGS_ATTR_NETWORK_RADIOLINK_TIMEOUT_MS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWGS_ATTR_NETWORK_RADIOLINK_TIMEOUT_BS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWGS_ATTR_NETWORK_TIMER_T3212                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSCMWGS_ATTR_NETWORK_TIMER_T3312                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSCMWGS_ATTR_NETWORK_ALERTING_TIMEOUT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSCMWGS_ATTR_NETWORK_MOC_ALERTING_TIMEOUT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSCMWGS_ATTR_NETWORK_TIMER_T3122                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSCMWGS_ATTR_NETWORK_TIMER_T3142                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSCMWGS_ATTR_NETWORK_RELEASE_TIMER_T3192                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_LOCATION_UPDATE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_GMM_ATTACH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_GMM_ROUTING_AREA                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_CM_SERVICE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 312
#define RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_CM_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSCMWGS_ATTR_NETWORK_TIME_SOURCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSCMWGS_ATTR_NETWORK_TIME_DST_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSCMWGS_ATTR_NETWORK_TIME_DST_SHIFT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSCMWGS_ATTR_NETWORK_TIME_TRANSFER_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSCMWGS_ATTR_NETWORK_TIME_TRANSFER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSCMWGS_ATTR_NETWORK_TIME_LOCAL_TIME_ZONE_OFFSET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSCMWGS_ATTR_NETWORK_TIME_SEND_NETWORK_NAME                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSCMWGS_ATTR_NEIGHBOR_CELL_THRESHOLD_LTE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSCMWGS_ATTR_NEIGHBOR_CELL_THRESHOLD_WCDMA                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSCMWGS_ATTR_NEIGHBOR_CELL_THRESHOLD_TDSCDMA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSCMWGS_ATTR_NETWORK_CELL_SYNCHRONIZATION_OFFSET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSCMWGS_ATTR_NETWORK_CELL_SYNCHRONIZATION_ZONE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSCMWGS_ATTR_CONNECTION_MS_POWER_CHANGE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSCMWGS_ATTR_CONNECTION_FREQUENCY_OFFSET_DOWNLINK                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSCMWGS_ATTR_CONNECTION_FREQUENCY_OFFSET_UPLINK                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSCMWGS_ATTR_CONNECTION_RANDOM_FREQUENCY_OFFSET_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSCMWGS_ATTR_CONNECTION_TIMING_ADVANCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSCMWGS_ATTR_CONNECTION_TIMESLOT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSCMWGS_ATTR_CONNECTION_TRAFFIC_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSCMWGS_ATTR_CONNECTION_HALF_RATE_SUBCHANNEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSCMWGS_ATTR_CONNECTION_DATA_SOURCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSCMWGS_ATTR_CONNECTION_CALL_RELEASE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSCMWGS_ATTR_CONNECTION_LOOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSCMWGS_ATTR_CONNECTION_LOOP_RECLOSE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSCMWGS_ATTR_CONNECTION_CALLER_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSCMWGS_ATTR_CONNECTION_TCH_ASSIGNMENT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSCMWGS_ATTR_CONNECTION_ECHO_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSCMWGS_ATTR_CONNECTION_TRAFFIC_CHANNEL_STATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSCMWGS_ATTR_CONNECTION_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSCMWGS_ATTR_CONNECTION_ATTEMPT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSCMWGS_ATTR_CONNECTION_REJECT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSCMWGS_ATTR_CONNECTION_ATTEMPT_QUERY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSCMWGS_ATTR_CONNECTION_REJECT_QUERY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSCMWGS_ATTR_CONNECTION_AMR_CODEC_MODE_DOWNLINK                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSCMWGS_ATTR_CONNECTION_AMR_CODEC_MODE_UPLINK                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSCMWGS_ATTR_CONNECTION_MS_CODEC_MODE_DOWNLINK                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSCMWGS_ATTR_CONNECTION_MS_CODEC_MODE_UPLINK                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSCMWGS_ATTR_CONNECTION_AMR_8PSK_CODEC_MODE_DOWNLINK                RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSCMWGS_ATTR_CONNECTION_AMR_8PSK_CODEC_MODE_UPLINK                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSCMWGS_ATTR_CONNECTION_MS_8PSK_CODEC_MODE_DOWNLINK                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSCMWGS_ATTR_CONNECTION_MS_8PSK_CODEC_MODE_UPLINK                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSCMWGS_ATTR_CONNECTION_AMR_SIGNALING_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSCMWGS_ATTR_CONNECTION_VAMOS_ENABLE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSCMWGS_ATTR_CONNECTION_VAMOS_MOBILE_SUPPORT_LEVEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_AUTO_SLOT_CONFIG_ENABLED    RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_AUTO_DUAL_TRANSFER_MODE     RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_SERVICE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_TESTMODE_B_ACK              RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_TESTMODE_RF_LEVEL           RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_TESTMODE_S_SRB_INFO         RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_BLER_POLLING_BLOCKS         RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DATA_SOURCE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_TBF_LEVEL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_CODING_SCHEME_UPLINK        RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_INCREMENTAL_REDUNDANCY_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_EXTENDED_DYNAMIC_ALLOCATION RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_NUMBER_OF_PROTOCOL_DATA_UNITS RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_SLOT_OFFSET                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_CONTROL_ACK_TYPE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DOWNLINK_DUALCARRIER        RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_BEP_PERIOD_2                RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_BCS_DATA_CORRUPTION_RATE    RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DOWNLINK_POWER_CONTROL_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DOWNLINK_POWER_CONTROL_P0   RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_POWER_REDUCTION_MODE        RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_POWER_REDUCTION_FIELD       RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_ALWAYS_SEND_RLC_DATA_BLOCKS RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_BLOCK_ENCODING              RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_USF_MODE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_STATE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_DOWNLINK_EVENT_BASED   RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_DOWNLINK_POLLED        RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_UPLINK_MODE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_UPLINK_TIMESHIFT       RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_MAX_DOWNLINK_THROUGHPUT     RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_MAX_UPLINK_THROUGHPUT       RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_ERROR                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_NW_EXT_UTBF                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_EXT_UTBF_NODATA             RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSCMWGS_ATTR_HANDOVER_DESTINATION_BAND                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSCMWGS_ATTR_HANDOVER_DESTINATION_CHANNEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSCMWGS_ATTR_HANDOVER_DESTINATION_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSCMWGS_ATTR_HANDOVER_DESTINATION_PCL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSCMWGS_ATTR_HANDOVER_DESTINATION_TIMESLOT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSCMWGS_ATTR_HANDOVER_UPLINK_CODING_SCHEME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSCMWGS_ATTR_HANDOVER_BAND                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSCMWGS_ATTR_HANDOVER_INITIATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSCMWGS_ATTR_SIGNALING_HANDOVER_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSCMWGS_ATTR_HANDOVER_DESTINATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSCMWGS_ATTR_HANDOVER_EXTERNAL_DESTINATION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 269
#define RSCMWGS_ATTR_HANDOVER_DUALBAND_TCH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSCMWGS_ATTR_HANDOVER_MOBILITY_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_TEXT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_DOMAIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_DATA_CODING                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_CODING_GROUP                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_CLASS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_ORIGINATOR_SMSC_ADDRESS           RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_ORIGINATING_ADDRESS               RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSCMWGS_ATTR_SMS_OUTGOING_SERVICE_TIME_SOURCE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSCMWGS_ATTR_SMS_OUTGOING_LAST_MESSAGE_SENT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSCMWGS_ATTR_SMS_OUTGOING_USER_DATA_HEADER_STATE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 323
#define RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_TEXT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_READ_FLAG                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_LENGTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_RESET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSCMWGS_ATTR_SMS_INCOMMING_MESSAGE_DATA_CODING                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSCMWGS_ATTR_CBS_GENERALLY_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 287
#define RSCMWGS_ATTR_CBS_MESSAGE_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 288
#define RSCMWGS_ATTR_CBS_MESSAGE_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 289
#define RSCMWGS_ATTR_CBS_MESSAGE_ID_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSCMWGS_ATTR_CBS_MESSAGE_DATA_CODE_SCHEME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 291
#define RSCMWGS_ATTR_CBS_MESSAGE_CATEGORY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 292
#define RSCMWGS_ATTR_CBS_MESSAGE_DATA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 293
#define RSCMWGS_ATTR_CBS_MESSAGE_PERIOD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSCMWGS_ATTR_CBS_DRX_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 295
#define RSCMWGS_ATTR_CBS_DRX_LENGTH_OF_PERIOD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 296
#define RSCMWGS_ATTR_CBS_DRX_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define RSCMWGS_ATTR_TRIGGER_FRAME_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSCMWGS_ATTR_MEASUREMENT_SLOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_STOP_CONDITION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_STATISTIC_COUNT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_CLASS_II_BITS               RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_CLASS_IB_BITS               RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_FER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_FER_FACCH                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_FER_SACCH                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_INIT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_ABORT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_STOP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_BER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_MODE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_TIMEOUT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_ROUND_TRIP_DELAY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_STOP_CONDITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_STATISTIC_COUNT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_LIMIT_CLASS_II_BITS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_LIMIT_DBLER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_LIMIT_USF_BLER                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_INIT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_ABORT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_STOP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_TIMEOUT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSCMWGS_ATTR_BER_PACKET_SWITCHED_MEASUREMENT_MODE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSCMWGS_ATTR_BLER_STATISTIC_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSCMWGS_ATTR_BLER_INIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSCMWGS_ATTR_BLER_ABORT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSCMWGS_ATTR_BLER_STOP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSCMWGS_ATTR_BLER_TIMEOUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSCMWGS_ATTR_RLC_THROUGHPUT_INIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSCMWGS_ATTR_RLC_THROUGHPUT_ABORT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSCMWGS_ATTR_RLC_THROUGHPUT_STOP                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSCMWGS_ATTR_RLC_THROUGHPUT_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSCMWGS_ATTR_RLC_THROUGHPUT_TIMEOUT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSCMWGS_ATTR_RLC_THROUGHPUT_REPETITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSCMWGS_ATTR_RLC_THROUGHPUT_WINDOW                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSCMWGS_ATTR_CMR_PERFORMANCE_INIT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSCMWGS_ATTR_CMR_PERFORMANCE_ABORT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSCMWGS_ATTR_CMR_PERFORMANCE_STOP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSCMWGS_ATTR_CMR_PERFORMANCE_TARGET_LEVEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSCMWGS_ATTR_CMR_PERFORMANCE_TIMEOUT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSCMWGS_ATTR_MEASUREMENT_REPORT_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSCMWGS_ATTR_MEASUREMENT_REPORT_WCDMA_QUANTITY                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSCMWGS_ATTR_MEASUREMENT_REPORT_LTE_QUANTITY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSCMWGS_ATTR_MESSAGE_MONITORING_ADD_GSM_SIGNALING_TO_LOGGING        RS_SPECIFIC_PUBLIC_ATTR_BASE + 308
#define RSCMWGS_ATTR_MESSAGE_MONITORING_LOGGING_PC_IPV4_ADDRESS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 309
#define RSCMWGS_ATTR_SYSTEM_VERSION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSCMWGS_ATTR_SYSTEM_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSCMWGS_ATTR_SYSTEM_ALL_ERRORS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSCMWGS_ATTR_SYSTEM_PRESET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSCMWGS_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSCMWGS_ATTR_ID_QUERY_RESPONSE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 144

// rscmwgs_rngBand
#define RSCMWGS_VAL_BAND_G085                                               0
#define RSCMWGS_VAL_BAND_G09                                                1
#define RSCMWGS_VAL_BAND_G18                                                2
#define RSCMWGS_VAL_BAND_G19                                                3

// rscmwgs_rngConnectState
#define RSCMWGS_VAL_CONNECT                                                 0
#define RSCMWGS_VAL_DISCONNECT                                              1
#define RSCMWGS_VAL_SMS                                                     2
#define RSCMWGS_VAL_RPC                                                     3
#define RSCMWGS_VAL_HAND                                                    6

// rscmwgs_rngConnectionState
#define RSCMWGS_VAL_CONNECTION_STATE_SOFF                                   0
#define RSCMWGS_VAL_CONNECTION_STATE_SON                                    1
#define RSCMWGS_VAL_CONNECTION_STATE_SYNC                                   2
#define RSCMWGS_VAL_CONNECTION_STATE_ALERT                                  3
#define RSCMWGS_VAL_CONNECTION_STATE_CALLE                                  4
#define RSCMWGS_VAL_CONNECTION_STATE_LOCU                                   5
#define RSCMWGS_VAL_CONNECTION_STATE_CONN                                   6
#define RSCMWGS_VAL_CONNECTION_STATE_RELEASE                                7
#define RSCMWGS_VAL_CONNECTION_STATE_IMSI                                   8
#define RSCMWGS_VAL_CONNECTION_STATE_RRH                                    9
#define RSCMWGS_VAL_CONNECTION_STATE_SMES                                   10
#define RSCMWGS_VAL_CONNECTION_STATE_RMES                                   11
#define RSCMWGS_VAL_CONNECTION_STATE_IHAN                                   12
#define RSCMWGS_VAL_CONNECTION_STATE_OHAN                                   13

// rscmwgs_rngBERStopCondition
#define RSCMWGS_VAL_STOP_CONDITION_NONE                                     0
#define RSCMWGS_VAL_STOP_CONDITION_FLIM                                     1

// rscmwgs_rngIdentityMNCDigits
#define RSCMWGS_VAL_MNC_DIGITS_2                                            2
#define RSCMWGS_VAL_MNC_DIGITS_3                                            3

// rscmwgs_rngConnectionTraffic
#define RSCMWGS_VAL_TRAFFIC_MODE_FV1                                        0
#define RSCMWGS_VAL_TRAFFIC_MODE_FV2                                        1
#define RSCMWGS_VAL_TRAFFIC_MODE_HV1                                        2
#define RSCMWGS_VAL_TRAFFIC_MODE_ANFG                                       3
#define RSCMWGS_VAL_TRAFFIC_MODE_ANHG                                       4
#define RSCMWGS_VAL_TRAFFIC_MODE_ANH8                                       5
#define RSCMWGS_VAL_TRAFFIC_MODE_AWFG                                       6
#define RSCMWGS_VAL_TRAFFIC_MODE_AWF8                                       7
#define RSCMWGS_VAL_TRAFFIC_MODE_AWH8                                       8

// rscmwgs_rngConnectionDataSource
#define RSCMWGS_VAL_DATA_SOURCE_ECHO                                        0
#define RSCMWGS_VAL_DATA_SOURCE_PR9                                         1
#define RSCMWGS_VAL_DATA_SOURCE_PR11                                        2
#define RSCMWGS_VAL_DATA_SOURCE_PR15                                        3
#define RSCMWGS_VAL_DATA_SOURCE_PR16                                        4
#define RSCMWGS_VAL_DATA_SOURCE_SP1                                         11

// rscmwgs_rngConnectionLoop
#define RSCMWGS_VAL_LOOP_OFF                                                0
#define RSCMWGS_VAL_LOOP_A                                                  1
#define RSCMWGS_VAL_LOOP_B                                                  2
#define RSCMWGS_VAL_LOOP_C                                                  3
#define RSCMWGS_VAL_LOOP_D                                                  4
#define RSCMWGS_VAL_LOOP_I                                                  5
#define RSCMWGS_VAL_LOOP_ON                                                 6

// rscmwgs_rngNetworkCellLocUpdate
#define RSCMWGS_VAL_CELL_UPDATE_ALWAYS                                      0
#define RSCMWGS_VAL_CELL_UPDATE_AUTO                                        1

// rscmwgs_rngSignPackSwConnStat
#define RSCMWGS_VAL_CONNECTION_STATE_ATT                                    2
#define RSCMWGS_VAL_CONNECTION_STATE_TBF                                    3
#define RSCMWGS_VAL_CONNECTION_STATE_RAU                                    4
#define RSCMWGS_VAL_CONNECTION_STATE_PDB                                    5
#define RSCMWGS_VAL_CONNECTION_STATE_PDPD                                   8
#define RSCMWGS_VAL_CONNECTION_STATE_DET                                    9
#define RSCMWGS_VAL_CONNECTION_STATE_AIPR                                   10
#define RSCMWGS_VAL_CONNECTION_STATE_PAIP                                   11
#define RSCMWGS_VAL_CONNECTION_STATE_PDIP                                   12

// rscmwgs_rngNetwCellPDPContext
#define RSCMWGS_VAL_CELL_PDP_CONTEXT_REJ                                    0
#define RSCMWGS_VAL_CELL_PDP_CONTEXT_ACC                                    1

// rscmwgs_rngCellPCMeasCh
#define RSCMWGS_VAL_CELL_PC_MEAS_CHANNEL_BCCH                               0
#define RSCMWGS_VAL_CELL_PC_MEAS_CHANNEL_PDCH                               1

// rscmwgs_rngConnTCHAssign
#define RSCMWGS_VAL_TCH_ASSIGNMENT_OFF                                      0
#define RSCMWGS_VAL_TCH_ASSIGNMENT_VEAR                                     1
#define RSCMWGS_VAL_TCH_ASSIGNMENT_EARL                                     2
#define RSCMWGS_VAL_TCH_ASSIGNMENT_LATE                                     3
#define RSCMWGS_VAL_TCH_ASSIGNMENT_ON                                       4

// rscmwgs_rngConnMSPow
#define RSCMWGS_VAL_MS_POWER_CHANGE_OFF                                     0
#define RSCMWGS_VAL_MS_POWER_CHANGE_FAST                                    1
#define RSCMWGS_VAL_MS_POWER_CHANGE_SLOW                                    2

// rscmwgs_rngConnPackSWServ
#define RSCMWGS_VAL_CONN_PSW_SERV_TMA                                       0
#define RSCMWGS_VAL_CONN_PSW_SERV_TMB                                       1
#define RSCMWGS_VAL_CONN_PSW_SERV_BLER                                      2
#define RSCMWGS_VAL_CONN_PSW_SERV_SRB                                       3

// rscmwgs_rngConnPackDataSour
#define RSCMWGS_VAL_DATA_SOURCE_LOOP                                        5
#define RSCMWGS_VAL_DATA_SOURCE_ALL0                                        6
#define RSCMWGS_VAL_DATA_SOURCE_ALL1                                        7
#define RSCMWGS_VAL_DATA_SOURCE_ALT                                         8
#define RSCMWGS_VAL_DATA_SOURCE_SPE                                         9
#define RSCMWGS_VAL_DATA_SOURCE_UPAT                                        10

// rscmwgs_rngConnPackSwUplinkCodScheme
#define RSCMWGS_VAL_CODING_SCHEME_C1                                        0
#define RSCMWGS_VAL_CODING_SCHEME_C2                                        1
#define RSCMWGS_VAL_CODING_SCHEME_C3                                        2
#define RSCMWGS_VAL_CODING_SCHEME_C4                                        3
#define RSCMWGS_VAL_CODING_SCHEME_MC1                                       4
#define RSCMWGS_VAL_CODING_SCHEME_MC2                                       5
#define RSCMWGS_VAL_CODING_SCHEME_MC3                                       6
#define RSCMWGS_VAL_CODING_SCHEME_MC4                                       7
#define RSCMWGS_VAL_CODING_SCHEME_MC5                                       8
#define RSCMWGS_VAL_CODING_SCHEME_MC6                                       9
#define RSCMWGS_VAL_CODING_SCHEME_MC7                                       10
#define RSCMWGS_VAL_CODING_SCHEME_MC8                                       11
#define RSCMWGS_VAL_CODING_SCHEME_MC9                                       12
#define RSCMWGS_VAL_CODING_SCHEME_UA7                                       13
#define RSCMWGS_VAL_CODING_SCHEME_UA8                                       14
#define RSCMWGS_VAL_CODING_SCHEME_UA9                                       15
#define RSCMWGS_VAL_CODING_SCHEME_UA10                                      16
#define RSCMWGS_VAL_CODING_SCHEME_UA11                                      17

// rscmwgs_rngExtDynAlloc
#define RSCMWGS_VAL_OFF                                                     0
#define RSCMWGS_VAL_ON                                                      1
#define RSCMWGS_VAL_AUTO                                                    2

// rscmwgs_rngCntrlACKType
#define RSCMWGS_VAL_CONN_PSW_ACK_TYPE_NBUR                                  0
#define RSCMWGS_VAL_CONN_PSW_ACK_TYPE_ABUR                                  1

// rscmwgs_rngConnBlockEncoding
#define RSCMWGS_VAL_CONN_PSW_BLOCK_ENCODING_RTTI                            0
#define RSCMWGS_VAL_CONN_PSW_BLOCK_ENCODING_BTTI                            1

// rscmwgs_rngHandoverState
#define RSCMWGS_VAL_HANDOVER_STATE_OFF                                      0
#define RSCMWGS_VAL_HANDOVER_STATE_DUAL                                     1

// rscmwgs_rngTrgFramMode
#define RSCMWGS_VAL_TRIGGER_FRAME_MODE_EVERY                                0
#define RSCMWGS_VAL_TRIGGER_FRAME_MODE_EWIDLE                               1
#define RSCMWGS_VAL_TRIGGER_FRAME_MODE_M26                                  2
#define RSCMWGS_VAL_TRIGGER_FRAME_MODE_M52                                  3
#define RSCMWGS_VAL_TRIGGER_FRAME_MODE_M104                                 4

// rscmwgs_rngUSFMode
#define RSCMWGS_VAL_CONN_PSW_USF_MODE_RC1                                   0
#define RSCMWGS_VAL_CONN_PSW_USF_MODE_RMC0                                  1
#define RSCMWGS_VAL_CONN_PSW_USF_MODE_BMC0                                  2

// rscmwgs_rngFANRUplinkMode
#define RSCMWGS_VAL_CONN_PSW_FANR_UPLINK_MODE_SSN                           0
#define RSCMWGS_VAL_CONN_PSW_FANR_UPLINK_MODE_TIME                          1

// rscmwgs_rngTBFLevel
#define RSCMWGS_VAL_CONN_PSW_TBF_LEVEL_EGPR                                 0
#define RSCMWGS_VAL_CONN_PSW_TBF_LEVEL_EG2A                                 1
#define RSCMWGS_VAL_CONN_PSW_TBF_LEVEL_GPRS                                 2

// rscmwgs_rngBERMeasMode
#define RSCMWGS_VAL_MEAS_BBBURST                                            0
#define RSCMWGS_VAL_MEAS_BER                                                1
#define RSCMWGS_VAL_MEAS_RFER                                               2
#define RSCMWGS_VAL_MEAS_FFAC                                               3
#define RSCMWGS_VAL_MEAS_FSAC                                               4
#define RSCMWGS_VAL_MEAS_RUFR                                               5
#define RSCMWGS_VAL_MEAS_AIF                                                6
#define RSCMWGS_VAL_MEAS_MBEP                                               7
#define RSCMWGS_VAL_MEAS_SQU                                                8
#define RSCMWGS_VAL_MEAS_BFI                                                9

// rscmwgs_rngPowerMode
#define RSCMWGS_VAL_MAN                                                     0
#define RSCMWGS_VAL_ULPC                                                    1

// rscmwgs_rngVAMOSMobileLevels
#define RSCMWGS_VAL_SUPPORT_LEVEL_VAMOS_I                                   1
#define RSCMWGS_VAL_SUPPORT_LEVEL_VAMOS_II                                  2
#define RSCMWGS_VAL_SUPPORT_LEVEL_VAMOS_AUTO                                3

// rscmwgs_rngHandoverCodingScheme
#define RSCMWGS_VAL_CODING_SCHEME_ON                                        18
#define RSCMWGS_VAL_CODING_SCHEME_OFF                                       19

// rscmwgs_rngNetworkTimeSource
#define RSCMWGS_VAL_TIME_SOURCE_OS                                          0
#define RSCMWGS_VAL_TIME_SOURCE_USER                                        1

// rscmwgs_rngTimeDSTShift
#define RSCMWGS_VAL_DST_1H                                                  1
#define RSCMWGS_VAL_DST_2H                                                  2

// rscmwgs_rngFadingSimulatorStandard
#define RSCMWGS_VAL_FSIM_STANDARD_T3                                        0
#define RSCMWGS_VAL_FSIM_STANDARD_T50                                       1
#define RSCMWGS_VAL_FSIM_STANDARD_T6                                        2
#define RSCMWGS_VAL_FSIM_STANDARD_T100                                      3
#define RSCMWGS_VAL_FSIM_STANDARD_T3P6                                      4
#define RSCMWGS_VAL_FSIM_STANDARD_T60                                       5
#define RSCMWGS_VAL_FSIM_STANDARD_T1P5                                      6
#define RSCMWGS_VAL_FSIM_STANDARD_H100                                      7
#define RSCMWGS_VAL_FSIM_STANDARD_H200                                      8
#define RSCMWGS_VAL_FSIM_STANDARD_H120                                      9
#define RSCMWGS_VAL_FSIM_STANDARD_R250                                      10
#define RSCMWGS_VAL_FSIM_STANDARD_R500                                      11
#define RSCMWGS_VAL_FSIM_STANDARD_R300                                      12
#define RSCMWGS_VAL_FSIM_STANDARD_R130                                      13
#define RSCMWGS_VAL_FSIM_STANDARD_E50                                       14
#define RSCMWGS_VAL_FSIM_STANDARD_E100                                      15
#define RSCMWGS_VAL_FSIM_STANDARD_E60                                       16
#define RSCMWGS_VAL_FSIM_STANDARD_TI5                                       17
#define RSCMWGS_VAL_FSIM_STANDARD_T25                                       18
#define RSCMWGS_VAL_FSIM_STANDARD_TU1P5                                     19
#define RSCMWGS_VAL_FSIM_STANDARD_TU3                                       20
#define RSCMWGS_VAL_FSIM_STANDARD_TU25                                      21
#define RSCMWGS_VAL_FSIM_STANDARD_TU50                                      22
#define RSCMWGS_VAL_FSIM_STANDARD_HT100                                     23

// rscmwgs_rngFSimInsertionLossMode
#define RSCMWGS_VAL_ILOSS_MODE_NORMAL                                       0
#define RSCMWGS_VAL_ILOSS_MODE_USER                                         1

// rscmwgs_rngFadingSimulatorDopplerFrequencyMode
#define RSCMWGS_VAL_DOPPLER_FREQUENCY_MODE_NORMAL                           0
#define RSCMWGS_VAL_DOPPLER_FREQUENCY_MODE_USER                             1

// rscmwgs_rngSMSOutgoingMessageDomain
#define RSCMW_VAL_SMS_DOMAIN_AUTO                                           0
#define RSCMW_VAL_SMS_DOMAIN_CS                                             1
#define RSCMW_VAL_SMS_DOMAIN_PS                                             2

// rscmwgs_rngSMSIncomingMessageDataCoding
#define RSCMW_VAL_SMS_DATA_CODING_BIT7                                      0
#define RSCMW_VAL_SMS_DATA_CODING_BIT8                                      1
#define RSCMW_VAL_SMS_DATA_CODING_NAV                                       2

// rscmwgs_rngSMSOutgoingMessageCodingGroup
#define RSCMW_VAL_SMS_CODING_GROUP_GDC                                      0
#define RSCMW_VAL_SMS_CODING_GROUP_DCMC                                     1

// rscmwgs_rngSMSOutgoingMessageClass
#define RSCMW_VAL_SMS_MESSAGE_CLASS_CL0                                     0
#define RSCMW_VAL_SMS_MESSAGE_CLASS_CL1                                     1
#define RSCMW_VAL_SMS_MESSAGE_CLASS_CL2                                     2
#define RSCMW_VAL_SMS_MESSAGE_CLASS_CL3                                     3
#define RSCMW_VAL_SMS_MESSAGE_CLASS_NONE                                    4

// rscmwgs_rngMeasurementState
#define RSCMWGS_VAL_MEAS_STATE_OFF                                          0
#define RSCMWGS_VAL_MEAS_STATE_RDY                                          1
#define RSCMWGS_VAL_MEAS_STATE_RUN                                          2

// rscmwgs_rngRLCThroughputRepetition
#define RSCMWGS_VAL_RLC_REP_SINGLE                                          0
#define RSCMWGS_VAL_RLC_REP_CONT                                            1

// rscmwgs_rngSMSOutgoingMessageDataCoding
#define RSCMW_VAL_SMS_OUT_DATA_CODING_BIT7                                  0
#define RSCMW_VAL_SMS_OUT_DATA_CODING_BIT8                                  1

// rscmwgs_rngBERPacketSwitchedMeasurementMode
#define RSCMWGS_VAL_MMODE_BERDBLER                                          0
#define RSCMWGS_VAL_MMODE_MEAN_BEP                                          1
#define RSCMWGS_VAL_MMODE_UB_ONLY                                           2

// rscmwgs_rngNetworkCellPageMode
#define RSCMWGS_VAL_PAGE_MODE_NORMAL                                        0
#define RSCMWGS_VAL_PAGE_MODE_REORG                                         1

// rscmwgs_rngNetworkCellPagingWithMSIdentity
#define RSCMWGS_VAL_PMI_IMSI                                                0
#define RSCMWGS_VAL_PMI_TMSI                                                1

// rscmwgs_rngNetworkCellSynchronizationZone
#define RSCMWGS_VAL_SYNC_NONE                                               0
#define RSCMWGS_VAL_SYNC_Z1                                                 1

// rscmwgs_rngConnectionCallRelease
#define RSCMWGS_VAL_CALL_RELEASE_NORMAL                                     0
#define RSCMWGS_VAL_CALL_RELEASE_IMMEDIATE                                  1
#define RSCMWGS_VAL_CALL_RELEASE_LOCAL                                      2

// rscmwgs_rngConnectionPacketSwitchedDownlinkPowerControlP0
#define RSCMWGS_VAL_DPC_P_0DB                                               0
#define RSCMWGS_VAL_DPC_P_2DB                                               2
#define RSCMWGS_VAL_DPC_P_4DB                                               4
#define RSCMWGS_VAL_DPC_P_6DB                                               6
#define RSCMWGS_VAL_DPC_P_8DB                                               8
#define RSCMWGS_VAL_DPC_P_10DB                                              10
#define RSCMWGS_VAL_DPC_P_12DB                                              12
#define RSCMWGS_VAL_DPC_P_14DB                                              14
#define RSCMWGS_VAL_DPC_P_16DB                                              16
#define RSCMWGS_VAL_DPC_P_18DB                                              18
#define RSCMWGS_VAL_DPC_P_20DB                                              20
#define RSCMWGS_VAL_DPC_P_22DB                                              22
#define RSCMWGS_VAL_DPC_P_24DB                                              24
#define RSCMWGS_VAL_DPC_P_26DB                                              26
#define RSCMWGS_VAL_DPC_P_28DB                                              28
#define RSCMWGS_VAL_DPC_P_30DB                                              30

// rscmwgs_rngConnectionPacketSwitchedPRMode
#define RSCMWGS_VAL_PR_MODE_A                                               0
#define RSCMWGS_VAL_PR_MODE_B                                               1

// rscmwgs_rngConnectioonPacketSwitchingPowerReductionField
#define RSCMWGS_VAL_PR_FIELD_DB0                                            0
#define RSCMWGS_VAL_PR_FIELD_DB3                                            1
#define RSCMWGS_VAL_PR_FIELD_DB7                                            2
#define RSCMWGS_VAL_PR_FIELD_NOT_USABLE                                     3

// rscmwgs_rngConnectionError
#define RSCMWGS_VAL_CONNECTION_ERROR_NO_ERROR                               0
#define RSCMWGS_VAL_CONNECTION_ERROR_REJECTED                               1
#define RSCMWGS_VAL_CONNECTION_ERROR_RADIO_LINK_TIMEOUT                     2
#define RSCMWGS_VAL_CONNECTION_ERROR_PAGING_TIMEOUT                         3
#define RSCMWGS_VAL_CONNECTION_ERROR_SIGNALING_TIMEOUT                      4
#define RSCMWGS_VAL_CONNECTION_ERROR_IGNORED                                5
#define RSCMWGS_VAL_CONNECTION_ERROR_ALTERING_TIMEOUT                       6

// rscmwgs_rngMobileCapabilitiesRXPower
#define RSCMWGS_VAL_RX_POWER_IN_RANGE                                       0
#define RSCMWGS_VAL_RX_POWER_UNDERFLOW                                      1
#define RSCMWGS_VAL_RX_POWER_OVERFLOW                                       2
#define RSCMWGS_VAL_RX_POWER_NAV                                            -1

// rscmwgs_rngNetworkRejectCauses
#define RSCMWGS_VAL_REJECT_CAUSE_C2                                         2
#define RSCMWGS_VAL_REJECT_CAUSE_C3                                         3
#define RSCMWGS_VAL_REJECT_CAUSE_C4                                         4
#define RSCMWGS_VAL_REJECT_CAUSE_C5                                         5
#define RSCMWGS_VAL_REJECT_CAUSE_C6                                         6
#define RSCMWGS_VAL_REJECT_CAUSE_C11                                        7
#define RSCMWGS_VAL_REJECT_CAUSE_C12                                        8
#define RSCMWGS_VAL_REJECT_CAUSE_C13                                        9
#define RSCMWGS_VAL_REJECT_CAUSE_C15                                        10
#define RSCMWGS_VAL_REJECT_CAUSE_C17                                        11
#define RSCMWGS_VAL_REJECT_CAUSE_C20                                        12
#define RSCMWGS_VAL_REJECT_CAUSE_C21                                        13
#define RSCMWGS_VAL_REJECT_CAUSE_C22                                        14
#define RSCMWGS_VAL_REJECT_CAUSE_C23                                        15
#define RSCMWGS_VAL_REJECT_CAUSE_C25                                        16
#define RSCMWGS_VAL_REJECT_CAUSE_C32                                        17
#define RSCMWGS_VAL_REJECT_CAUSE_C33                                        18
#define RSCMWGS_VAL_REJECT_CAUSE_C34                                        19
#define RSCMWGS_VAL_REJECT_CAUSE_C38                                        20
#define RSCMWGS_VAL_REJECT_CAUSE_C48                                        21
#define RSCMWGS_VAL_REJECT_CAUSE_C95                                        22
#define RSCMWGS_VAL_REJECT_CAUSE_C96                                        23
#define RSCMWGS_VAL_REJECT_CAUSE_C97                                        24
#define RSCMWGS_VAL_REJECT_CAUSE_C98                                        25
#define RSCMWGS_VAL_REJECT_CAUSE_C99                                        26
#define RSCMWGS_VAL_REJECT_CAUSE_C100                                       27
#define RSCMWGS_VAL_REJECT_CAUSE_C101                                       28
#define RSCMWGS_VAL_REJECT_CAUSE_C111                                       29
#define RSCMWGS_VAL_REJECT_CAUSE_C7                                         30
#define RSCMWGS_VAL_REJECT_CAUSE_C8                                         31
#define RSCMWGS_VAL_REJECT_CAUSE_C9                                         32
#define RSCMWGS_VAL_REJECT_CAUSE_C14                                        33
#define RSCMWGS_VAL_REJECT_CAUSE_C16                                        34
#define RSCMWGS_VAL_REJECT_CAUSE_C10                                        35
#define RSCMWGS_VAL_REJECT_CAUSE_C28                                        36
#define RSCMWGS_VAL_REJECT_CAUSE_C40                                        37

// rscmwgs_rngHandoverExternalDestination
#define RSCMWGS_VAL_HANDOVER_DESTINATION_EXT_LTE                            0
#define RSCMWGS_VAL_HANDOVER_DESTINATION_EXT_GSM                            1
#define RSCMWGS_VAL_HANDOVER_DESTINATION_EXT_WCDMA                          2
#define RSCMWGS_VAL_HANDOVER_DESTINATION_EXT_TDSCDMA                        3

// rscmwgs_rngWCDMAQuantity
#define RSCMWGS_VAL_MEAS_REPORT_WCDMA_RSCP                                  0
#define RSCMWGS_VAL_MEAS_REPORT_WCDMA_ECNO                                  1

// rscmwgs_rngLTEQuantity
#define RSCMWGS_VAL_MEAS_REPORT_LTE_RSRP                                    0
#define RSCMWGS_VAL_MEAS_REPORT_LTE_RSRQ                                    1

// rscmwgs_rngCBSMessageIDType
#define RSCMWGS_VAL_CBS_ID_TYPE_UDEF                                        0
#define RSCMWGS_VAL_CBS_ID_TYPE_APR                                         1
#define RSCMWGS_VAL_CBS_ID_TYPE_AEXT                                        2
#define RSCMWGS_VAL_CBS_ID_TYPE_ASEV                                        3
#define RSCMWGS_VAL_CBS_ID_TYPE_AAMB                                        4

// rscmwgs_rngCBSMessageCategory
#define RSCMWGS_VAL_CBS_MESSAGE_CATEGORY_BACK                               0
#define RSCMWGS_VAL_CBS_MESSAGE_CATEGORY_NORM                               1
#define RSCMWGS_VAL_CBS_MESSAGE_CATEGORY_HIGH                               2

// rscmwgs_rngSMSOutgoingLastMessageSent
#define RSCMWGS_VAL_SMS_LMS_SUCC                                            0
#define RSCMWGS_VAL_SMS_LMS_FAIL                                            1

// rscmwgs_rngAMRSignalingMode
#define RSCMWGS_VAL_AMR_SIGNALING_MODE_LTRR                                 0
#define RSCMWGS_VAL_AMR_SIGNALING_MODE_RATSCCH                              1

// rscmwgs_rngMobilityMode
#define RSCMWGS_VAL_MOBILITY_REDIRECTION                                    0
#define RSCMWGS_VAL_MOBILITY_HANDOVER                                       1
#define RSCMWGS_VAL_MOBILITY_CCORDER                                        2

// rscmwgs_rngSIMCardType
#define RSCMWGS_VAL_SIM_C3G                                                 0
#define RSCMWGS_VAL_SIM_C2G                                                 1

// rscmwgs_rngMessageMonitoringLoggingPCIPv4Address
#define RSCMWGS_VAL_LOGGING_IP1                                             1
#define RSCMWGS_VAL_LOGGING_IP2                                             2
#define RSCMWGS_VAL_LOGGING_IP3                                             3

// rscmwgs_rngNetworkCellSupport
#define RSCMWGS_VAL_NETWORK_SUPPORT_GPRS                                    0
#define RSCMWGS_VAL_NETWORK_SUPPORT_EGPRS                                   1

// rscmwgs_rngNetworkRejectCausesCMType
#define RSCMWGS_VAL_REJECT_CAUSES_CM_TYPE_NESM                              0
#define RSCMWGS_VAL_REJECT_CAUSES_CM_TYPE_NCEC                              1
#define RSCMWGS_VAL_REJECT_CAUSES_CM_TYPE_NCSM                              2
#define RSCMWGS_VAL_REJECT_CAUSES_CM_TYPE_ECSM                              3
#define RSCMWGS_VAL_REJECT_CAUSES_CM_TYPE_NCAL                              4
#define RSCMWGS_VAL_REJECT_CAUSES_CM_TYPE_ECAL                              5
#define RSCMWGS_VAL_REJECT_CAUSES_CM_TYPE_SMS                               6
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWGS_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWGS_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWGS_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWGS_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/
#define RSCMWGS_VAL_RXCONNECTOR_RF1C 0
#define RSCMWGS_VAL_RXCONNECTOR_RF2C 1
#define RSCMWGS_VAL_RXCONNECTOR_RF3C 2
#define RSCMWGS_VAL_RXCONNECTOR_RF4C 3
#define RSCMWGS_VAL_RXCONNECTOR_RFAC 4
#define RSCMWGS_VAL_RXCONNECTOR_RFBC 5
#define RSCMWGS_VAL_RXCONNECTOR_R11C 6
#define RSCMWGS_VAL_RXCONNECTOR_R12C 7
#define RSCMWGS_VAL_RXCONNECTOR_R13C 8
#define RSCMWGS_VAL_RXCONNECTOR_R14C 9
#define RSCMWGS_VAL_RXCONNECTOR_R21C 10
#define RSCMWGS_VAL_RXCONNECTOR_R22C 11
#define RSCMWGS_VAL_RXCONNECTOR_R23C 12
#define RSCMWGS_VAL_RXCONNECTOR_R24C 13
#define RSCMWGS_VAL_RXCONNECTOR_R31C 14
#define RSCMWGS_VAL_RXCONNECTOR_R32C 15
#define RSCMWGS_VAL_RXCONNECTOR_R33C 16
#define RSCMWGS_VAL_RXCONNECTOR_R34C 17
#define RSCMWGS_VAL_RXCONNECTOR_R41C 18
#define RSCMWGS_VAL_RXCONNECTOR_R42C 19
#define RSCMWGS_VAL_RXCONNECTOR_R43C 20
#define RSCMWGS_VAL_RXCONNECTOR_R44C 21

#define RSCMWGS_VAL_RXMODULE_RX1 0
#define RSCMWGS_VAL_RXMODULE_RX2 1
#define RSCMWGS_VAL_RXMODULE_RX3 2
#define RSCMWGS_VAL_RXMODULE_RX4 3
#define RSCMWGS_VAL_RXMODULE_RX11 4
#define RSCMWGS_VAL_RXMODULE_RX12 5
#define RSCMWGS_VAL_RXMODULE_RX13 6
#define RSCMWGS_VAL_RXMODULE_RX14 7
#define RSCMWGS_VAL_RXMODULE_RX21 8
#define RSCMWGS_VAL_RXMODULE_RX22 9
#define RSCMWGS_VAL_RXMODULE_RX23 10
#define RSCMWGS_VAL_RXMODULE_RX24 11
#define RSCMWGS_VAL_RXMODULE_RX31 12
#define RSCMWGS_VAL_RXMODULE_RX32 13
#define RSCMWGS_VAL_RXMODULE_RX33 14
#define RSCMWGS_VAL_RXMODULE_RX34 15
#define RSCMWGS_VAL_RXMODULE_RX41 16
#define RSCMWGS_VAL_RXMODULE_RX42 17
#define RSCMWGS_VAL_RXMODULE_RX43 18
#define RSCMWGS_VAL_RXMODULE_RX44 19

#define RSCMWGS_VAL_TXMODULE_TX1 0
#define RSCMWGS_VAL_TXMODULE_TX2 1
#define RSCMWGS_VAL_TXMODULE_TX3 2
#define RSCMWGS_VAL_TXMODULE_TX4 3
#define RSCMWGS_VAL_TXMODULE_TX11 4
#define RSCMWGS_VAL_TXMODULE_TX12 5
#define RSCMWGS_VAL_TXMODULE_TX13 6
#define RSCMWGS_VAL_TXMODULE_TX14 7
#define RSCMWGS_VAL_TXMODULE_TX21 8
#define RSCMWGS_VAL_TXMODULE_TX22 9
#define RSCMWGS_VAL_TXMODULE_TX23 10
#define RSCMWGS_VAL_TXMODULE_TX24 11
#define RSCMWGS_VAL_TXMODULE_TX31 12
#define RSCMWGS_VAL_TXMODULE_TX32 13
#define RSCMWGS_VAL_TXMODULE_TX33 14
#define RSCMWGS_VAL_TXMODULE_TX34 15
#define RSCMWGS_VAL_TXMODULE_TX41 16
#define RSCMWGS_VAL_TXMODULE_TX42 17
#define RSCMWGS_VAL_TXMODULE_TX43 18
#define RSCMWGS_VAL_TXMODULE_TX44 19

#define RSCMWGS_VAL_TXCONNECTOR_RF1C 0
#define RSCMWGS_VAL_TXCONNECTOR_RF2C 1
#define RSCMWGS_VAL_TXCONNECTOR_RF3C 2
#define RSCMWGS_VAL_TXCONNECTOR_RF4C 3
#define RSCMWGS_VAL_TXCONNECTOR_RFAC 4
#define RSCMWGS_VAL_TXCONNECTOR_RFBC 5
#define RSCMWGS_VAL_TXCONNECTOR_RF1O 6
#define RSCMWGS_VAL_TXCONNECTOR_RF3O 7
#define RSCMWGS_VAL_TXCONNECTOR_RFAO 8
#define RSCMWGS_VAL_TXCONNECTOR_R11C 9
#define RSCMWGS_VAL_TXCONNECTOR_R12C 10
#define RSCMWGS_VAL_TXCONNECTOR_R13C 11
#define RSCMWGS_VAL_TXCONNECTOR_R14C 12
#define RSCMWGS_VAL_TXCONNECTOR_R21C 13
#define RSCMWGS_VAL_TXCONNECTOR_R22C 14
#define RSCMWGS_VAL_TXCONNECTOR_R23C 15
#define RSCMWGS_VAL_TXCONNECTOR_R24C 16
#define RSCMWGS_VAL_TXCONNECTOR_R31C 17
#define RSCMWGS_VAL_TXCONNECTOR_R32C 18
#define RSCMWGS_VAL_TXCONNECTOR_R33C 19
#define RSCMWGS_VAL_TXCONNECTOR_R34C 20
#define RSCMWGS_VAL_TXCONNECTOR_R41C 21
#define RSCMWGS_VAL_TXCONNECTOR_R42C 22
#define RSCMWGS_VAL_TXCONNECTOR_R43C 23
#define RSCMWGS_VAL_TXCONNECTOR_R44C 24
#define RSCMWGS_VAL_TXCONNECTOR_R11O 25
#define RSCMWGS_VAL_TXCONNECTOR_R13O 26
#define RSCMWGS_VAL_TXCONNECTOR_R21O 27
#define RSCMWGS_VAL_TXCONNECTOR_R23O 28
#define RSCMWGS_VAL_TXCONNECTOR_R31O 29
#define RSCMWGS_VAL_TXCONNECTOR_R33O 30
#define RSCMWGS_VAL_TXCONNECTOR_R41O 31
#define RSCMWGS_VAL_TXCONNECTOR_R43O 32

#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_IQ2O 0
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_IQ4O 1
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_IQ6O 2
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_IQ8O 3
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I12O 4
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I14O 5
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I16O 6
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I18O 7
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I22O 8
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I24O 9
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I26O 10
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I28O 11
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I32O 12
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I34O 13
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I36O 14
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I38O 15
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I42O 16
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I44O 17
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I46O 18
#define RSCMWGS_VAL_IQ_OUT_CONNECTOR_I48O 19

#define RSCMWGS_VAL_CONN_RF1C  0
#define RSCMWGS_VAL_CONN_RF2C  1
#define RSCMWGS_VAL_CONN_RF3C  2
#define RSCMWGS_VAL_CONN_RF4C  3
#define RSCMWGS_VAL_CONN_RFAC  4
#define RSCMWGS_VAL_CONN_RFBC  5
#define RSCMWGS_VAL_CONN_RF1O  6
#define RSCMWGS_VAL_CONN_RF3O  7
#define RSCMWGS_VAL_CONN_RFAO  8
#define RSCMWGS_VAL_CONN_IQ2O  9
#define RSCMWGS_VAL_CONN_IQ4O  10
#define RSCMWGS_VAL_CONN_IQ6O  11
#define RSCMWGS_VAL_CONN_IQ8O  12

#define RSCMWGS_VAL_CONV_RX1  0
#define RSCMWGS_VAL_CONV_RX2  1
#define RSCMWGS_VAL_CONV_RX3  2
#define RSCMWGS_VAL_CONV_RX4  3

#define RSCMWGS_VAL_CONV_TX1  0
#define RSCMWGS_VAL_CONV_TX2  1
#define RSCMWGS_VAL_CONV_TX3  2
#define RSCMWGS_VAL_CONV_TX4  3
#define RSCMWGS_VAL_CONV_ITX1 4
#define RSCMWGS_VAL_CONV_ITX2 5

#define RSCMWGS_VAL_FAD1 0
#define RSCMWGS_VAL_FAD2 1
#define RSCMWGS_VAL_FAD11 2
#define RSCMWGS_VAL_FAD12 3
#define RSCMWGS_VAL_FAD21 4
#define RSCMWGS_VAL_FAD22 5
#define RSCMWGS_VAL_FAD31 6
#define RSCMWGS_VAL_FAD32 7
#define RSCMWGS_VAL_FAD41 8
#define RSCMWGS_VAL_FAD42 9

#define RSCMWGS_VAL_PATH_INPUT       0
#define RSCMWGS_VAL_PATH_OUTPUT      1
#define RSCMWGS_VAL_PATH_OUTPUT1     1
#define RSCMWGS_VAL_PATH_OUTPUT2     2
#define RSCMWGS_VAL_PATH_OUTPUT_BCCH 3

#define RSCMWGS_VAL_RX_LEVEL    0
#define RSCMWGS_VAL_RX_QUALITY  1

#define RSCMWGS_VAL_BEP_GMSK       0
#define RSCMWGS_VAL_BEP_8PSK       1
#define RSCMWGS_VAL_BEP_16QAM_NSR  2
#define RSCMWGS_VAL_BEP_32QAM_NSR  3
#define RSCMWGS_VAL_BEP_16QAM_HSR  4
#define RSCMWGS_VAL_BEP_32QAM_HSR  5

#define RSCMWGS_VAL_GPRS       0
#define RSCMWGS_VAL_EGPRS      1
#define RSCMWGS_VAL_DTM_GPRS   2
#define RSCMWGS_VAL_DTM_EGPRS  3

#define RSCMWGS_VAL_PC_U  0
#define RSCMWGS_VAL_PC_E1 1
#define RSCMWGS_VAL_PC_E2 2
#define RSCMWGS_VAL_PC_E3 3

#define RSCMWGS_VAL_FRATE 0
#define RSCMWGS_VAL_HRATE 1

#define RSCMWGS_VAL_RSET_RATE_OFF    0
#define RSCMWGS_VAL_RSET_RATE_C0475  1
#define RSCMWGS_VAL_RSET_RATE_C0515  2
#define RSCMWGS_VAL_RSET_RATE_C0590  3
#define RSCMWGS_VAL_RSET_RATE_C0670  4
#define RSCMWGS_VAL_RSET_RATE_C0740  5
#define RSCMWGS_VAL_RSET_RATE_C0795  6
#define RSCMWGS_VAL_RSET_RATE_C1020  7
#define RSCMWGS_VAL_RSET_RATE_C1220  8

#define RSCMWGS_VAL_DL_OFF 0
#define RSCMWGS_VAL_DL_ON  1
#define RSCMWGS_VAL_DL_VAL 2

#define RSCMWGS_VAL_SCEL 0
#define RSCMWGS_VAL_IORI 1
#define RSCMWGS_VAL_FADING 2

#define RSCMWGS_VAL_RFACCH 0
#define RSCMWGS_VAL_RSACCH 1

#define RSCMWGS_VAL_NB 0
#define RSCMWGS_VAL_WB 1

#define RSCMWGS_VAL_RSET_RATE_C0660 1
#define RSCMWGS_VAL_RSET_RATE_C0885 2
#define RSCMWGS_VAL_RSET_RATE_C1265 3
#define RSCMWGS_VAL_RSET_RATE_C1585 4
#define RSCMWGS_VAL_RSET_RATE_C2385 5

#define RSCMWGS_VAL_DEFINE_TIME_SHIFT 2

#define RSCMWGS_VAL_DOWNLINK 0
#define RSCMWGS_VAL_UPLINK   1

#define RSCMWGS_VAL_IPV4 0
#define RSCMWGS_VAL_IPV6 1

#define RSCMWGS_VAL_NETWORK_UMTS 0
#define RSCMWGS_VAL_NETWORK_GSM  1

#define RSCMWGS_VAL_NCELL_THRESHOLD_MODE_ALL     0
#define RSCMWGS_VAL_NCELL_THRESHOLD_MODE_LTE     1
#define RSCMWGS_VAL_NCELL_THRESHOLD_MODE_WCDMA   2
#define RSCMWGS_VAL_NCELL_THRESHOLD_MODE_TDSCDMA 3

#define RSCMW_VAL_NCELL_GSM_BAND_G085   0
#define RSCMW_VAL_NCELL_GSM_BAND_G09    1
#define RSCMW_VAL_NCELL_GSM_BAND_G18    2
#define RSCMW_VAL_NCELL_GSM_BAND_G19    3

#define RSCMW_VAL_NCELL_LTE_BAND_OB1     0
#define RSCMW_VAL_NCELL_LTE_BAND_OB2     1
#define RSCMW_VAL_NCELL_LTE_BAND_OB3     2
#define RSCMW_VAL_NCELL_LTE_BAND_OB4     3
#define RSCMW_VAL_NCELL_LTE_BAND_OB5     4
#define RSCMW_VAL_NCELL_LTE_BAND_OB6     5
#define RSCMW_VAL_NCELL_LTE_BAND_OB7     6
#define RSCMW_VAL_NCELL_LTE_BAND_OB8     7
#define RSCMW_VAL_NCELL_LTE_BAND_OB9     8
#define RSCMW_VAL_NCELL_LTE_BAND_OB10    9
#define RSCMW_VAL_NCELL_LTE_BAND_OB11    10
#define RSCMW_VAL_NCELL_LTE_BAND_OB12    11
#define RSCMW_VAL_NCELL_LTE_BAND_OB13    12
#define RSCMW_VAL_NCELL_LTE_BAND_OB14    13
#define RSCMW_VAL_NCELL_LTE_BAND_OB15    14
#define RSCMW_VAL_NCELL_LTE_BAND_OB16    15
#define RSCMW_VAL_NCELL_LTE_BAND_OB17    16
#define RSCMW_VAL_NCELL_LTE_BAND_OB18    17
#define RSCMW_VAL_NCELL_LTE_BAND_OB19    18
#define RSCMW_VAL_NCELL_LTE_BAND_OB20    19
#define RSCMW_VAL_NCELL_LTE_BAND_OB21    20
#define RSCMW_VAL_NCELL_LTE_BAND_OB22    21
#define RSCMW_VAL_NCELL_LTE_BAND_OB23    22
#define RSCMW_VAL_NCELL_LTE_BAND_OB24    23
#define RSCMW_VAL_NCELL_LTE_BAND_OB25    24
#define RSCMW_VAL_NCELL_LTE_BAND_OB33    25
#define RSCMW_VAL_NCELL_LTE_BAND_OB34    26
#define RSCMW_VAL_NCELL_LTE_BAND_OB35    27
#define RSCMW_VAL_NCELL_LTE_BAND_OB36    28
#define RSCMW_VAL_NCELL_LTE_BAND_OB37    29
#define RSCMW_VAL_NCELL_LTE_BAND_OB38    30
#define RSCMW_VAL_NCELL_LTE_BAND_OB39    31
#define RSCMW_VAL_NCELL_LTE_BAND_OB40    32
#define RSCMW_VAL_NCELL_LTE_BAND_OB41    33
#define RSCMW_VAL_NCELL_LTE_BAND_OB42    34
#define RSCMW_VAL_NCELL_LTE_BAND_OB43    35
#define RSCMW_VAL_NCELL_LTE_BAND_OB44    36
#define RSCMW_VAL_NCELL_LTE_BAND_OB45    37
#define RSCMW_VAL_NCELL_LTE_BAND_OB46    38
#define RSCMW_VAL_NCELL_LTE_BAND_OB65    39
#define RSCMW_VAL_NCELL_LTE_BAND_OB66    40
#define RSCMW_VAL_NCELL_LTE_BAND_OB67    41
#define RSCMW_VAL_NCELL_LTE_BAND_OB76    41
#define RSCMW_VAL_NCELL_LTE_BAND_OB252   42
#define RSCMW_VAL_NCELL_LTE_BAND_OB255   43

#define RSCMW_VAL_NCELL_WCDMA_BAND_OB1      0
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB2      1
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB3      2
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB4      3
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB5      4
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB6      5
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB7      6
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB8      7
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB9      8
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB10     9
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB11     10
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB12     11
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB13     12
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB14     13
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB15     14
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB16     15
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB17     16
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB18     17
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB19     18
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB20     19
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB21     20
#define RSCMW_VAL_NCELL_WCDMA_BAND_OBS1     21
#define RSCMW_VAL_NCELL_WCDMA_BAND_OBS2     22
#define RSCMW_VAL_NCELL_WCDMA_BAND_OBS3     23
#define RSCMW_VAL_NCELL_WCDMA_BAND_OBL1     24
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB22     25
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB25     26
#define RSCMW_VAL_NCELL_WCDMA_BAND_OB26     27

#define RSCMWGS_VAL_MODULATION_GMSK     0
#define RSCMWGS_VAL_MODULATION_EPSK     1

#define RSCMWGS_VAL_RLC_PDU     0
#define RSCMWGS_VAL_RLC_SDU     1

#define RSCMWGS_VAL_TRACE_TYPE_CURR     0
#define RSCMWGS_VAL_TRACE_TYPE_AVER     1

#define RSCMWGS_VAL_CS 0
#define RSCMWGS_VAL_PS 1

#define RSCMWGS_VAL_CONNECTION_REQUEST_REJECT 0
#define RSCMWGS_VAL_CONNECTION_REQUEST_ACCEPT 1
#define RSCMWGS_VAL_CONNECTION_REQUEST_IGNORE 2

#define RSCMW_VAL_NCELL_TDSCDMA_BAND_OB1  0
#define RSCMW_VAL_NCELL_TDSCDMA_BAND_OB2  1
#define RSCMW_VAL_NCELL_TDSCDMA_BAND_OB3  2

#define RSCMWGS_VAL_CBS_GEO_CIMM 0
#define RSCMWGS_VAL_CBS_GEO_PLMN 1
#define RSCMWGS_VAL_CBS_GEO_SERV 2
#define RSCMWGS_VAL_CBS_GEO_CNOR 3

/* Old constants definition */
#define RSCMWGS_VAL_FSIM_STANDARD_HT10      RSCMWGS_VAL_FSIM_STANDARD_HT100

#define RSCMWGS_VAL_SCENARIO_SCEL 0
#define RSCMWGS_VAL_SCENARIO_IORI 1
#define RSCMWGS_VAL_SCENARIO_BATC 2
#define RSCMWGS_VAL_SCENARIO_SCF  3
#define RSCMWGS_VAL_SCENARIO_SCFD 4

#define RSCMWGS_VAL_IQ_CONNECTOR_IQ2O 0
#define RSCMWGS_VAL_IQ_CONNECTOR_IQ4O 1
#define RSCMWGS_VAL_IQ_CONNECTOR_IQ6O 2
#define RSCMWGS_VAL_IQ_CONNECTOR_IQ8O 3
#define RSCMWGS_VAL_IQ_CONNECTOR_I12O 4
#define RSCMWGS_VAL_IQ_CONNECTOR_I14O 5
#define RSCMWGS_VAL_IQ_CONNECTOR_I16O 6
#define RSCMWGS_VAL_IQ_CONNECTOR_I18O 7
#define RSCMWGS_VAL_IQ_CONNECTOR_I22O 8
#define RSCMWGS_VAL_IQ_CONNECTOR_I24O 9
#define RSCMWGS_VAL_IQ_CONNECTOR_I26O 10
#define RSCMWGS_VAL_IQ_CONNECTOR_I28O 11
#define RSCMWGS_VAL_IQ_CONNECTOR_I32O 12
#define RSCMWGS_VAL_IQ_CONNECTOR_I34O 13
#define RSCMWGS_VAL_IQ_CONNECTOR_I36O 14
#define RSCMWGS_VAL_IQ_CONNECTOR_I38O 15
#define RSCMWGS_VAL_IQ_CONNECTOR_I42O 16
#define RSCMWGS_VAL_IQ_CONNECTOR_I44O 17
#define RSCMWGS_VAL_IQ_CONNECTOR_I46O 18
#define RSCMWGS_VAL_IQ_CONNECTOR_I48O 19

/* Fast Mode */
#define RSCMWGS_VAL_FAST_SWEEP_NORMAL 0
#define RSCMWGS_VAL_FAST_SWEEP_FAST   1

#define RSCMWGS_VAL_DOWN_CODING_SCHEME_C1   0
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_C2   1
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_C3   2
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_C4   3
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC1  4
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC2  5
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC3  6
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC4  7
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC5  8
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC6  9
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC7  10
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC8  11
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_MC9  12
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA5  13
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA6  14
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA7  15
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA8  16
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA9  17
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA10 18
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA11 19
#define RSCMWGS_VAL_DOWN_CODING_SCHEME_DA12 20

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC rscmwgs_init(ViRsrc     resourceName,
                               ViBoolean  IDQuery,
                               ViBoolean  resetDevice,
                               ViPSession instrumentHandle);

ViStatus _VI_FUNC rscmwgs_InitWithOptions(ViRsrc     resourceName,
                                          ViBoolean  IDQuery,
                                          ViBoolean  resetDevice,
                                          ViString   optionString,
                                          ViPSession instrumentHandle);

ViStatus _VI_FUNC rscmwgs_ConfigureRoutingStandardCell(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   RFInputConnector,
                                                       ViInt32   RXModule,
                                                       ViInt32   RFOutputConnector,
                                                       ViInt32   TXModule);

ViStatus _VI_FUNC rscmwgs_ConfigureRoutingIqOutRfIn(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   RFInputConnector,
                                                    ViInt32   RXModule,
                                                    ViInt32   IQOutputConnector,
                                                    ViInt32   TXModule);

ViStatus _VI_FUNC rscmwgs_ConfigureRoutingWithInternalFading(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   RFInputConnector,
                                                             ViInt32   RFInputConverter,
                                                             ViInt32   RFOutputConnector,
                                                             ViInt32   RFOutputConverter,
                                                             ViInt32   fader);

ViStatus _VI_FUNC rscmwgs_ConfigureRoutingExternalFading(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   RFInputConnector,
                                                         ViInt32   RFInputConverter,
                                                         ViInt32   RFOutputConnector,
                                                         ViInt32   RFOutputConverter,
                                                         ViInt32   IQOutputConnector);

ViStatus _VI_FUNC rscmwgs_ConfigureRoutingWithInternalDiversityFading(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   RFInputConnector,
							ViInt32   RFInputConverter,
							ViInt32   RFOutputConnector,
							ViInt32   RFOutputConverter,
							ViInt32   RFOutputConnector2,
							ViInt32   RFOutputConverter2,
							ViInt32   fader);

ViStatus _VI_FUNC rscmwgs_ConfigureRoutingExternalDiversityFading(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   RFInputConnector,
							ViInt32   RFInputConverter,
							ViInt32   RFOutputConnector,
							ViInt32   RFOutputConverter,
							ViInt32   RFOutputConnector2,
							ViInt32   RFOutputConverter2,
							ViInt32   IQOutputConnector,
							ViInt32   IQOutputConnector2);

ViStatus _VI_FUNC rscmwgs_ConfigureBCCHandTCHPDCHScenario(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   RFInputConnector,
                                                          ViInt32   RFInputConverter,
                                                          ViInt32   RFOutputConnector1,
                                                          ViInt32   RFOutputConverter1,
                                                          ViInt32   RFOutputConnector2,
                                                          ViInt32   RFOutputConverter2);

ViStatus _VI_FUNC rscmwgs_ConfigureEndToEnd(ViSession instrumentHandle,
                                            ViInt32   instance,
                                            ViBoolean endToEnd);

ViStatus _VI_FUNC rscmwgs_ConfigureSpeechCodec(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViBoolean speechCodec);

ViStatus _VI_FUNC rscmwgs_QuerySignalRouting(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViPInt32  scenario,
                                             ViChar    _VI_FAR controller[],
                                             ViPInt32  RFInputConnector,
                                             ViPInt32  RFInputConverter,
                                             ViPInt32  RFOutputConnector1,
                                             ViPInt32  RFOutputConverter1,
                                             ViPInt32  RFOutputConnector2,
                                             ViPInt32  RFOutputConverter2,
                                             ViPInt32  fader);

ViStatus _VI_FUNC rscmwgs_ConfigureExternalAttenuation(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   path,
                                                       ViReal64  externalAttenuation);

ViStatus _VI_FUNC rscmwgs_ConfigureBCCH(ViSession instrumentHandle,
                                        ViInt32   instance,
                                        ViInt32   band,
                                        ViInt32   channel,
                                        ViInt32   PMax);

ViStatus _VI_FUNC rscmwgs_ConfigureBCCHLevel(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViReal64  level);

ViStatus _VI_FUNC rscmwgs_ConfigureBCCHLowerLimitCheck(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViBoolean lowerLimitCheck);

ViStatus _VI_FUNC rscmwgs_ConfigureTCHPDCH(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   carrier,
                                           ViInt32   channel,
                                           ViReal64  referenceLevel,
                                           ViInt32   circuitSwitchedPCL);

ViStatus _VI_FUNC rscmwgs_ConfigureHopping(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   carrier,
                                           ViBoolean enableHopping,
                                           ViInt32   hoppingMAIO,
                                           ViInt32   hoppingHSN,
                                           ViString  hoppingList);

ViStatus _VI_FUNC rscmwgs_ConfigureRFFrequencyOffset(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViReal64  downlinkOffset,
                                                     ViReal64  uplinkOffset);

ViStatus _VI_FUNC rscmwgs_ConfigureRFPowerUplink(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   powerMode,
                                                 ViReal64  margin,
                                                 ViReal64  expectedPower);

ViStatus _VI_FUNC rscmwgs_ConfigureRFPowerUplinkMixerLevelOffset(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  mixerLevelOffset);

ViStatus _VI_FUNC rscmwgs_ConfigureExternalDelayCompensation(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViReal64  downlinkDelayCompensation,
                                                             ViReal64  uplinkDelayCompensation);

ViStatus _VI_FUNC rscmwgs_ConfigureIQInput(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   path,
                                           ViReal64  PEP,
                                           ViReal64  level);

ViStatus _VI_FUNC rscmwgs_QueryIQOutput(ViSession instrumentHandle,
                                        ViInt32   instance,
                                        ViInt32   path,
                                        ViPReal64 PEP,
                                        ViPReal64 crestFactor);

ViStatus _VI_FUNC rscmwgs_QueryFadingSimulatorDLSettings(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViPReal64 noiseBWPower,
                                                         ViPReal64 noiseTotalPower,
                                                         ViPReal64 signalPlusNoisePower);

ViStatus _VI_FUNC rscmwgs_ConfigureFadingSimulator(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViBoolean state,
                                                   ViInt32   standard,
                                                   ViInt32   restartMode,
                                                   ViInt32   globalSeed);

ViStatus _VI_FUNC rscmwgs_RestartFadingSimulator(ViSession instrumentHandle,
                                                 ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_ConfigureFadingSimulatorInsertionLoss(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   mode,
							ViReal64  userValue);

ViStatus _VI_FUNC rscmwgs_ConfigureFadingSimulatorDopplerFrequency(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   mode,
							ViReal64  frequency);

ViStatus _VI_FUNC rscmwgs_QueryFadingSimulatorClippingCounter(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  clippedSamples);

ViStatus _VI_FUNC rscmwgs_QueryFadingSimulatorInsertionLoss(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViPReal64 insertionLoss);

ViStatus _VI_FUNC rscmwgs_ConfigureFadingAWGN(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViBoolean state,
                                              ViReal64  bandwidthRatio,
                                              ViReal64  signalToNoiseRatio);

ViStatus _VI_FUNC rscmwgs_QueryFadingAWGNNoiseBandwidth(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViPReal64 noiseBandwidth);

ViStatus _VI_FUNC rscmwgs_ConnectionState(ViSession instrumentHandle,
                                          ViInt32   instance,
                                          ViInt32   action);

ViStatus _VI_FUNC rscmwgs_QueryConnectionState(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViPInt32  connectionState);

ViStatus _VI_FUNC rscmwgs_PacketSwitchedConnectionState(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   action);

ViStatus _VI_FUNC rscmwgs_QueryPacketSwitchedConnectionState(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViPInt32  connectionState);

ViStatus _VI_FUNC rscmwgs_ClearEventLog(ViSession instrumentHandle,
                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryEventLogLastEntry(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   bufferSize,
                                                 ViChar    _VI_FAR timeStamp[],
                                                 ViPInt32  eventCategory,
                                                 ViChar    _VI_FAR message[]);

ViStatus _VI_FUNC rscmwgs_QueryEventLogAllEntries(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   arraySize,
                                                  ViInt32   bufferSize,
                                                  ViChar    _VI_FAR timeStamp[],
                                                  ViPInt32  eventCategory,
                                                  ViChar    _VI_FAR message[],
                                                  ViPInt32  numberOfEntries);

ViStatus _VI_FUNC rscmwgs_QueryVoiceInfo(ViSession instrumentHandle,
                                         ViInt32   instance,
                                         ViPReal64 loopbackDelay,
                                         ViPReal64 downlinkEncoderDelay,
                                         ViPReal64 uplinkEncoderDelay);

ViStatus _VI_FUNC rscmwgs_ConfigureGeneratorState(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViBoolean cellState);

ViStatus _VI_FUNC rscmwgs_QueryGeneratorDetailState(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViPInt32  mainState,
                                                    ViPInt32  syncState);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReports(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   report,
                                                  ViPInt32  value,
                                                  ViPReal64 lowerRange,
                                                  ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsSub(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   report,
                                                     ViPInt32  value,
                                                     ViPReal64 lowerRange,
                                                     ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCount(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViPInt32  count);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsReceivedBlocks(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  receivedBlocks);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCValue(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViPInt32  value,
                                                        ViPReal64 lowerRange,
                                                        ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsSignalVariance(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  value,
							ViPReal64 lowerRange,
							ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsMeanBEP(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   modulation,
                                                         ViPInt32  value,
                                                         ViPReal64 lowerRange,
                                                         ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsMeanBEPCircuitSwitched(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  value,
							ViPReal64 lowerRange,
							ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCVBEP(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   modulation,
                                                       ViPInt32  value,
                                                       ViPReal64 lowerRange,
                                                       ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCVBEPCircuitSwitched(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  value,
							ViPReal64 lowerRange,
							ViPReal64 upperRange);

ViStatus _VI_FUNC rscmwgs_QueryMobileCapabilities(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViChar    _VI_FAR IMEI[],
                                                  ViChar    _VI_FAR IMSI[],
                                                  ViChar    _VI_FAR dialedNumber[]);

ViStatus _VI_FUNC rscmwgs_QueryMobileTighterCapabilities(ViSession  instrumentHandle,
                                                         ViInt32    instance,
                                                         ViPBoolean EGPRS2,
                                                         ViPBoolean GPRSAndEGPRS,
                                                         ViPBoolean SSCH);

ViStatus _VI_FUNC rscmwgs_QueryMobileIPAddress(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViInt32   IPVersion,
                                               ViInt32   arraySize,
                                               ViChar    _VI_FAR IPAddress[]);

ViStatus _VI_FUNC rscmwgs_QueryMultislotClass(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViInt32   mode,
                                              ViPInt32  multislotClass);

ViStatus _VI_FUNC rscmwgs_QueryAPNGateway(ViSession instrumentHandle,
                                          ViInt32   instance,
                                          ViInt32   arraySize,
                                          ViChar    _VI_FAR APNGateway[]);

ViStatus _VI_FUNC rscmwgs_QueryRXPower(ViSession instrumentHandle,
                                       ViInt32   instance,
                                       ViPInt32  RXPower);

ViStatus _VI_FUNC rscmwgs_QueryBandPowerClass(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViInt32   arraySize,
                                              ViInt32   _VI_FAR values[],
                                              ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_QueryEmergencyCallServiceCategory(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   arraySize,
                                                            ViBoolean _VI_FAR values[],
                                                            ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_QueryExtendedDynamicAllocationSupport(
							ViSession  instrumentHandle,
							ViInt32    instance,
							ViPBoolean GPRS,
							ViPBoolean EGPRS);

ViStatus _VI_FUNC rscmwgs_QueryCodecListSupport(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   network,
                                                ViBoolean _VI_FAR codecList[]);

ViStatus _VI_FUNC rscmwgs_QueryVAMOSLevel(ViSession instrumentHandle,
                                          ViInt32   instance,
                                          ViPInt32  VAMOSLevel);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkIdentity(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   cellIdentity,
                                                   ViInt32   MCC,
                                                   ViInt32   MNCDigits,
                                                   ViInt32   MNC,
                                                   ViInt32   LAC,
                                                   ViInt32   RAC,
                                                   ViInt32   NCC,
                                                   ViInt32   BCC);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkMSIdentity(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   MCC,
                                                     ViInt32   MNC,
                                                     ViString  MSIN);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkRequestedMobileData(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean IMEIRequest,
							ViBoolean authenticationRequest,
							ViBoolean IMSIRequest,
							ViBoolean classmarkRequest);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCell(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViInt32   locationUpdate,
                                               ViInt32   BSAGBLKSRES,
                                               ViInt32   BSPAMFRMS,
                                               ViBoolean MSDTXAllowed,
                                               ViInt32   bandIndicator);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellECGSMIoT(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViBoolean ECGSMIoT);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellSIMCardType(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   SIMCardType);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellKIValue(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViString  KIValue);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellEarlyClassmarkSending(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enable);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellExtended(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   pageMode,
                                                       ViInt32   NCCPermitted,
                                                       ViInt32   maxRetrans,
                                                       ViInt32   pagingWithMSIdentity);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellInitialPowerReduction(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   enable,
							ViInt32   value);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellBaring(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViBoolean cellBaring);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellCircuitSwitched(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean earlyClassmarkSending);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellCircuitSwitchedEnhancedMeasurementReport(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enhancedMeasurementReport);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellPacketSwitched(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   PDPContextActivation,
                                                             ViInt32   signalLevelFilterPeriod,
                                                             ViInt32   BEPPeriod,
                                                             ViInt32   PCMeasChannel);

ViStatus _VI_FUNC rscmwgs_ConfigureNetwokCellPacketSwitchedDomainState(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean cellState);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellIMSIFilter(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViBoolean IMSIFilter);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellSupport(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   support);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimersAndConstants(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   radiolinkTimeoutMS,
                                                             ViInt32   radiolinkTimeoutBS,
                                                             ViInt32   t3212,
                                                             ViInt32   t3312,
                                                             ViInt32   MTCAlertingTimeout);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkMOCAlertingTimer(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   MOCAlertingTimeout);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkImmediateAssignmentTimers(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   t3122,
							ViInt32   t3142);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkReleaseTimer(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   t3192);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkRejectCauses(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   locationUpdate,
                                                       ViInt32   gmmAttach,
                                                       ViInt32   cmService);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkGmmRoutingAreaRejectCause(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   cause);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkRejectCausesCMType(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   CMType);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellReselection(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViReal64  rxLevMinAccess,
                                                          ViReal64  qRxLevMinEUTRAN,
                                                          ViReal64  qRxLevMinUTRAN,
                                                          ViInt32   tReselection);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellReselectionHysteresis(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  hysteresis);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellAllowedDLChannels(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32   _VI_FAR allowedChannels[]);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellConnectionRequest(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   connectionType,
							ViInt32   connectionRequest,
							ViInt32   acceptAfter);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellSynchronization(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  offset,
							ViInt32   zone);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellThreshold(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   setFor,
							ViReal64  threshold);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellGSM(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   number,
                                                          ViBoolean state,
                                                          ViInt32   band,
                                                          ViInt32   channel,
                                                          ViBoolean measurementEnabled,
                                                          ViInt32   BSIC);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellLTE(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   number,
                                                          ViBoolean state,
                                                          ViInt32   band,
                                                          ViInt32   channel,
                                                          ViInt32   cellID,
                                                          ViBoolean measurementEnabled);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellWCDMA(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   number,
                                                            ViBoolean state,
                                                            ViInt32   band,
                                                            ViInt32   channel,
                                                            ViInt32   scramblingCode,
                                                            ViBoolean measurementEnabled);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellTDSCDMA(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViBoolean state,
							ViInt32   band,
							ViInt32   channel,
							ViInt32   scramblingCode,
							ViBoolean measurementEnabled);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellGSMRSSI(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   number,
                                                          ViPInt32  RSSI);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellGSMRSSIRange(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViPReal64 RSSIMin,
							ViPReal64 RSSIMax);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellLTERSRPRSRQ(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViPInt32  RSRP,
							ViPInt32  RSRQ);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellLTERSRPRSRQRange(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViPReal64 RSRPMin,
							ViPReal64 RSRPMax,
							ViPReal64 RSRQMin,
							ViPReal64 RSRQMax);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellWCDMARSCPEcNo(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViPInt32  RSCP,
							ViPInt32  ecNo);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellWCDMARSCPEcNoRange(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViPReal64 RSCPMin,
							ViPReal64 RSCPMax,
							ViPReal64 ecNoMin,
							ViPReal64 ecNoMax);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellTDSCDMARSCP(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViPInt32  RSCP);

ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellTDSCDMARSCPRange(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   number,
							ViPReal64 RSCPMin,
							ViPReal64 RSCPMax);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeSource(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   source);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeDate(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   year,
                                                   ViInt32   month,
                                                   ViInt32   day,
                                                   ViInt32   hour,
                                                   ViInt32   minute,
                                                   ViInt32   second,
                                                   ViInt32   DST,
                                                   ViInt32   DSTTimeShift);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeTransfer(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViBoolean enable);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeSendNetworkName(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enable);

ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeLocalZoneOffset(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  localZoneOffset);

ViStatus _VI_FUNC rscmwgs_ApplyNetworkTime(ViSession instrumentHandle,
                                           ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionFrequencyOffset(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViBoolean randomFrequencyOffset,
                                                             ViReal64  downlinkFrequencyOffset,
                                                             ViReal64  uplinkFrequencyOffset);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionTimingAdvance(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   timingAdvance);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionExtendedUplinkTBF(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean extendedUplinkTBF,
							ViBoolean extendedUplinkTBFNodata);

ViStatus _VI_FUNC rscmwgs_QueryConnectionError(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViInt32   domain,
                                               ViPInt32  connectionError);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitched(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   timeslot,
                                                             ViInt32   trafficMode,
                                                             ViInt32   dataSource,
                                                             ViInt32   loop,
                                                             ViString  callerId,
                                                             ViBoolean reCloseLoop,
                                                             ViInt32   TCHAssignment,
                                                             ViInt32   MSPowerChange);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedEchoDelay(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   echoDelay);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedDTXDL(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enable,
							ViReal64  noDataFrames,
							ViReal64  SIDFrames2Part);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedCallRelease(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   callRelease);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedTrafficChannelsState(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   controlChannel,
							ViBoolean enable);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRRate(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   rate,
							ViInt32   codecModeRate4,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRCodecMode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   codecModeDownlink,
							ViInt32   codecModeUplink);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRSignalingMode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   signalingMode);

ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedAMRMSCodecMode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViPInt32  codecModeDownlink,
							ViPInt32  codecModeUplink);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedWidebandAMRRate(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRNarrowBand8PSKHalfRate(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   codecModeRate4,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRWideBand8PSKFullRate(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   codecModeRate4,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRWideBand8PSKHalfRate(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMR8PSKCodecModeDownlink(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   codecModeDownlink);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMR8PSKCodecModeUplink(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   codecModeUplink);

ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedAMR8PSKMSCodecMode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViPInt32  codecModeDownlink,
							ViPInt32  codecModeUplink);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedVAMOS(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean VAMOSEnable,
							ViInt32   activeSubchannel,
							ViInt32   TSC,
							ViInt32   TSCSet,
							ViInt32   TSCOther,
							ViInt32   TSCSetOther,
							ViReal64  subchanPowerImbalanceRatio,
							ViInt32   VAMOSProfile);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedVAMOSSupportLevel(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   mobileSupportLevel);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedHalfRateSubchannel(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   HRSubchannel);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedWidebandAMRThreshold(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   modulation,
							ViBoolean _VI_FAR thresholdState[],
							ViReal64  _VI_FAR threshold[]);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAttempt(
							ViSession instrumentHandle,
							ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedReject(
							ViSession instrumentHandle,
							ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedAttempt(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32*  attempt);

ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedReject(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32*  reject);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedAutoSlot(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean autoSlotConfigEnabled);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedAutoDualSlot(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean autoDualSlotConfigEnabled);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedService(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   serviceSelection,
							ViBoolean testmodeBWithULACK,
							ViBoolean testmodeRFLevelReporting,
							ViBoolean testmodeSSRBWithSysInfo,
							ViInt32   BLERPollingRadioBlocks);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedDataSource(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   dataSource,
							ViString  userPattern);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSettings(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   extendedDynamicAllocation,
							ViInt32   numberOfProtocolDataUnits,
							ViInt32   slotOffset,
							ViInt32   controlAckType);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfig(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   TBFLevel);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfigUplink(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   uplinkCodingScheme,
							ViInt32   numberOfSlots,
							ViBoolean _VI_FAR used[],
							ViInt32   _VI_FAR uplinkGamma[]);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfigDownlink(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   numberOfSlots,
							ViBoolean _VI_FAR used[],
							ViInt32   _VI_FAR downlinkState[],
							ViReal64  _VI_FAR downlinkLevel[],
							ViInt32   _VI_FAR downlinkCodingScheme[]);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfigUSFDownlink(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   _VI_FAR percentage[]);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedIncrementalRedundancy(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean incrementalRedundancy);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedDownlinkDualcarrier(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enableDownlinkDualcarrier);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedBEPPeriod2(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   BEPPeriod2);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedBCSDataCorruptionRate(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  BCSDataCorruptionRate);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedDownlinkPowerControl(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enabled,
							ViInt32   p0,
							ViInt32   powerReductionMode,
							ViInt32   powerReductionField);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedAlwaysSendRLCDataBlocks(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enabled);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedBlockEncoding(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   blockEncoding,
							ViInt32   USFMode);

ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedFANR(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViBoolean enableFANR,
							ViBoolean downlinkEventBased,
							ViBoolean downlinkPolled,
							ViInt32   uplinkMode,
							ViInt32   uplinkTimeshift);

ViStatus _VI_FUNC rscmwgs_QueryConnectionPacketSwitchedMaxThroughput(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   direction,
							ViPReal64 throughput);

ViStatus _VI_FUNC rscmwgs_ConfigureHandover(ViSession instrumentHandle,
                                            ViInt32   instance,
                                            ViInt32   destinationBand,
                                            ViInt32   destinationChannel,
                                            ViReal64  destinationLevel,
                                            ViInt32   destinationPCL,
                                            ViInt32   destinationTimeslot);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverMobilityMode(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   mobilityMode);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverUplinkTimeslotsEnable(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   numberOfSlots,
							ViBoolean _VI_FAR uplinkTimeslotEnabled[]);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverUplinkGamma(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   numberOfSlots,
                                                       ViInt32   _VI_FAR uplinkGamma[]);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDownlinkTimeslotsEnable(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   numberOfSlots,
							ViBoolean _VI_FAR downlinkTimeslotEnabled[]);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDownlinkCodingScheme(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   numberOfSlots,
							ViInt32   _VI_FAR downlinkState[],
							ViReal64  _VI_FAR downlinkLevel[],
							ViInt32   _VI_FAR downlinkCodingScheme[]);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverUplinkCodingScheme(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   uplinkCodingScheme);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDestination(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViString  destination);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDualbandTCH(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   TCH);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDualbandDestination(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   channel,
							ViReal64  level,
							ViInt32   PCL,
							ViInt32   timeslot);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverPercentageOfDownlink(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   _VI_FAR percentage[]);

ViStatus _VI_FUNC rscmwgs_QueryHandoverBand(ViSession instrumentHandle,
                                            ViInt32   instance,
                                            ViPInt32  band);

ViStatus _VI_FUNC rscmwgs_InitiateHandover(ViSession instrumentHandle,
                                           ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryHandoverState(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViPInt32  handoverState);

ViStatus _VI_FUNC rscmwgs_QueryHandoverDestinationCatalog(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   bufferSize,
                                                          ViChar    _VI_FAR listOfDestination[],
                                                          ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalDestination(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   destination);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareGSM(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   DLChannel,
							ViInt32   bandIndicator);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareLTE(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   DLChannel);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareTDSCDMA(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   DLChannel);

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareWCDMA(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   DLChannel);

ViStatus _VI_FUNC rscmwgs_ConfigureTriggerFrameMode(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   frameTriggerMode);

ViStatus _VI_FUNC rscmwgs_ConfigureMeasurementSlotSettings(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   slot);

ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedStatisticalSettings(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   mode,
							ViInt32   stopCondition);

ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedStatisticCount(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   statisticCount);

ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedMeasurementTimeout(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  timeoutValue);

ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedLimit(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViReal64  BERLimit,
                                                           ViReal64  classIIBits,
                                                           ViReal64  classIbBits,
                                                           ViReal64  FERLimit,
                                                           ViReal64  FERFACCH,
                                                           ViReal64  FERSACCH);

ViStatus _VI_FUNC rscmwgs_BERCircuitSwitchedMeasurementInit(ViSession instrumentHandle,
                                                            ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_BERCircuitSwitchedMeasurementAbort(ViSession instrumentHandle,
                                                             ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_BERCircuitSwitchedMeasurementStop(ViSession instrumentHandle,
                                                            ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryBERCircuitSwitchedMeasurementStatus(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  mainState,
							ViPInt32  syncState,
							ViPInt32  resourcesState);

ViStatus _VI_FUNC rscmwgs_ReadBERCircuitSwitchedResults(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViPInt32  reliability,
                                                        ViPInt32  frames,
                                                        ViPReal64 BER,
                                                        ViPInt32  CRCErrors,
                                                        ViPReal64 classII,
                                                        ViPReal64 classIb,
                                                        ViPReal64 FER,
                                                        ViPInt32  l2FramesRepeated,
                                                        ViPInt32  errorEvent,
                                                        ViPInt32  numberSIDFrames,
                                                        ViPReal64 SIDFrameErrorRate,
                                                        ViPReal64 falseBFIRate);

ViStatus _VI_FUNC rscmwgs_FetchBERCircuitSwitchedResults(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViPInt32  reliability,
                                                         ViPInt32  frames,
                                                         ViPReal64 BER,
                                                         ViPInt32  CRCErrors,
                                                         ViPReal64 classII,
                                                         ViPReal64 classIb,
                                                         ViPReal64 FER,
                                                         ViPInt32  l2FramesRepeated,
                                                         ViPInt32  errorEvent,
                                                         ViPInt32  numberSIDFrames,
                                                         ViPReal64 SIDFrameErrorRate,
                                                         ViPReal64 falseBFIRate);

ViStatus _VI_FUNC rscmwgs_FetchBERCircuitSwitchedIntermediateResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViPInt32  reliability,
							ViPInt32  numberOfResults,
							ViInt32   _VI_FAR segmentReliability[],
							ViInt32   _VI_FAR RXQualityFull[],
							ViInt32   _VI_FAR RXQualitySubset[],
							ViInt32   _VI_FAR meanBEP[],
							ViInt32   _VI_FAR CVBEP[],
							ViInt32   _VI_FAR numberOfBlocks[],
							ViInt32   _VI_FAR TDMAFrameNumber[],
							ViInt32   _VI_FAR BER[]);

ViStatus _VI_FUNC rscmwgs_QueryBERCircuitSwitchedRoundTripDelay(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  roundTripDelay);

ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedStatisticalSettings(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   stopCondition);

ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedStatisticCount(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   statisticCount);

ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedMeasurementTimeout(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  timeoutValue);

ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedLimit(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViReal64  classIIBits,
                                                          ViReal64  DBLERLimit,
                                                          ViReal64  USFBLERLimit);

ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedMeasurementMode(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   measurementMode);

ViStatus _VI_FUNC rscmwgs_BERPacketSwitchedMeasurementInit(ViSession instrumentHandle,
                                                           ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_BERPacketSwitchedMeasurementAbort(ViSession instrumentHandle,
                                                            ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_BERPacketSwitchedMeasurementStop(ViSession instrumentHandle,
                                                           ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryBERPacketSwitchedMeasurementStatus(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  mainState,
							ViPInt32  syncState,
							ViPInt32  resourcesState);

ViStatus _VI_FUNC rscmwgs_ReadBERPacketSwitchedResults(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViPInt32  reliability,
                                                       ViPInt32  frames,
                                                       ViPReal64 BER,
                                                       ViPReal64 DBLER,
                                                       ViPReal64 USFBLER,
                                                       ViPReal64 falseUSFDetect,
                                                       ViPInt32  CRCErrors,
                                                       ViPInt32  nonAssignedUSF);

ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedResults(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViPInt32  reliability,
                                                        ViPInt32  frames,
                                                        ViPReal64 BER,
                                                        ViPReal64 DBLER,
                                                        ViPReal64 USFBLER,
                                                        ViPReal64 falseUSFDetect,
                                                        ViPInt32  CRCErrors,
                                                        ViPInt32  nonAssignedUSF);

ViStatus _VI_FUNC rscmwgs_ReadBERPacketSwitchedSingleCarrierResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   arraySize,
							ViPInt32  reliability,
							ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedSingleCarrierResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   arraySize,
							ViPInt32  reliability,
							ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedIntermediateResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViPInt32  reliability,
							ViPInt32  numberOfResults,
							ViInt32   _VI_FAR segmentReliability[],
							ViInt32   _VI_FAR meanBEPGMSK[],
							ViInt32   _VI_FAR CVBEPGMSK[],
							ViInt32   _VI_FAR meanBEP8PSK[],
							ViInt32   _VI_FAR CVBEP8PSK[],
							ViInt32   _VI_FAR TDMAFrameNumber[],
							ViInt32   _VI_FAR BER[]);

ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedIntermediateEnhancedResults(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   arraySize,
							ViPInt32  reliability,
							ViPInt32  numberOfResults,
							ViInt32   _VI_FAR segmentsResults[],
							ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_ConfigureBLERMeasurementTimeout(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViReal64  timeoutValue);

ViStatus _VI_FUNC rscmwgs_ConfigureBLERStatisticCount(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   statisticCount);

ViStatus _VI_FUNC rscmwgs_BLERMeasurementInit(ViSession instrumentHandle,
                                              ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_BLERMeasurementAbort(ViSession instrumentHandle,
                                               ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_BLERMeasurementStop(ViSession instrumentHandle,
                                              ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryBLERMeasurementStatus(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViPInt32  mainState,
                                                     ViPInt32  syncState,
                                                     ViPInt32  resourcesState);

ViStatus _VI_FUNC rscmwgs_ReadBLERSingleCarrierResults(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   carrier,
                                                       ViInt32   arraySize,
                                                       ViPInt32  reliability,
                                                       ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_FetchBLERSingleCarrierResults(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   carrier,
                                                        ViInt32   arraySize,
                                                        ViPInt32  reliability,
                                                        ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_ReadBLEROverAllResults(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   arraySize,
                                                 ViPInt32  reliability,
                                                 ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_FetchBLEROverAllResults(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   arraySize,
                                                  ViPInt32  reliability,
                                                  ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_ConfigureRLCThroughputMeasurementTimeout(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  timeoutValue);

ViStatus _VI_FUNC rscmwgs_ConfigureRLCThroughputMeasurement(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   repetition,
                                                            ViReal64  window);

ViStatus _VI_FUNC rscmwgs_RLCThroughputMeasurementInit(ViSession instrumentHandle,
                                                       ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_RLCThroughputMeasurementAbort(ViSession instrumentHandle,
                                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_RLCThroughputMeasurementStop(ViSession instrumentHandle,
                                                       ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryRLCThroughputMeasurementStatus(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  mainState);

ViStatus _VI_FUNC rscmwgs_QueryRLCThroughputMeasurementStatusAll(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  mainState,
							ViPInt32  syncState,
							ViPInt32  resourcesState);

ViStatus _VI_FUNC rscmwgs_ReadRLCThroughputSingleTraceResult(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   direction,
                                                             ViInt32   trace,
                                                             ViInt32   type,
                                                             ViInt32   arraySize,
                                                             ViPInt32  reliability,
                                                             ViReal64  _VI_FAR throughput[],
                                                             ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_FetchRLCThroughputSingleTraceResult(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   direction,
							ViInt32   trace,
							ViInt32   type,
							ViInt32   arraySize,
							ViPInt32  reliability,
							ViReal64  _VI_FAR throughput[],
							ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_ReadRLCThroughputResultsAll(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   arraySize,
                                                      ViPInt32  reliability,
                                                      ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_FetchRLCThroughputResultsAll(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   arraySize,
                                                       ViPInt32  reliability,
                                                       ViReal64  _VI_FAR results[]);

ViStatus _VI_FUNC rscmwgs_ConfigureCMRPerformanceMeasurementTimeout(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViReal64  timeoutValue);

ViStatus _VI_FUNC rscmwgs_ConfigureCMRPerformanceMeasurement(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViReal64  targetLevel);

ViStatus _VI_FUNC rscmwgs_CMRPerformanceMeasurementInit(ViSession instrumentHandle,
                                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_CMRPerformanceMeasurementAbort(ViSession instrumentHandle,
                                                         ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_CMRPerformanceMeasurementStop(ViSession instrumentHandle,
                                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QueryCMRPerformanceMeasurementStatusAll(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViPInt32  mainState,
							ViPInt32  syncState,
							ViPInt32  resourcesState);

ViStatus _VI_FUNC rscmwgs_ReadCMRPerformanceResult(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViPInt32  reliability,
                                                   ViInt32   _VI_FAR result[],
                                                   ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_FetchCMRPerformanceResult(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   arraySize,
                                                    ViPInt32  reliability,
                                                    ViInt32   _VI_FAR result[],
                                                    ViPInt32  returnedValues);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageDomain(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   domain);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageInternalParameters(
							ViSession instrumentHandle,
							ViInt32   instance,
							ViInt32   codingGroup,
							ViInt32   messageClass,
							ViString  originatorSMSCAddress,
							ViString  originatingAddress);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingServiceTimeSource(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   source);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingServiceTimeDate(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   year,
                                                     ViInt32   month,
                                                     ViInt32   day,
                                                     ViInt32   hour,
                                                     ViInt32   minute,
                                                     ViInt32   second);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageText(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViString  messageText);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageBinary(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViUInt8   _VI_FAR message[]);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingLastMessageSent(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViPInt32  lastMessageSent);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingProtocolIdentifier(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViString  protocolIdentifier);

ViStatus _VI_FUNC rscmwgs_SMSOutgoingUserDataHeader(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViBoolean enable,
                                                    ViString  userDataHeader);

ViStatus _VI_FUNC rscmwgs_QuerySMSOutgoingMessageSegment(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViPInt32  current,
                                                         ViPInt32  total);

ViStatus _VI_FUNC rscmwgs_SMSIncomingMessageReset(ViSession instrumentHandle,
                                                  ViInt32   instance);

ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageStatus(ViSession  instrumentHandle,
                                                        ViInt32    instance,
                                                        ViPBoolean status,
                                                        ViPInt32   messageLength);

ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageText(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   bufferSize,
                                                      ViChar    _VI_FAR messageText[]);

ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageDataCoding(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViPInt32  messageCoding);

ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageSegment(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViPInt32  current,
                                                         ViPInt32  total);

ViStatus _VI_FUNC rscmwgs_CBSGenerallyEnabled(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViBoolean enabled);

ViStatus _VI_FUNC rscmwgs_CBSMessageEnabled(ViSession instrumentHandle,
                                            ViInt32   instance,
                                            ViBoolean enabled);

ViStatus _VI_FUNC rscmwgs_CBSMessageID(ViSession instrumentHandle,
                                       ViInt32   instance,
                                       ViInt32   ID);

ViStatus _VI_FUNC rscmwgs_CBSMessageIDType(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   IDType);

ViStatus _VI_FUNC rscmwgs_CBSMessageDataCodeScheme(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   dataCodeScheme);

ViStatus _VI_FUNC rscmwgs_CBSMessageCategory(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViInt32   category);

ViStatus _VI_FUNC rscmwgs_CBSMessageData(ViSession instrumentHandle,
                                         ViInt32   instance,
                                         ViString  data);

ViStatus _VI_FUNC rscmwgs_CBSMessagePeriod(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   period);

ViStatus _VI_FUNC rscmwgs_CBSMessageSerial(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   geoScope,
                                           ViInt32   messageCode,
                                           ViBoolean autoIncrement,
                                           ViInt32   updateNumber);

ViStatus _VI_FUNC rscmwgs_CBSDRXEnabled(ViSession instrumentHandle,
                                        ViInt32   instance,
                                        ViBoolean enabled);

ViStatus _VI_FUNC rscmwgs_CBSDRXLengthOfPeriod(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViInt32   lengthOfPeriod);

ViStatus _VI_FUNC rscmwgs_CBSDRXOffset(ViSession instrumentHandle,
                                       ViInt32   instance,
                                       ViInt32   offset);

ViStatus _VI_FUNC rscmwgs_ConfigureMeasurementReportSettings(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViBoolean report,
                                                             ViInt32   WCDMAMeasurementQuantity,
                                                             ViInt32   LTEMeasurementQuantity);

ViStatus _VI_FUNC rscmwgs_ConfigureMessageMonitoring(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViBoolean addGSMSignalingToLogging,
                                                     ViInt32   loggingPCIPv4Address);

ViStatus _VI_FUNC rscmwgs_QueryMessageMonitoringIPAddress(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   bufferSize,
                                                          ViPInt32  loggingPCIPv4Address,
                                                          ViChar    _VI_FAR IPAddress[]);

ViStatus _VI_FUNC rscmwgs_SetAttributeViInt32(ViSession instrumentHandle,
                                              ViString  repeatedCapabilityName,
                                              ViUInt32  attributeID,
                                              ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwgs_SetAttributeViReal64(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwgs_SetAttributeViString(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViString  attributeValue);

ViStatus _VI_FUNC rscmwgs_SetAttributeViBoolean(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwgs_SetAttributeViSession(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViSession attributeValue);

ViStatus _VI_FUNC rscmwgs_GetAttributeRepCapName(ViSession instrumentHandle,
                                                 ViUInt32  attributeID,
                                                 ViString  repCapNameID,
                                                 ViInt32   index,
                                                 ViInt32   bufferSize,
                                                 ViChar    repCapName[]);

ViStatus _VI_FUNC rscmwgs_GetAttributeRepeatedCapabilityIds(ViSession instrumentHandle,
                                                            ViUInt32  attributeID,
                                                            ViInt32   bufferSize,
                                                            ViChar    _VI_FAR repeatedCapabilityId_s[]);

ViStatus _VI_FUNC rscmwgs_GetAttributeRepeatedCapabilityIdNames(
							ViSession instrumentHandle,
							ViUInt32  attributeID,
							ViString  repeatedCapabilityId,
							ViInt32   bufferSize,
							ViChar    _VI_FAR repeatedCapabilityIdName_s[]);

ViStatus _VI_FUNC rscmwgs_GetAttributeViInt32(ViSession instrumentHandle,
                                              ViString  repeatedCapabilityName,
                                              ViUInt32  attributeID,
                                              ViPInt32  attributeValue);

ViStatus _VI_FUNC rscmwgs_GetAttributeViReal64(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViPReal64 attributeValue);

ViStatus _VI_FUNC rscmwgs_GetAttributeViString(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViInt32   bufferSize,
                                               ViChar    _VI_FAR attributeValue[]);

ViStatus _VI_FUNC rscmwgs_GetAttributeViBoolean(ViSession  instrumentHandle,
                                                ViString   repeatedCapabilityName,
                                                ViUInt32   attributeID,
                                                ViPBoolean attributeValue);

ViStatus _VI_FUNC rscmwgs_GetAttributeViSession(ViSession  instrumentHandle,
                                                ViString   repeatedCapabilityName,
                                                ViUInt32   attributeID,
                                                ViPSession attributeValue);

ViStatus _VI_FUNC rscmwgs_CheckAttributeViInt32(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwgs_CheckAttributeViReal64(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwgs_CheckAttributeViString(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViString  attributeValue);

ViStatus _VI_FUNC rscmwgs_CheckAttributeViBoolean(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwgs_CheckAttributeViSession(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViSession attributeValue);

ViStatus _VI_FUNC rscmwgs_reset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgs_self_test(ViSession instrumentHandle,
                                    ViPInt16  selfTestResult,
                                    ViChar    _VI_FAR selfTestMessage[]);

ViStatus _VI_FUNC rscmwgs_revision_query(ViSession instrumentHandle,
                                         ViChar    _VI_FAR instrumentDriverRevision[],
                                         ViChar    _VI_FAR firmwareRevision[]);

ViStatus _VI_FUNC rscmwgs_SystemVersion(ViSession instrumentHandle,
                                        ViInt32   length,
                                        ViChar    _VI_FAR systemVersion[]);

ViStatus _VI_FUNC rscmwgs_error_query(ViSession instrumentHandle,
                                      ViPInt32  errorCode,
                                      ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwgs_ErrorList(ViSession instrumentHandle,
                                    ViInt32   bufferSize,
                                    ViChar    _VI_FAR errors[]);

ViStatus _VI_FUNC rscmwgs_error_message(ViSession instrumentHandle,
                                        ViStatus  errorCode,
                                        ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwgs_ReliabilityIndicator(ViSession instrumentHandle,
                                               ViInt32   reliabilityCode,
                                               ViChar    _VI_FAR reliabilityMessage[]);

ViStatus _VI_FUNC rscmwgs_Preset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgs_SetOPCTimeout(ViSession instrumentHandle,
                                        ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rscmwgs_GetOPCTimeout(ViSession instrumentHandle,
                                        ViPUInt32 timeout);

ViStatus _VI_FUNC rscmwgs_SetVISATimeout(ViSession instrumentHandle,
                                         ViUInt32  VISATimeout);

ViStatus _VI_FUNC rscmwgs_GetVISATimeout(ViSession instrumentHandle,
                                         ViPUInt32 VISATimeout);

ViStatus _VI_FUNC rscmwgs_ClearStatus(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgs_IDQueryResponse(ViSession instrumentHandle,
                                          ViUInt32  bufferSize,
                                          ViChar    _VI_FAR IDQueryResponse[]);

ViStatus _VI_FUNC rscmwgs_ProcessAllPreviousCommands(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgs_QueryOPC(ViSession instrumentHandle,
                                   ViPInt32  OPC);

ViStatus _VI_FUNC rscmwgs_SetFastSweepMode(ViSession instrumentHandle,
                                           ViInt32   fastSweepMode);

ViStatus _VI_FUNC rscmwgs_ConfigureErrorChecking(ViSession instrumentHandle,
                                                 ViBoolean optionChecking,
                                                 ViBoolean rangeChecking,
                                                 ViBoolean statusChecking);

ViStatus _VI_FUNC rscmwgs_ConfigureAutoSystemErrQuery(ViSession instrumentHandle,
                                                      ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rscmwgs_ConfigureMultiThreadLocking(ViSession instrumentHandle,
                                                      ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rscmwgs_GetError(ViSession instrumentHandle,
                                   ViPStatus code,
                                   ViInt32   bufferSize,
                                   ViChar    _VI_FAR description[]);

ViStatus _VI_FUNC rscmwgs_ClearError(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwgs_ReadToFileFromInstrument(ViSession instrumentHandle,
                                                   ViString  source,
                                                   ViString  destination);

ViStatus _VI_FUNC rscmwgs_WriteFromFileToInstrument(ViSession instrumentHandle,
                                                    ViString  source,
                                                    ViString  destination);

ViStatus _VI_FUNC rscmwgs_WriteInstrData(ViSession instrumentHandle,
                                         ViString  writeBuffer);

ViStatus _VI_FUNC rscmwgs_ReadInstrData(ViSession instrumentHandle,
                                        ViInt32   numberOfBytesToRead,
                                        ViChar    _VI_FAR readBuffer[],
                                        ViPUInt32 numBytesRead);

ViStatus _VI_FUNC rscmwgs_WriteCommandWithOPCSync(ViSession instrumentHandle,
                                                  ViString  writeBuffer,
                                                  ViUInt32  timeout);

ViStatus _VI_FUNC rscmwgs_QueryWithOPCSync(ViSession instrumentHandle,
                                           ViString  writeBuffer,
                                           ViUInt32  timeout,
                                           ViInt32   bufferSize,
                                           ViChar    _VI_FAR readBuffer[],
                                           ViPUInt32 numBytesRead);

ViStatus _VI_FUNC rscmwgs_QueryViBoolean(ViSession  instrumentHandle,
                                         ViString   command,
                                         ViPBoolean value);

ViStatus _VI_FUNC rscmwgs_QueryViInt32(ViSession instrumentHandle,
                                       ViString  command,
                                       ViPInt32  value);

ViStatus _VI_FUNC rscmwgs_QueryViReal64(ViSession instrumentHandle,
                                        ViString  command,
                                        ViPReal64 value);

ViStatus _VI_FUNC rscmwgs_QueryViString(ViSession instrumentHandle,
                                        ViString  command,
                                        ViInt32   bufferSize,
                                        ViChar    _VI_FAR value[]);

ViStatus _VI_FUNC rscmwgs_close(ViSession instrumentHandle);

// deprecated
ViStatus _VI_FUNC rscmwgs_QueryEvenetLogLastEntry(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   bufferSize,
                                                  ViChar    timeStamp[],
                                                  ViInt32   *eventCategory,
                                                  ViChar    message[]);

ViStatus _VI_FUNC rscmwgs_QueryEvenetLogAllEntries(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   bufferSize,
                                                   ViChar    timeStamp[],
                                                   ViInt32   eventCategory[],
                                                   ViChar    message[],
                                                   ViInt32   *numberOfEntries);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWGS_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWGS_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWGS_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWGS_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWGS_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWGS_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWGS_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWGS_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWGS_ERRMSG_INCORRECT_STATE       "Instrument in incorrect state"
#define RSCMWGS_ERRMSG_INCORRECT_RESPONSE    "Response incorrect; report problem to R&S support!"
#define RSCMWGS_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWGS_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWGS_ERROR_CODES_AND_MSGS \
    {RSCMWGS_ERROR_INCORRECT_STATE,   RSCMWGS_ERRMSG_INCORRECT_STATE},\
    {RSCMWGS_ERROR_INCORRECT_RESPONSE,     RSCMWGS_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWGS_ERROR_MAX_TIME_EXCEEDED,    RSCMWGS_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWGS_ERROR_RELIABILITY_INDICATOR, RSCMWGS_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWGS_HEADER */
