/*****************************************************************************
 *  Rohde&Schwarz CMW Radiocommunication Analyzer WiMAX Signalling driver
 *  VXIpnp Instrument Driver
 *  Original Release: February 2010
 *  By: Martin Krcmar
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *     see ChangeLog
 *****************************************************************************/
#include <math.h>
#include <float.h>
#include "rscmwgs.h"

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
    #define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
    #include <windows.h>
#endif

#if defined (_CVI_)
    #include <utility.h>
#endif

/*****************************************************************************
 *- Value Definition and Range Tables ---------------------------------------*
 *****************************************************************************/
static ViString rfInputConverterArr[] = {"RX1","RX2","RX3","RX4",NULL};
static ViString rfOutputConverterArr[] = {"TX1","TX2","TX3","TX4","ITX1","ITX2",NULL};

static ViString gs_rxModuleArr[] = {"RX1","RX2","RX3","RX4","RX11","RX12","RX13","RX14","RX21","RX22","RX23","RX24","RX31","RX32","RX33","RX34","RX41","RX42","RX43","RX44",NULL};
static ViString gs_rxConnectorArr[] = {"RF1C","RF2C","RF3C","RF4C","RFAC","RFBC","R11C","R12C","R13C","R14C","R21C","R22C","R23C","R24C","R31C","R32C","R33C","R34C","R41C","R42C","R43C","R44C",NULL};
static ViString gs_txModuleArr[] = {"TX1","TX2","TX3","TX4","TX11","TX12","TX13","TX14","TX21","TX22","TX23","TX24","TX31","TX32","TX33","TX34","TX41","TX42","TX43","TX44",NULL};
static ViString gs_txConnectorArr[] = {"RF1C","RF2C","RF3C","RF4C","RFAC","RFBC","RF1O","RF3O","RFAO","R11C","R12C","R13C","R14C","R21C","R22C","R23C","R24C","R31C","R32C","R33C","R34C","R41C","R42C","R43C","R44C","R11O","R13O","R21O","R23O","R31O","R33O","R41O","R43O",NULL};
static ViString gs_iqOutConnectorArr[] = {"IQ2O","IQ4O","IQ6O","IQ8O","I12O","I14O","I16O","I18O","I22O","I24O","I26O","I28O","I32O","I34O","I36O","I38O","I42O","I44O","I46O","I48O",NULL};
static ViString gs_faderArr[] = {"FAD1","FAD2","FAD11","FAD12","FAD21","FAD22","FAD31","FAD32","FAD41","FAD42",NULL};

static ViString RFConnectorArr[] = {"RF1C","RF2C","RF3C","RF4C","RFAC","RFBC","RF1O","RF3O","RFAO","IQ2O","IQ4O", NULL};
static ViString gs_RFConnectorArr[] = {"RF1C","RF2C","RF3C","RF4C","RFAC","RFBC","R11C","R12C","R13C","R14C","R21C","R22C",
                                       "R23C","R24C","R31C","R32C","R33C","R34C","R41C","R42C","R43C","R44C", NULL};
//static ViString faderArr[] = {"FAD1","FAD2", NULL};
//static ViString iqConnectorArr[] = {"IQ2O","IQ4O","IQ6O","IQ8O"};
static ViString mainStateArr[]={"OFF","ON","RFH",NULL};
static ViString syncStateArr[]={"PEND","ADJ",NULL};
static ViString scenarioArr[] = {"SCEL", "IORI", "BATC","SCF","SCFD", NULL};
static ViString powerClassArr[] = {"U", "E1", "E2", "E3", NULL};
static ViString codecRateArr[] = {"OFF", "C0475", "C0515", "C0590", "C0670", "C0740", "C0795", "C1020", "C1220", NULL};
static ViString codeSchemeArr[] = {"C1", "C2", "C3", "C4", "MC1", "MC2", "MC3", "MC4",
                                   "MC5", "MC6", "MC7", "MC8", "MC9", "DA5", "DA6", "DA7",
                                   "DA8", "DA9", "DA10", "DA11", "DA12", NULL};
static ViString VAMOSProfileArr[] = {"", "SUS", "TUS", "TUDT", NULL};
static ViString codecRateWBArr[] = {"OFF","C0660","C0885","C1265","C1585","C2385", NULL};
static ViString logMessageCategoryArr[] = {"INFO","WARN","ERR","CONT", NULL};
static ViString ipVersionArr[] = {"ipv4","ipv6", NULL};
static ViString networkArr[] = {"UMTS","GSM",NULL};
static ViString gsmNcellBandArr[] = {"G085","G09","G18","G19", NULL};
static ViString lteNcellBandArr[] = {"OB1","OB2","OB3","OB4","OB5","OB6","OB7","OB8","OB9", "OB10",
                                     "OB11","OB12","OB13","OB14","OB15","OB16","OB17","OB18","OB19","OB20",
                                     "OB21","OB22","OB23","OB24","OB25","OB33","OB34","OB35","OB36","OB37",
                                     "OB38","OB39","OB40","OB41","OB42","OB43","OB44","OB45","OB46","OB65",
                                     "OB66","OB67","OB252","OB255",NULL};

static ViString wcdmaNcellBandArr[] = {"OB1","OB2","OB3","OB4","OB5","OB6","OB7","OB8","OB9", "OB10",
                                     "OB11","OB12","OB13","OB14","OB15","OB16","OB17","OB18","OB19","OB20",
                                     "OB21","OBS1","OBS2","OBS3","OBL1","OB22","OB25","OB26",NULL};
static ViString modulationArr[] = {"GMSK","EPSK", NULL};
static ViString modulationBandArr[] = {"NB","WB",NULL};
static ViString modulationRateArr[]={"FRAT","HRAT",NULL};
static ViString rlcDirectionArr[] = {"DL", "UL", NULL};
static ViString rlcTrace[] = {"PDU","SDU",NULL};
static ViString rlcType[] = {"CURR","AVER",NULL};
static ViString gs_ConnectionTypeArr[] = {"CSW","PSW",NULL};
static ViString gs_ConnectionRequestArr[] = {"REJ","ACC","IGN",NULL};
static ViString gs_TDSCDMANcellBandArr[] = {"OB1","OB2","OB3",NULL};
static ViString switchArr[] = {"OFF", "ON", NULL};
static ViString geoScopeArr[] = {"CIMM","PLMN","LOC","CNOR", NULL};
static ViString LoggingPCIPv4AddressArr[] = {"","IP1","IP2","IP3",NULL};

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/

/*****************************************************************************
 *- User-Callable Functions (Exportable Functions) --------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function: rscmwgs_init
 * Purpose:  VXIplug&play required function. Calls the
 *           rscmwgs_InitWithOptions function.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_init (ViRsrc resourceName, ViBoolean IDQuery,
                                 ViBoolean resetDevice, ViSession *newInstrSession)
{
	ViStatus error = VI_SUCCESS;

	if (newInstrSession == NULL)
	{
		(void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
		                          VI_ERROR_PARAMETER4, "Null address for Instrument Handle");

		checkErr(RS_ERROR_INVALID_PARAMETER);
	}

	checkErr(rscmwgs_InitWithOptions (resourceName, IDQuery, resetDevice, "", newInstrSession));

Error:
	return error;
}

/*****************************************************************************
 * Function: rscmwgs_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_InitWithOptions(
    ViRsrc          resourceName,
    ViBoolean       IDQuery,
    ViBoolean       resetDevice,
    ViString        optionString,
    ViSession      *newInstrSession
)
{
	ViStatus error = VI_SUCCESS;
	RsCoreAttributePtr *attrList = NULL;
	ViSession instrSession = 0;
	RsCoreSessionPtr sessionProperties = NULL;

	if (newInstrSession == NULL)
	{
		(void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
		                          "Null address for Instrument Handle");
		checkErr(RS_ERROR_INVALID_PARAMETER);
	}

	attrList = (RsCoreAttributePtr *)rscmwgs_RsCoreAttributeList;

	*newInstrSession = 0;

	checkErr(RsCore_NewSpecificDriver(
        resourceName, // VISA Resource Name
        "rscmwgs", // driver prefix
        optionString, // Init Options string, is applied to the session settings
        attrList, // List of all attributes from the rsxxx_AttrPropertiesList
        VI_FALSE, //idnModelFullName Model has the full *IDN? query name e.g. true: "CMW100A", VI_FALSE: "CMW" Used in CheckInstrument()
        0, // WriteDelay
        0, // ReadDelay
        100000, // IO Segment Size
        RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
        RSCMWGS_OPC_TIMEOUT, // OPC timeout
        15000, // VISA Timeout
        600000, // Self-test timeout
        RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
        RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
        &instrSession));

	// Minimal allowed rscore version is 3.4.0
	checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 3, 4, 0));

	checkErr(RsCore_GetRsSession(instrSession, &sessionProperties));

	// No SCPI command has been sent yet.
	// Call viClear before sending any SCPI command
	checkErr(RsCore_ViClear(instrSession));

	/* --- Here perform settings that are default for this driver,
	but can be overwritten by the optionsString settings */

	sessionProperties->autoSystErrQuery = VI_FALSE;

	// Parse option string and optionally sets the initial state of the following session attributes
	checkErr(RsCore_ApplyOptionString(instrSession, optionString));
	checkErr(RsCore_BuildRepCapTable(instrSession, rscmwgs_RsCoreRepCapTable));

	// Query *IDN? string, parse it and set the following attributes:
	// -RS_ATTR_INSTRUMENT_MANUFACTURER
	// - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "CMW100A", false : "CMW"
	// - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
	checkErr(RsCore_QueryAndParseIDNstring(instrSession, RSCMWGS_SIMULATION_ID_QUERY, NULL));

	// Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
	checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSCMWGS_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

	// Default Instrument Setup + optional *RST
	if (resetDevice == VI_TRUE)
	{
		checkErr(rscmwgs_reset(instrSession));
	}
	else
	{
		checkErr(rscmwgs_DefaultInstrSetup(instrSession));
	}

	if (IDQuery == VI_TRUE)
	{
		checkErr(RsCore_FitsIDNpattern(instrSession, RSCMWGS_VALID_ID_RESPONSE_STRING, NULL));
	}

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	if (error < VI_SUCCESS)
	{
		if (error == RS_ERROR_INSTRUMENT_STATUS && sessionProperties->autoSystErrQuery == VI_FALSE)
		{
			sessionProperties->autoSystErrQuery = VI_TRUE;
			(void)rscmwgs_CheckStatus(instrSession);
			sessionProperties->autoSystErrQuery = VI_FALSE;
		}

		if (instrSession != 0)
			(void)RsCore_ViClose(instrSession);
	}
	else
	{
		*newInstrSession = instrSession;
	}

	return error;
}

/// HIFN  This function selects the input and output connectors for the
/// HIFN  generated RF signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR rfInputConnector/Defines the RF input connector.
/// HIPAR rxModule/Defines the RF input module.
/// HIPAR rfOutputConnector/Defines the RF output connector.
/// HIPAR txModule/Defines the RF output converter.
ViStatus _VI_FUNC rscmwgs_ConfigureRoutingStandardCell(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   rfInputConnector,
                                                       ViInt32   rxModule,
                                                       ViInt32   rfOutputConnector,
                                                       ViInt32   txModule)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConnector, RSCMWGS_VAL_RXCONNECTOR_RF1C, RSCMWGS_VAL_RXCONNECTOR_R44C),
    		3, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rxModule, RSCMWGS_VAL_RXMODULE_RX1, RSCMWGS_VAL_RXMODULE_RX44),
    		4, "RX Module");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector, RSCMWGS_VAL_TXCONNECTOR_RF1C, RSCMWGS_VAL_TXCONNECTOR_R43O),
    		5, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, txModule, RSCMWGS_VAL_TXMODULE_TX1, RSCMWGS_VAL_TXMODULE_TX44),
    		6, "TX Module");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld:SCEN:SCEL %s,%s,%s,%s\n", instance,
                                                                                  gs_RFConnectorArr[rfInputConnector],
                                                                                  gs_rxModuleArr[rxModule],
                                                                                  gs_txConnectorArr[rfOutputConnector],
                                                                                  gs_txModuleArr[txModule]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the input and output connectors for the
/// HIFN  generated RF signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR rfInputConnector/Defines the RF input connector.
/// HIPAR rxModule/Defines the RF input module.
/// HIPAR iqOutputConnector/Defines IQ output connector
/// HIPAR txModule/Defines the RF output converter.
ViStatus _VI_FUNC rscmwgs_ConfigureRoutingIqOutRfIn(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   rfInputConnector,
                                                    ViInt32   rxModule,
                                                    ViInt32   iqOutputConnector,
                                                    ViInt32   txModule)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConnector, RSCMWGS_VAL_RXCONNECTOR_RF1C, RSCMWGS_VAL_RXCONNECTOR_R44C),
    		3, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rxModule, RSCMWGS_VAL_RXMODULE_RX1, RSCMWGS_VAL_RXMODULE_RX44),
    		4, "RX Module");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, iqOutputConnector, RSCMWGS_VAL_TXCONNECTOR_RF1C, RSCMWGS_VAL_TXCONNECTOR_R43O),
    		5, "IQ Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, txModule, RSCMWGS_VAL_TXMODULE_TX1, RSCMWGS_VAL_TXMODULE_TX44),
    		6, "TX Module");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld:SCEN:IORI %s,%s,%s,%s\n", instance,
                                                                                  gs_RFConnectorArr[rfInputConnector],
                                                                                  gs_rxModuleArr[rxModule],
                                                                                  gs_iqOutConnectorArr[iqOutputConnector],
                                                                                  gs_txModuleArr[txModule]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN the "Standard Cell Fading: Internal" scenario, selects the RF
/// HIFN input (RX) and output (TX) path, i.e. RF connectors and RX/TX
/// HIFN modules and specifies fader to be used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR RFInputConnector/Defines the RF input connector.
/// HIPAR RFInputConverter/Defines the RF input converter.
/// HIPAR RFOutputConnector/Selects the RF output connector.
/// HIPAR RFOutputConverter/Defines the RF output converter.
/// HIPAR fader/Defines the internal fading I/Q board
ViStatus _VI_FUNC rscmwgs_ConfigureRoutingWithInternalFading(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   RFInputConnector,
                                                             ViInt32   RFInputConverter,
                                                             ViInt32   RFOutputConnector,
                                                             ViInt32   RFOutputConverter,
                                                             ViInt32   fader)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConnector, RSCMWGS_VAL_RXCONNECTOR_RF1C, RSCMWGS_VAL_RXCONNECTOR_R44C),
    		3, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConverter, RSCMWGS_VAL_RXMODULE_RX1, RSCMWGS_VAL_RXMODULE_RX44),
    		4, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConnector, RSCMWGS_VAL_TXCONNECTOR_RF1C, RSCMWGS_VAL_TXCONNECTOR_R43O),
    		5, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConverter, RSCMWGS_VAL_TXMODULE_TX1, RSCMWGS_VAL_TXMODULE_TX44),
    		6, "RF Output Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, fader, 0, 9),
    		7, "Fader");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld:SCEN:SCF:INT %s,%s,%s,%s,%s\n",
    		instance, gs_rxConnectorArr[RFInputConnector], gs_rxModuleArr[RFInputConverter], gs_txConnectorArr[RFOutputConnector], gs_txModuleArr[RFOutputConverter], gs_faderArr[fader]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the "Standard Cell Fading: External" scenario and selects
/// HIFN  the RF connectors, RX/TX modules and digital I/Q output connector to be
/// HIFN  used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR rfInputConnector/Defines the RF input connector.
/// HIPAR rfInputConverter/Defines the RF input converter.
/// HIPAR rfOutputConnector/Selects the RF output connector.
/// HIPAR rfOutputConverter/Defines the RF output converter.
/// HIPAR iqOutputConnector/Defines the IQ output connector.
ViStatus _VI_FUNC rscmwgs_ConfigureRoutingExternalFading(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   rfInputConnector,
                                                         ViInt32   rfInputConverter,
                                                         ViInt32   rfOutputConnector,
                                                         ViInt32   rfOutputConverter,
                                                         ViInt32   iqOutputConnector)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConnector, RSCMWGS_VAL_CONN_RF1C, RSCMWGS_VAL_CONN_RFBC),
    		3, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConverter, RSCMWGS_VAL_CONV_RX1, RSCMWGS_VAL_CONV_RX4),
    		4, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector, RSCMWGS_VAL_CONN_RF1C, RSCMWGS_VAL_CONN_IQ4O),
    		5, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConverter, RSCMWGS_VAL_CONV_TX1, RSCMWGS_VAL_CONV_ITX2),
    		6, "RF Output Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, iqOutputConnector, RSCMWGS_VAL_IQ_CONNECTOR_IQ2O, RSCMWGS_VAL_IQ_CONNECTOR_I48O),
    		7, "IQ Converter");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld:SCEN:SCF:EXT %s,%s,%s,%s,%s\n",
    		instance, RFConnectorArr[rfInputConnector], rfInputConverterArr[rfInputConverter], RFConnectorArr[rfOutputConnector], rfOutputConverterArr[rfOutputConverter], gs_iqOutConnectorArr[iqOutputConnector]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the "Standard Cell RX Diversity Fading: Internal" scenario
/// HIFN  and selects the signal paths.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR rfInputConnector/Defines the RF input connector.
/// HIPAR rfInputConverter/Defines the RF input converter.
/// HIPAR rfOutputConnector/Selects the RF output connector.
/// HIPAR rfOutputConverter/Defines the RF output converter.
/// HIPAR rfOutputConnector2/Selects the RF output connector 2.
/// HIPAR fader/Defines the internal fading I/Q board to be used
/// HIPAR rfOutputConverter2/Defines the RF output converter 2.
ViStatus _VI_FUNC rscmwgs_ConfigureRoutingWithInternalDiversityFading(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   rfInputConnector,
							ViInt32   rfInputConverter,
							ViInt32   rfOutputConnector,
							ViInt32   rfOutputConverter,
							ViInt32   rfOutputConnector2,
							ViInt32   rfOutputConverter2,
							ViInt32   fader)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConnector, RSCMWGS_VAL_RXCONNECTOR_RF1C, RSCMWGS_VAL_RXCONNECTOR_R44C),
    		3, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConverter, RSCMWGS_VAL_RXMODULE_RX1, RSCMWGS_VAL_RXMODULE_RX44),
    		4, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector, RSCMWGS_VAL_TXCONNECTOR_RF1C, RSCMWGS_VAL_TXCONNECTOR_R43O),
    		5, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConverter, RSCMWGS_VAL_TXMODULE_TX1, RSCMWGS_VAL_TXMODULE_TX44),
    		6, "RF Output Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector2, RSCMWGS_VAL_TXCONNECTOR_RF1C, RSCMWGS_VAL_TXCONNECTOR_R43O),
    		5, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConverter2, RSCMWGS_VAL_TXMODULE_TX1, RSCMWGS_VAL_TXMODULE_TX44),
    		6, "RF Output Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, fader, 0, 9),
    		7, "Fader");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld:SCEN:SCFD:INT %s,%s,%s,%s,%s,%s,%s\n", instance,
                                                                          gs_rxConnectorArr[rfInputConnector],
                                                                          gs_rxModuleArr[rfInputConverter],
                                                                          gs_txConnectorArr[rfOutputConnector],
                                                                          gs_txModuleArr[rfOutputConverter],
                                                                          gs_txConnectorArr[rfOutputConnector2],
                                                                          gs_txModuleArr[rfOutputConverter2],
                                                                          gs_faderArr[fader]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the "Standard Cell Fading: External" scenario and selects
/// HIFN  the RF connectors, RX/TX modules and digital I/Q output connector to be
/// HIFN  used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR rfInputConnector/Defines the RF input connector.
/// HIPAR rfInputConverter/Defines the RF input module.
/// HIPAR rfOutputConnector/Defines the RF output connector.
/// HIPAR rfOutputConverter/Defines the RF output converter.
/// HIPAR rfOutputConnector2/Defines the RF output connector.
/// HIPAR rfOutputConverter2/Defines the RF output converter.
/// HIPAR iqOutputConnector/Defines the IQ output connector.
/// HIPAR iqOutputConnector2/Defines the IQ output connector.
ViStatus _VI_FUNC rscmwgs_ConfigureRoutingExternalDiversityFading(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   rfInputConnector,
							ViInt32   rfInputConverter,
							ViInt32   rfOutputConnector,
							ViInt32   rfOutputConverter,
							ViInt32   rfOutputConnector2,
							ViInt32   rfOutputConverter2,
							ViInt32   iqOutputConnector,
							ViInt32   iqOutputConnector2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConnector, RSCMWGS_VAL_RXCONNECTOR_RF1C, RSCMWGS_VAL_RXCONNECTOR_R44C),
    		3, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConverter, RSCMWGS_VAL_RXMODULE_RX1, RSCMWGS_VAL_RXMODULE_RX44),
    		4, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector, RSCMWGS_VAL_TXCONNECTOR_RF1C, RSCMWGS_VAL_TXCONNECTOR_R43O),
    		5, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConverter, RSCMWGS_VAL_TXMODULE_TX1, RSCMWGS_VAL_TXMODULE_TX44),
    		6, "RF Output Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector2, RSCMWGS_VAL_TXCONNECTOR_RF1C, RSCMWGS_VAL_TXCONNECTOR_R43O),
    		7, "RF Output Connector 2");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConverter2, RSCMWGS_VAL_TXMODULE_TX1, RSCMWGS_VAL_TXMODULE_TX44),
    		8, "RF Output Converter 2");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, iqOutputConnector, RSCMWGS_VAL_IQ_CONNECTOR_IQ2O, RSCMWGS_VAL_IQ_CONNECTOR_I48O),
    		9, "IQ Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, iqOutputConnector2, RSCMWGS_VAL_IQ_CONNECTOR_IQ2O, RSCMWGS_VAL_IQ_CONNECTOR_I48O),
    		10, "IQ Converter 2");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld:SCEN:SCFD:EXT %s,%s,%s,%s,%s,%s,%s,%s\n", instance,
                                                                          gs_RFConnectorArr[rfInputConnector],
                                                                          gs_rxModuleArr[rfInputConverter],
                                                                          gs_txConnectorArr[rfOutputConnector],
                                                                          gs_txModuleArr[rfOutputConverter],
                                                                          gs_RFConnectorArr[rfOutputConnector2],
                                                                          gs_txModuleArr[rfOutputConverter2],
                                                                          gs_iqOutConnectorArr[iqOutputConnector],
                                                                          gs_iqOutConnectorArr[iqOutputConnector2]
                                                                          );
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the input and output connectors for the
/// HIFN  generated RF signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR rfInputConnector/Defines the RF input connector.
/// HIPAR rfInputConverter/Defines the RF input converter.
/// HIPAR rfOutputConnector1/Selects the RF output connector.
/// HIPAR rfOutputConverter1/Defines the RF output converter.
/// HIPAR rfOutputConnector2/Selects the RF output connector.
/// HIPAR rfOutputConverter2/Defines the RF output converter.
ViStatus _VI_FUNC rscmwgs_ConfigureBCCHandTCHPDCHScenario(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   rfInputConnector,
                                                          ViInt32   rfInputConverter,
                                                          ViInt32   rfOutputConnector1,
                                                          ViInt32   rfOutputConverter1,
                                                          ViInt32   rfOutputConnector2,
                                                          ViInt32   rfOutputConverter2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConnector, RSCMWGS_VAL_CONN_RF1C, RSCMWGS_VAL_CONN_RFBC),
    		3, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfInputConverter, RSCMWGS_VAL_CONV_RX1, RSCMWGS_VAL_CONV_RX4),
    		4, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector1, RSCMWGS_VAL_CONN_RF1C, RSCMWGS_VAL_CONN_RFAO),
    		5, "RF Output Connector 1");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConverter1, RSCMWGS_VAL_CONV_TX1, RSCMWGS_VAL_CONV_TX4),
    		6, "RF Output Converter 1");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConnector2, RSCMWGS_VAL_CONN_RF1C, RSCMWGS_VAL_CONN_RFAO),
    		7, "RF Output Connector 2");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rfOutputConverter2, RSCMWGS_VAL_CONV_TX1, RSCMWGS_VAL_CONV_TX4),
    		8, "RF Output Converter 2");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld:SCEN:BATC %s,%s,%s,%s,%s,%s\n", instance,
                                                                                       RFConnectorArr[rfInputConnector],
                                                                                       rfInputConverterArr[rfInputConverter],
                                                                                       RFConnectorArr[rfOutputConnector1],
                                                                                       rfOutputConverterArr[rfOutputConverter1],
                                                                                       RFConnectorArr[rfOutputConnector2],
                                                                                       rfOutputConverterArr[rfOutputConverter2]
                                                                                       );
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Enables audio tests involving the "audio measurements"
/// HIFN application. Can only be set, if the downlink signal is switched
/// HIFN OFF.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR speechCodec/Enables the audio tests involving the "audio measurements"
/// HIPAR applicatio
ViStatus _VI_FUNC rscmwgs_ConfigureSpeechCodec(ViSession instrSession,
                                               ViInt32   instance,
                                               ViBoolean speechCodec)
{
        ViStatus error = VI_SUCCESS;
        ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_SIGNALING_SPEECH_CODEC, speechCodec),
    		3, "Speech Codec");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Signal Routing
 * Purpose:  Returns the configured routing settings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QuerySignalRouting(ViSession instrSession,
                                             ViInt32   instance,
                                             ViInt32   *scenario,
                                             ViChar    controller[],
                                             ViInt32   *RFInputConnector,
                                             ViInt32   *RFInputConverter,
                                             ViInt32   *RFOutputConnector1,
                                             ViInt32   *RFOutputConverter1,
                                             ViInt32   *RFOutputConnector2,
                                             ViInt32   *RFOutputConverter2,
                                             ViInt32   *fader)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *pbuffer = NULL;
    ViChar   *p2buf;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, controller), 4, "Controller");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:GSM:SIGN%ld?\n", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &pbuffer));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (pbuffer, ",\r\n");
    *scenario = RsCore_FindStringIndex(scenarioArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    strcpy (controller, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    *RFInputConnector = RsCore_FindStringIndex(RFConnectorArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    *RFInputConverter = RsCore_FindStringIndex(rfInputConverterArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    *RFOutputConnector1 = RsCore_FindStringIndex(RFConnectorArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    *RFOutputConverter1 = RsCore_FindStringIndex(rfOutputConverterArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    if (p2buf != NULL)
        *RFOutputConnector2 = RsCore_FindStringIndex(RFConnectorArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    if (p2buf != NULL)
        *RFOutputConverter2 = RsCore_FindStringIndex(rfOutputConverterArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    if (p2buf != NULL)
        *fader = RsCore_FindStringIndex(gs_faderArr, p2buf);

Error:
    if (pbuffer) free (pbuffer);
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/*****************************************************************************
 * Function: Configure External Attenuation
 * Purpose:  Defines an external attenuation (or gain, if the value is
 *           negative), to be applied to the selected RF input or output
 *           connector (ROUTe:...:CONNector).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureExternalAttenuation(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   path,
                                                       ViReal64  externalAttenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    switch (path)
    {
        case RSCMWGS_VAL_PATH_INPUT:
            viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXTERNAL_ATTENUATION_INPUT, externalAttenuation),
            		4, "External Attenuation");
            break;
        case RSCMWGS_VAL_PATH_OUTPUT1:
            strcat(repCap, ",Out1");
            viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXTERNAL_ATTENUATION_PATH_OUTPUT, externalAttenuation),
            		4, "External Attenuation");
            break;

        case RSCMWGS_VAL_PATH_OUTPUT2:
            strcat(repCap, ",Out2");
            viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXTERNAL_ATTENUATION_PATH_OUTPUT, externalAttenuation),
            		4, "External Attenuation");
            break;

        case RSCMWGS_VAL_PATH_OUTPUT_BCCH:
            viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXTERNAL_ATTENUATION_BCCH_OUTPUT, externalAttenuation),
            		4, "External Attenuation");
            break;

        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, path), 3 ,"Path");
            break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BCCH
 * Purpose:  Configures the GSM channel number and Maximum transmitter
 *           output level for the Broadcast Control Channel (BCCH).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBCCH(ViSession instrSession,
                                        ViInt32   instance,
                                        ViInt32   band,
                                        ViInt32   channel,
                                        ViInt32   pmax)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BCCH_BAND, band),
    		3, "Band");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BCCH_CHANNEL, channel),
    		4, "Channel");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_PMAX_BCCH, pmax),
    		5, "PMax");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures absolute level of the Broadcast Control Channel(BCCH).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR level/BCCH level.
ViStatus _VI_FUNC rscmwgs_ConfigureBCCHLevel(ViSession instrSession,
                                             ViInt32   instance,
                                             ViReal64  level)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BCCH_LEVEL, level),
    		3, "Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables or disables the check of BCCH lower limit of -95 dBm.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_BCCH_ENABLE_LOWER_LIMIT_CHECK
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN      CONFigure:GSM:SIGN:RFSettings:LEVel:BCCH:MINimum:ENABle
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR lowerLimitCheck/Enables or disables the check of BCCH lower limit of -95 dBm.
ViStatus _VI_FUNC rscmwgs_ConfigureBCCHLowerLimitCheck(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViBoolean lowerLimitCheck)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_BCCH_ENABLE_LOWER_LIMIT_CHECK, lowerLimitCheck),
    		3, "Lower Limit Check");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure TCH PDCH
 * Purpose:  Configures the Traffic Channel (TCH, for circuit switched
 *           connections) and the PDCH (Packet Data Channel, for packet
 *           switched connections) that the R&S CMW generates for data
 *           transmission.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureTCHPDCH(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   carrier,
                                           ViInt32   channel,
                                           ViReal64  referenceLevel,
                                           ViInt32   circuitSwitchedPCL)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));
    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_TCH_CIRCUIT_SWITCHED_PCL, circuitSwitchedPCL),
    		6, "Circuit Switched PCL");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,c%ld", instance, carrier);
    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_TCH_CHANNEL_NUMBER, channel),
    		4, "Channel");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_TCH_LEVEL, referenceLevel),
    		5, "Reference Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Hopping
 * Purpose:  Configures the Traffic Channel (TCH, for circuit switched
 *           connections) hopping.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureHopping(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   carrier,
                                           ViBoolean enableHopping,
                                           ViInt32   hoppingMAIO,
                                           ViInt32   hoppingHSN,
                                           ViString  hoppingList)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,c%ld" , instance, carrier);

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_TCH_HOPPING_ENABLE, enableHopping),
    		4, "Enable Hopping");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HOPPING_MAIO, hoppingMAIO),
    		5, "Hopping MAIO");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HOPPING_HSN, hoppingHSN),
    		6, "Hopping HSN");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:RFS:HOPP:SEQ:TCH %ld, %s\n", instance, carrier, hoppingList);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN Configures frequency offset settings for RF.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR downlinkOffset/Sets a frequency offset to be added to the downlink center
/// HIPAR downlinkOffset/frequency of the configured channel
/// HIPAR uplinkOffset/Sets a frequency offset to be added to the uplink center
/// HIPAR uplinkOffset/frequency of the configured channel
ViStatus _VI_FUNC rscmwgs_ConfigureRFFrequencyOffset(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViReal64  downlinkOffset,
                                                     ViReal64  uplinkOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FREQUENCY_OFFSET_DL, downlinkOffset),
    		3, "Downlink Offset");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FREQUENCY_OFFSET_UL, uplinkOffset),
    		4, "Uplink Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure RF Power Uplink
 * Purpose:  Configure the expected uplnik power settings. The expected
 *           nominal power of the UL signal can be defined manually or
 *           calculated automatically, according to the UL power control
 *           settings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureRFPowerUplink(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   powerMode,
                                                 ViReal64  margin,
                                                 ViReal64  expectedPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_EXPECTED_NOMINAL_POWER_MODE, powerMode),
    		3, "Power Mode");

    if(powerMode == RSCMWGS_VAL_MAN)
    {
        viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXPECTED_NOMINAL_POWER_MARGIN, margin),
        		4, "Margin");

        viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXPECTED_NOMINAL_POWER, expectedPower),
        		5, "Expected Power");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Sets the input level offset of the mixer in the analyzer path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mixerLevelOffset/Sets the input level of the mixer in the analyzer path.
ViStatus _VI_FUNC rscmwgs_ConfigureRFPowerUplinkMixerLevelOffset(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  mixerLevelOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_RF_MIXER_LEVEL_OFFSET, mixerLevelOffset),
    		3, "Mixer Level Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Define the value of an external time delay in the output path
/// HIFN and in the input path, so that it can be compensated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR downlinkDelayCompensation/Define the value of an external time delay in the input path, so that it can be compensated.
/// HIPAR uplinkDelayCompensation/Define the value of an external time delay in the output path, so that it can be compensated.
ViStatus _VI_FUNC rscmwgs_ConfigureExternalDelayCompensation(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64  downlinkDelayCompensation,
                                                             ViReal64  uplinkDelayCompensation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXTERNAL_DELAY_COMPENSATION_DL, downlinkDelayCompensation),
    		3, "Downlink Delay Compensation");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_EXTERNAL_DELAY_COMPENSATION_UL, uplinkDelayCompensation),
    		4, "Uplink Delay Compensation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies properties of the baseband signal at the I/Q input.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR path/Selects the path to be configured - only path 1 is relevant in the current software version.
/// HIPAR PEP/Peak envelope power of the incoming baseband signal.
/// HIPAR level/Average level of the incoming baseband signal (without noise).
ViStatus _VI_FUNC rscmwgs_ConfigureIQInput(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   path,
                                           ViReal64  PEP,
                                           ViReal64  level)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 2),
    		3, "Path");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, PEP,
                                              -60.0,
                                              0.0), 4, "PEP");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:IQIN:PATH%ld %.12G,%.12G\n", instance,
                                                                          path,
                                                                          PEP,
                                                                          level
                                                                          );
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries properties of the baseband signal at the I/Q output.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR path/Selects the path to be configured - only path 1 is relevant in the current software version.
/// HIPAR PEP/Peak envelope power of the incoming baseband signal.
/// HIPAR crestFactor/Crest factor of the baseband signal.
ViStatus _VI_FUNC rscmwgs_QueryIQOutput(ViSession instrSession,
                                        ViInt32   instance,
                                        ViInt32   path,
                                        ViReal64  *PEP,
                                        ViReal64  *crestFactor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, 1, 2),
    		3, "Path");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, PEP), 4, "PEP");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, crestFactor), 5, "Crest Factor");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:IQO:PATH%ld?\n", instance, path);
    checkErr(RsCore_QueryViString(instrSession, cmd, buffer));
    checkErr(rscmwgs_CheckStatus(instrSession));
    sscanf (buffer, "%lE,%lE", PEP, crestFactor);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries noise power values, calculated from the downlink power and the AWGN settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR noiseBWPower/Queries the calculated noise power on the downlink channel.
/// HIPAR noiseTotalPower/Queries the total noise power.
/// HIPAR signalPlusNoisePower/Queries the calculated total power (signal + noise) on the downlink channel.
ViStatus _VI_FUNC rscmwgs_QueryFadingSimulatorDLSettings(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViReal64  *noiseBWPower,
                                                         ViReal64  *noiseTotalPower,
                                                         ViReal64  *signalPlusNoisePower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NOISE_BW_POWER, noiseBWPower),
    		3, "Noise BW Power");

    viCheckParm(rscmwgs_GetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NOISE_TOTAL_POWER, noiseTotalPower),
    		4, "Noise Total Power");

    viCheckParm(rscmwgs_GetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_SIGNAL_PLUS_NOISE_POWER, signalPlusNoisePower),
    		3, "Signal Plus Noise Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures internal fading simulator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR state/Enables or disables the fading simulator.
/// HIPAR standard/Selects one of the multipath propagation conditions defined in Annex C.3 of 3GPP TS45.005.
/// HIPAR restartMode/Sets the restart mode of the fading simulator.
/// HIPAR globalSeed/Sets the start seed for the pseudo-random fading algorithm.
ViStatus _VI_FUNC rscmwgs_ConfigureFadingSimulator(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViBoolean state,
                                                   ViInt32   standard,
                                                   ViInt32   restartMode,
                                                   ViInt32   globalSeed)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_STANDARD, standard),
    		4, "Standard");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_RESTART_MODE, restartMode),
    		5, "Restart Mode");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_GLOBAL_SEED, globalSeed),
    		6, "Global Seed");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_ENABLED, state),
    		3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN In manual mode this command restarts the fading process.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_RestartFadingSimulator(ViSession instrSession,
                                                 ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_RESTART, NULL),
    		3, "Fading Simulator Restart");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures insertion loss of fading simulator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mode/Document parameter here.
/// HIPAR userValue/Document parameter here.
ViStatus _VI_FUNC rscmwgs_ConfigureFadingSimulatorInsertionLoss(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   mode,
							ViReal64  userValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS_MODE, mode),
    		3, "Mode");
    if (mode == RSCMWGS_VAL_ILOSS_MODE_USER)
    {
        viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS_USER_VALUE, userValue),
        		4, "User Value");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures the maximum Doppler frequency. In normal mode it is
/// HIFN resulting from the selected fading profile, in user mode the maximum Doppler
/// HIFN frequency is set manualy.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mode/Sets the Doppler shift mode.
/// HIPAR frequency/Sets maximum Doppler frequency for the fading simulator..
ViStatus _VI_FUNC rscmwgs_ConfigureFadingSimulatorDopplerFrequency(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   mode,
							ViReal64  frequency)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS_MODE, mode),
    		3, "Mode");
    if (mode == RSCMWGS_VAL_ILOSS_MODE_USER)
    {
        viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_DOPPLER_FREQUENCY, frequency),
        		4, "Frequency");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries the percentage of clipped samples.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR clippedSamples/Returns the percentage of clipped samples
ViStatus _VI_FUNC rscmwgs_QueryFadingSimulatorClippingCounter(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   *clippedSamples)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_CLIPPING_COUNTER, clippedSamples),
    		3, "Clipped Samples");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the insertion loss for the fading simulator. It is only
/// HIFN  relevant in 'Normal' mode.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:FADing:FSIMulator:ILOSs:LOSS:NORMal?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR insertionLoss/Queries the insertion loss for the fading simulator. It is only
/// HIPAR insertionLoss/relevant in 'Normal' mode.
ViStatus _VI_FUNC rscmwgs_QueryFadingSimulatorInsertionLoss(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64* insertionLoss)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FADING_SIMULATOR_INSERTION_LOSS, insertionLoss),
    		3, "Insertion Loss");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures internal fading AWGN module.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR state/Enables or disables AWGN insertion via the fading module.
/// HIPAR bandwidthRatio/Specifies the minimum ratio between noise bandwidth and channel bandwidth.
/// HIPAR signalToNoiseRatio/Specifies the signal to noise ratio for the AWGN inserted on the internal fading module.
ViStatus _VI_FUNC rscmwgs_ConfigureFadingAWGN(ViSession instrSession,
                                              ViInt32   instance,
                                              ViBoolean state,
                                              ViReal64  bandwidthRatio,
                                              ViReal64  signalToNoiseRatio)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_FADING_AWGN_ENABLED, state),
    		3, "State");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FADING_AWGN_BANDWIDTH_RATIO, bandwidthRatio),
    		4, "Bandwidth Ratio");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FADING_AWGN_SIGNAL_TO_NOISE_RATIO, signalToNoiseRatio),
    		5, "Signal To Noise Ratio");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries the noise bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR noiseBandwidth/Returns the noise bandwidth.
ViStatus _VI_FUNC rscmwgs_QueryFadingAWGNNoiseBandwidth(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViReal64  *noiseBandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_FADING_AWGN_NOISE_BANDWIDTH, noiseBandwidth),
    		3, "Noise Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Enables the setup of a connection between the signaling unit and
/// HIFN the Data Application Unit (DAU), required for IP-based data
/// HIFN tests involving the DAU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR endToEnd/Enables the setup of a connection between the signaling unit and the Data Application Unit (DAU), required for IP-based data tests involving the DAU.
ViStatus _VI_FUNC rscmwgs_ConfigureEndToEnd(ViSession instrSession,
                                            ViInt32   instance,
                                            ViBoolean endToEnd)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_SIGNALING_END_TO_END, endToEnd),
    		3, "End To End");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Connection State
 * Purpose:  This function controls the setup and release of a
 *           circuit-switched GSM connection. Initiates a transition between
 *           different connection states.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConnectionState(ViSession instrSession,
                                          ViInt32   instance,
                                          ViInt32   action)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SIGNALING_CONNECTION_ACTION, action),
    		3, "Action");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Connection State
 * Purpose:  This function returns the connection state of a
 *           circuit-switched GSM connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryConnectionState(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32*  connectionState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SIGNALING_CONNECTION_STATE, connectionState),
    		3, "Connection State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Packet Switched Connection State
 * Purpose:  This function controls the setup and release of a
 *           packet-switched GSM connection. Initiates a transition between
 *           different connection states.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_PacketSwitchedConnectionState(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   action)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SIGNALING_PACKET_SWITCHED_CONNECTION_ACTION, action),
    		3, "Action");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Packet Switched Connection State
 * Purpose:  This function returns the connection state of a packet-switched
 *           GSM connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryPacketSwitchedConnectionState(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32*  connectionState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SIGNALING_PACKET_SWITCHED_CONNECTION_STATE, connectionState),
    		3, "Connection State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Clears the event log.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_ClearEventLog(ViSession instrSession,
                                        ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CLEAN_EVENT_LOG, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


ViStatus _VI_FUNC rscmwgs_QueryEvenetLogLastEntry(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   bufferSize,
                                                  ViChar    timeStamp[],
                                                  ViInt32*  eventCategory,
                                                  ViChar    message[])
{
    return rscmwgs_QueryEventLogLastEntry(instrSession, instance, bufferSize, timeStamp, eventCategory, message);
}

/// HIFN  This function queries the last event log entry.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the  Time
/// HIPAR bufferSize/Stamp and Event Message.
/// HIPAR timeStamp/Timestamp of the entry as string in the format "hh:mm:ss".
/// HIPAR eventCategory/Category of event log entry.
/// HIPAR message/Text string describing the event.
ViStatus _VI_FUNC rscmwgs_QueryEventLogLastEntry(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   bufferSize,
                                                 ViChar    timeStamp[],
                                                 ViInt32*  eventCategory,
                                                 ViChar    message[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   *pbuffer = NULL;
    ViChar   *p2buf;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:ELOG:LAST?\n", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &pbuffer));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (pbuffer, ",\r\n");
    strncpy(timeStamp, p2buf, bufferSize);

    p2buf = strtok (NULL, ",\r\n");
    *eventCategory = RsCore_FindStringIndex(logMessageCategoryArr, p2buf);

    p2buf = strtok (NULL, ",\r\n");
    strncpy(message, p2buf, bufferSize);

Error:
    if(pbuffer != NULL) free(pbuffer);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rscmwgs_QueryEvenetLogAllEntries(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   bufferSize,
                                                   ViChar    timeStamp[],
                                                   ViInt32   eventCategory[],
                                                   ViChar    message[],
                                                   ViInt32*  numberOfEntries)
{
    return rscmwgs_QueryEventLogAllEntries(instrSession, instance, arraySize, bufferSize, timeStamp, eventCategory, message, numberOfEntries);
}

/// HIFN  This function queries the all event log entries.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Number of elements alcoated for array.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the  Time
/// HIPAR bufferSize/Stamp and Event Message.
/// HIPAR timeStamp/Comma separated list of entry timestamps in the format "hh:mm:ss".
/// HIPAR eventCategory/Array of event log category entries.
/// HIPAR message/Comma separated list describing each event.
/// HIPAR numberOfEntries/Number of entries.
ViStatus _VI_FUNC rscmwgs_QueryEventLogAllEntries(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   arraySize,
                                                  ViInt32   bufferSize,
                                                  ViChar    timeStamp[],
                                                  ViInt32   eventCategory[],
                                                  ViChar    message[],
                                                  ViInt32*  numberOfEntries)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *pbuffer = NULL;
    ViChar   *p2buf;
    ViInt32  i = 0;
    ViInt32  TSBufferSize = bufferSize - 1;
    ViInt32  MsgBufferSize = bufferSize - 1;
    ViChar   cmd [RS_MAX_MESSAGE_BUF_SIZE];

	checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:ELOG:ALL?\n", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &pbuffer));
    checkErr(rscmwgs_CheckStatus(instrSession));

    timeStamp[0]='\0';
    message[0]='\0';
    p2buf = strtok (pbuffer, ",\r\n");
    while(p2buf && (i < arraySize))
    {
        if(TSBufferSize)
        {
            strncat(timeStamp, p2buf, TSBufferSize);
            TSBufferSize -= (ViInt32) strlen(p2buf);

            strncat(timeStamp, ",", TSBufferSize--);
        }

        p2buf = strtok (NULL, ",\r\n");
        eventCategory[i] = RsCore_FindStringIndex(logMessageCategoryArr, p2buf);

        p2buf = strtok (NULL, ",\r\n");
        if(MsgBufferSize)
        {
            strncat(message, p2buf, MsgBufferSize);
            MsgBufferSize -= (ViInt32) strlen(p2buf);

            strncat(message, ",", MsgBufferSize--);
        }

        i++;
        p2buf = strtok (NULL, ",\r\n");
    }
    if (strlen(message)>0)
        message[strlen(message)-1] = '\0';
    if (strlen(timeStamp)>0)
            timeStamp[strlen(timeStamp)-1] = '\0';
    *numberOfEntries = i;

Error:
    if(pbuffer != NULL) free(pbuffer);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the time delay of the voice connection.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     -
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     SENSe:GSM:SIGN:CVINfo?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR loopbackDelay/Time delay measured during the loopback connection in seconds.
/// HIPAR downlinkEncoderDelay/Encoder time delay in downlink measured during the connection to the
/// HIPAR downlinkEncoderDelay/speech codec board in seconds.
/// HIPAR uplinkEncoderDelay/Decoder time delay in uplink measured during the connection to the
/// HIPAR uplinkEncoderDelay/speech codec board in seconds.
ViStatus _VI_FUNC rscmwgs_QueryVoiceInfo(ViSession instrSession,
                                         ViInt32   instance,
                                         ViReal64* loopbackDelay,
                                         ViReal64* downlinkEncoderDelay,
                                         ViReal64* uplinkEncoderDelay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:CVIN?\n", instance);
    checkErr(RsCore_QueryTupleViReal64(instrSession, cmd, loopbackDelay, downlinkEncoderDelay, uplinkEncoderDelay, NULL));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Generator State
 * Purpose:  Turns the GSM Signaling generator (DL GSM signal) off or on.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureGeneratorState(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViBoolean cellState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_GENERATOR_STATE, cellState),
    		3, "Cell State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Generator State
 * Purpose:  Returns detailed information about the "GSM Signaling"
 *           generator state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryGeneratorDetailState(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32*  mainState,
                                                    ViInt32*  syncState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR:GSM:SIGN%ld:CELL:STAT:ALL?\n", instance);
    checkErr(RsCore_QueryViString(instrSession, cmd, buffer));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (buffer, ",");
    *mainState = RsCore_FindStringIndex(mainStateArr, p2buf);
    p2buf = strtok (NULL, ",\r\n");
    *syncState = RsCore_FindStringIndex(syncStateArr, p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Measurement Reports
 * Purpose:  Queries the "RX Level Full" or "RX Quality Full"  reported by
 *           the MS as dimensionless index.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReports(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   report,
                                                  ViInt32   *value,
                                                  ViReal64  *lowerRange,
                                                  ViReal64  *upperRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[256] = "";
    ViReal64 dbl_res[2];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, report, RSCMWGS_VAL_RX_LEVEL, RSCMWGS_VAL_RX_QUALITY),
    		3, "Report");

    switch(report)
    {
        case RSCMWGS_VAL_RX_LEVEL:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_LEVEL, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:RXL:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_RX_QUALITY:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_QUALITY, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:RXQ:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        default: break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Measurement Reports Sub
 * Purpose:  This function returns the information that the connected mobile
 *           provides in its periodic "measurement reports".
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsSub(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   report,
                                                     ViInt32   *value,
                                                     ViReal64  *lowerRange,
                                                     ViReal64  *upperRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[256] = "";
    ViReal64 dbl_res[2];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, report, RSCMWGS_VAL_RX_LEVEL, RSCMWGS_VAL_RX_QUALITY),
    		3, "Report");

    switch(report)
    {
        case RSCMWGS_VAL_RX_LEVEL:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_LEVEL_SUB, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:RXL:SUB:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_RX_QUALITY:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_RX_QUALITY_SUB, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:RXQ:SUB:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        default: break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Measurement Reports Count
 * Purpose:  This function returns the number of measurement reports received
 *           since the connection was established.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCount(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   *count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_COUNT, count),
    		3, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the number of blocks that theR&S CMW received in
/// HIFN  the UL since the beginning of the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR receivedBlocks/Returns the number of blocks that theR&S CMW received in the UL since
/// HIPAR receivedBlocks/the beginning of the measurement.
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsReceivedBlocks(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32*  receivedBlocks)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_RECEIVED_BLOCKS, receivedBlocks),
    		3, "Received Blocks");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Measurement Reports C Value
 * Purpose:  This function queries the C value. It is the normalized received
 *           signal level at the MS, averaged over the radio blocks. The
 *           level is expressed in terms of dimensionless numbers ranging
 *           from 0 to 63.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCValue(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   *value,
                                                        ViReal64  *lowerRange,
                                                        ViReal64  *upperRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[256] = "";
    ViReal64 dbl_res[2];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_C_VALUE, value),
    		3, "Value");

    sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:CVAL:RANG?\n", instance);

    checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

    *lowerRange = dbl_res[0];
    *upperRange = dbl_res[1];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Measurement Reports Signal Variance
 * Purpose:  This function queries the variance of the received signal level
 *           within the radio blocks, averaged overall blocks within the MS
 *           reporting period. It is expressed in terms ofdimensionless
 *           values.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsSignalVariance(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   *value,
							ViReal64  *lowerRange,
							ViReal64  *upperRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[256] = "";
    ViReal64 dbl_res[2];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_SIGNAL_VARIANCE, value),
    		3, "Value");

    sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:SVAR:RANG?\n", instance);

    checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

    *lowerRange = dbl_res[0];
    *upperRange = dbl_res[1];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Measurement Reports Mean BEP
 * Purpose:  This function queries the average Bit Error Probability (BEP) of
 *           the radio blocks, averaged over all blocks within the MS
 *           reporting period. Independent MEAN_BEP parameters are available
 *           for the different modulation schemes. In 3GPP TS 45.008 the
 *           parameter is called MEAN_BEP. It is expressed in terms of
 *           dimensionless values.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsMeanBEP(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   modulation,
                                                         ViInt32   *value,
                                                         ViReal64  *lowerRange,
                                                         ViReal64  *upperRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[256] = "";
    ViReal64 dbl_res[2];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulation, RSCMWGS_VAL_BEP_GMSK, RSCMWGS_VAL_BEP_32QAM_HSR),
    		3, "Modulation");

    switch(modulation)
    {
        case RSCMWGS_VAL_BEP_GMSK:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_GMSK_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:GMB:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_8PSK:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_8PSK_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:EMB:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_16QAM_NSR:
            strcat(repCap, ",NSR16QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:NSRQ16:MBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_32QAM_NSR:
            strcat(repCap, ",NSR32QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:NSRQ32:MBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_16QAM_HSR:
            strcat(repCap, ",HSR16QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:HSRQ16:MBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_32QAM_HSR:
            strcat(repCap, ",HSR32QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:HSRQ32:MBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        default: break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the average Bit Error Probability (BEP) of the
/// HIFN  radio blocks, averaged over all blocks within the MS reporting period.
/// HIFN  Modulation independent mean BEP value is cal-
/// HIFN     culated for circuit switched connections.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR value/Shows the average Bit Error Probability.
/// HIPAR lowerRange/Shows the  lower range, corresponding to the "Mean BEP" index
/// HIPAR upperRange/Shows the  upper range, corresponding to the "Mean BEP" index
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsMeanBEPCircuitSwitched(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32*  value,
							ViReal64* lowerRange,
							ViReal64* upperRange)
{
ViStatus error = VI_SUCCESS;
ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
ViChar   buffer[256] = "";
ViReal64 dbl_res[2];
ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_MEAN_BEP, value),
    		3, "Value");

    sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:CSW:MBEP:RANG?\n", instance);

    checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

    *lowerRange = dbl_res[0];
    *upperRange = dbl_res[1];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Measurement Reports CV BEP
 * Purpose:  This function queries the Coefficient of Variation (CV) of the
 *           Bit Error Probability (BEP) of the radio blocks, averaged over
 *           all blocks within the MS reporting period. Independent CV BEP
 *           parameters are available for the different modulation schemes.
 *           In 3GPP TS 45.008 the parameter is called CV_BEP. It is xpressed
 *           in terms of dimensionless values.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCVBEP(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   modulation,
                                                       ViInt32   *value,
                                                       ViReal64  *lowerRange,
                                                       ViReal64  *upperRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[256] = "";
    ViReal64 dbl_res[2];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulation, RSCMWGS_VAL_BEP_GMSK, RSCMWGS_VAL_BEP_32QAM_HSR),
    		3, "Modulation");

    switch(modulation)
    {
        case RSCMWGS_VAL_BEP_GMSK:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_GMSK_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:GCB:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_8PSK:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_8PSK_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:ECB:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_16QAM_NSR:
            strcat(repCap, ",NSR16QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:NSRQ16:CBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_32QAM_NSR:
            strcat(repCap, ",NSR32QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:NSRQ32:CBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_16QAM_HSR:
            strcat(repCap, ",HSR16QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:HSRQ16:CBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        case RSCMWGS_VAL_BEP_32QAM_HSR:
            strcat(repCap, ",HSR32QAM");

            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_QAM_BEP, value),
            		4, "Value");

            sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:HSRQ32:CBEP:RANG?\n", instance);

            checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

            *lowerRange = dbl_res[0];
            *upperRange = dbl_res[1];
        break;

        default: break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the Coefficient of Variation (CV) of the Bit
/// HIFN  Error Probability (BEP) of the radio blocks, averaged over all blocks
/// HIFN  within the MS reporting period.  The coefficient of variation is the
/// HIFN  standard deviation of the measured BEP of the different bursts within
/// HIFN  the block. It vanishes if all bursts have equal BEP.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR value/Shows the  "CV BEP", reported by the MS as dimensionless index.
/// HIPAR lowerRange/Shows the  lower range, corresponding to the "CV BEP" index reported
/// HIPAR lowerRange/by the MS.
/// HIPAR upperRange/Shows the  upper range, corresponding to the "CV BEP" index reported
/// HIPAR upperRange/by the MS.
ViStatus _VI_FUNC rscmwgs_QueryMeasurementReportsCVBEPCircuitSwitched(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32*  value,
							ViReal64* lowerRange,
							ViReal64* upperRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[256] = "";
    ViReal64 dbl_res[2];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORTS_CV_BEP, value),
    		3, "Value");

    sprintf(buffer, "SENS:GSM:SIGN%ld:RREP:CSW:CBEP:RANG?\n", instance);

    checkErr(rscmwgs_GetMeasReport(instrSession, buffer, 2, dbl_res, &count));

    *lowerRange = dbl_res[0];
    *upperRange = dbl_res[1];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Mobile Capabilities
 * Purpose:  This function retrieves information about the connected mobile
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMobileCapabilities(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViChar    imei[],
                                                  ViChar    imsi[],
                                                  ViChar    dialedNumber[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_IMEI,
    		512, imei),
    		3, "IMEI");

    viCheckParm(rscmwgs_GetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_IMSI,
    		512, imsi),
    		4, "IMSI");

    viCheckParm(rscmwgs_GetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_DIALED_NUMBER,
    		512, dialedNumber),
    		5, "Dialed Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function indicates tightened link level performance support of
/// HIFN  the MS.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_MOBILE_CAPABILITIES_EGPRS2
/// HIFN     RSCMWGS_ATTR_MOBILE_CAPABILITIES_GPRS_AND_EGPRS
/// HIFN     RSCMWGS_ATTR_MOBILE_CAPABILITIES_SSCH
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     SENSe:GSM:SIGN:MSSinfo:TCAPability:ETWO?
/// HIFN     SENSe:GSM:SIGN:MSSinfo:TCAPability:GEGPrs?
/// HIFN     SENSe:GSM:SIGN:MSSinfo:TCAPability:SSCHannels?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR egprs2/Indicates tightened link level performance support of the MS EGPRS2.
/// HIPAR gprsandEGPRS/Indicates tightened link level performance support of the MS GPRS and
/// HIPAR gprsandEGPRS/EGPRS.
/// HIPAR ssch/Indicates tightened link level performance support of the MS SSCH.
ViStatus _VI_FUNC rscmwgs_QueryMobileTighterCapabilities(ViSession  instrSession,
                                                         ViInt32    instance,
                                                         ViBoolean* egprs2,
                                                         ViBoolean* gprsandEGPRS,
                                                         ViBoolean* ssch)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_EGPRS2, egprs2),
    		3, "EGPRS2");

    viCheckParm(rscmwgs_GetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_GPRS_AND_EGPRS, gprsandEGPRS),
    		4, "GPRS and EGPRS");

    viCheckParm(rscmwgs_GetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_SSCH, ssch),
    		5, "SSCG");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the IPv4 address (<n> = 4) or the IPv6 prefix (<n> = 6)
/// HIFN assigned to the MS by the R&S CMW.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR IPVersion/Selects IP version.
/// HIPAR arraySize/Defines size of IP Address array.
/// HIPAR IPAddress/Returns the IPv4 address (<n> = 4) or the IPv6 prefix (<n> = 6) assigned to the MS by the R&S CMW.
ViStatus _VI_FUNC rscmwgs_QueryMobileIPAddress(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   IPVersion,
                                               ViInt32   arraySize,
                                               ViChar    IPAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IPVersion, 0, 1),
    		3, "IP Version");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,%s", instance, ipVersionArr[IPVersion]);

    viCheckParm(rscmwgs_GetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_IP_ADDRESS,
    		arraySize, IPAddress),
    		5, "IP Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Multislot Class
 * Purpose:  Queries multislot class of the mobile station in (E)GPRS and
 *           Dual Transfer Mode (DTM) as defined in 3GPP TS 45.002, Annex B.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryMultislotClass(ViSession instrSession,
                                              ViInt32   instance,
                                              ViInt32   mode,
                                              ViInt32   *multislotClass)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString MSStandardArr[] = {",GPRS", ",EGPRS", ",DTMGPRS", ",DTMEGPRS"};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSCMWGS_VAL_GPRS, RSCMWGS_VAL_DTM_EGPRS),
    		3, "Mode");

    strcat(repCap, MSStandardArr[mode]);

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_MULTISLOT_CLASS, multislotClass),
    		4, "Multislot Class");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the access point name of the gateway to the PS domain.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Sets the number of values allocated for 'APN Gateway' array.
/// HIPAR APNGateway/Indicates the quality of the received uplink power.
ViStatus _VI_FUNC rscmwgs_QueryAPNGateway(ViSession instrSession,
                                          ViInt32   instance,
                                          ViInt32   arraySize,
                                          ViChar    APNGateway[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_APN,
    		arraySize, APNGateway),
    		4, "APN Gateway");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Indicates the quality of the received uplink power.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR RXPower/Indicates the quality of the received uplink power.
ViStatus _VI_FUNC rscmwgs_QueryRXPower(ViSession instrSession,
                                       ViInt32   instance,
                                       ViInt32   *RXPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_RX_POWER, RXPower),
    		4, "RX Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Band Power Class
 * Purpose:  Queries the supported GSM band(s), support indicators for UMTS
 *           and CDMA2000 and the power class.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryBandPowerClass(ViSession instrSession,
                                              ViInt32   instance,
                                              ViInt32   arraySize,
                                              ViInt32   values[],
                                              ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *pbuffer = NULL;
    ViChar   *p2buf;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  i=0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, arraySize, 1, 32001),
    		3, "arraySize");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:MSS:BAND?\n", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &pbuffer));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (pbuffer, ",\r\n");

    if (strncmp (p2buf, "INV", 3) == 0)
    {
        values[i++] = RSCMW_NAN_VI_INT32;
    }
    else
    {
        while(p2buf != NULL)
        {
            if(i < arraySize)
            {
				if (strcmp (p2buf, "OFF") == 0)
                    values[i] = 0;
				else
                    values[i] = 1;
				i++;

				if((i != 19) && (i != 27) && (i != 28) && (i != 29) && (i != 30) && (i != 31))
				{
				   //GSMK
				   p2buf = strtok (NULL, ",\r\n");
				   values[i] = atoi(p2buf);
				   i++;

				   //8PSK
				   if(i != 21)
				   {
				    p2buf = strtok (NULL, ",\r\n");
				    values[i] = RsCore_FindStringIndex(powerClassArr, p2buf);
				    i++;
				   }
				}
            }
            p2buf = strtok (NULL, ",\r\n");
        }
    }
    *returnedValues = i;

Error:
    if (pbuffer) free (pbuffer);
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN Returns the service category during emergency call.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR values/Array of emergency services.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwgs_QueryEmergencyCallServiceCategory(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   arraySize,
                                                            ViBoolean values[],
                                                            ViInt32   *returnedValues)
{
    ViStatus  error = VI_SUCCESS;
    ViBoolean *pbuffer = NULL;
    ViChar    cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32   dataSize;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, arraySize, 1, 2000000),
    		3, "arraySize");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:MSS:SCAT?\n", instance);
    checkErr(RsCore_QueryAsciiViBooleanArray(instrSession, cmd, &pbuffer, &dataSize));

	checkErr(rscmwgs_CheckStatus(instrSession));

	if ((size_t)arraySize >= (size_t)dataSize)
		memcpy(values, pbuffer, (size_t)(dataSize * sizeof(ViBoolean)));
	else
		memcpy(values, pbuffer, (arraySize * sizeof(ViBoolean)));

	if (returnedValues)
		*returnedValues = dataSize;

Error:
    if (pbuffer) free (pbuffer);
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN Returns support indicators for extended dynamic allocation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR GPRS/Support of extended dynamic allocation in GPRS mode.
/// HIPAR EGPRS/Support of extended dynamic allocation in EGPRS mode.
ViStatus _VI_FUNC rscmwgs_QueryExtendedDynamicAllocationSupport(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean *GPRS,
							ViBoolean *EGPRS)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   *p2buf;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, GPRS), 3, "GPRS");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, EGPRS), 4, "EGPRS");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:MSS:EDAL?\n", instance);
    checkErr(RsCore_QueryViString(instrSession, cmd, buffer));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (buffer, ",");
    *GPRS = strcmp (p2buf, "ON") == 0;
    p2buf = strtok (NULL, ",");
    *EGPRS = strcmp (p2buf, "ON") == 0;

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns codec list supported by the UE in GSM and UMTS networks.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR network/Sets the network.
/// HIPAR codecList/Indicates which codec the UE supports in UMTS and GSM networks.
/// HIPAR Array of 14 values is returned.
ViStatus _VI_FUNC rscmwgs_QueryCodecListSupport(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   network,
                                                ViBoolean codecList[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   *p2buf;
    ViInt32  i=0;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, network, 0, 1),
    		3, "Network");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, codecList), 4, "Codec List");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENSe:GSM:SIGN%ld:MSS:COD:%s?\n", instance, networkArr[network]);
    checkErr(RsCore_QueryViString(instrSession, cmd, response));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (response, ",\n");
    while (p2buf != NULL)
    {
        codecList[i] = (strcmp (p2buf, "ON") == 0);
        p2buf = strtok (NULL, ",\n");
        i++;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Indicates the VAMOS support of the MS and the VAMOS level supported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR vamosLevel/Indicates the VAMOS support of the MS and the VAMOS level supported.
ViStatus _VI_FUNC rscmwgs_QueryVAMOSLevel(ViSession instrSession,
                                          ViInt32   instance,
                                          ViInt32*  vamosLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MOBILE_CAPABILITIES_VAMOS_LEVEL, vamosLevel),
    		3, "VAMOS Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Network Identity
 * Purpose:  This function configures the Network "Identity" parameters that
 *           characterize the radio network simulated by the R&S CMW.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkIdentity(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   cellIdentity,
                                                   ViInt32   mcc,
                                                   ViInt32   mncDigits,
                                                   ViInt32   mnc,
                                                   ViInt32   lac,
                                                   ViInt32   rac,
                                                   ViInt32   ncc,
                                                   ViInt32   bcc)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

	viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_CELL, cellIdentity),
			3, "MCC");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_MCC, mcc),
    		4, "MCC");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_MNC, mnc),
    		5, "MNC");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_MNC_DIGITS, mncDigits),
    		6, "MNC Digits");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_LAC, lac),
    		7, "LAC");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_RAC, rac),
    		8, "RAC");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_NCC, ncc),
    		9, "NCC");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_IDENTITY_BCC, bcc),
    		10, "BCC");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Network MS Identity
 * Purpose:  This function defines the default IMSI which is used to set up
 *           the connection if the mobile does not initiate a location update
 *           (CONFigure:GSM:SIGN:CELL:LUPDate AUTO).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkMSIdentity(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   mcc,
                                                     ViInt32   mnc,
                                                     ViString  msin)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

	checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CELL:IMSI %ld,%ld,%s\n", instance, mcc, mnc, msin);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Network Requested Mobile Data
 * Purpose:  This functions defines which parameters of the mobile station
 *           are requested during location update.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkRequestedMobileData(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean imeiRequest,
							ViBoolean authenticationRequest,
							ViBoolean imsiRequest,
							ViBoolean classmarkRequest)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REQUESTED_IMEI, imeiRequest),
    		3, "IMEI Request");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REQUESTED_AUTHENTICATION, authenticationRequest),
    		4, "Authentication Request");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REQUESTED_IMSI, imsiRequest),
    		5, "IMSI Request");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REQUESTED_CLASSMARK, classmarkRequest),
    		6, "Classmark Request");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Network Cell
 * Purpose:  This function configures the radio link for connection setup.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCell(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   locationUpdate,
                                               ViInt32   bsAGBLKSRES,
                                               ViInt32   bsPAMFRMS,
                                               ViBoolean msDTXAllowed,
                                               ViInt32   bandIndicator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_LOCATION_UPDATE, locationUpdate),
    		3, "Location Update");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_BS_AG_BLKS_RES, bsAGBLKSRES),
    		4, "BS AG BLKS RES");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_BS_PA_MFRMS, bsPAMFRMS),
    		5, "BS PA MFRMS");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_MS_DTX, msDTXAllowed),
    		6, "MS DTX Allowed");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_BAND_INDICATOR, bandIndicator),
    		7, "Band Indicator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Enables/ disables extended coverage GSM IoT.
/// HIRET Document return value here.
/// HIRET You may use multiple lines for documentation.
/// HIPAR instrSession/Document parameter here.
/// HIPAR instance/Document parameter here.
/// HIPAR ECGSMIoT/Document parameter here.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellECGSMIoT(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViBoolean ECGSMIoT)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_EC_GSM_IOT_ENABLED, ECGSMIoT),
    		3, "EC GSM IoT Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Selects the type of the used SIM card.
/// HIRET Document return value here.
/// HIRET You may use multiple lines for documentation.
/// HIPAR instrSession/Document parameter here.
/// HIPAR instance/Document parameter here.
/// HIPAR SIMCardType/Document parameter here.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellSIMCardType(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   SIMCardType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_SIM_CARD_TYPE, SIMCardType),
    		3, "SIM Card Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN Defines the secret key Ki as 32-digit hexadecimal number. Leading zeros can be omitted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR KIValue/Defines the secret key Ki as 32-digit hexadecimal number. Leading zeros can be omitted.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellKIValue(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViString  KIValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd [RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CELL:SEC:SKEY #H%s", instance, KIValue);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function activates/deactivates early clasmark sending as defined
/// HIFN  in 3GPP TS 44.018.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enable/Activates/deactivates early clasmark sending as defined in 3GPP TS
/// HIPAR enable/44.018.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellEarlyClassmarkSending(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_EARLY_CLASSMARK_SENDING, enable),
    		3, "Enable");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Basic parameters of the GSM cell.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR pageMode/Selects paging mode.
/// HIPAR NCCPermitted/Specifies the neighbor cell by its Network Color Code (NCC) that the MS is allowed to measure.
/// HIPAR maxRetrans/Maximum no. of the DL retransmissions.
/// HIPAR pagingWithMSIdentity/Selects the MS identity used by paging.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellExtended(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   pageMode,
                                                       ViInt32   NCCPermitted,
                                                       ViInt32   maxRetrans,
                                                       ViInt32   pagingWithMSIdentity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_PAGE_MODE, pageMode),
    		3, "Page Mode");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_NCC_PERMITTED, NCCPermitted),
    		4, "NCC Permitted");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_MAX_RETRANS, maxRetrans),
    		5, "Max Retrans");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_PAGING_WITH_MS_IDENTITY, pagingWithMSIdentity),
    		6, "Paging With MS Identity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the MS transmit level reduction at the very beginning of the
/// HIFN  connection before the standard power control algorithm starts. The
/// HIFN  power reduction only applies for the first transmission of the access
/// HIFN  burst on the RACH as defined in 3GPP TS 45.008.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enable/Enables/disables or the Intitial Power Reduction.
/// HIPAR value/Specifies the MS transmit level reduction for the RACH at the very
/// HIPAR value/beginning of the connection before the standard power control algorithm
/// HIPAR value/starts.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellInitialPowerReduction(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   enable,
							ViInt32   value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, enable, RSCMWGS_VAL_OFF, RSCMWGS_VAL_VALUE),
    		3, "Enable");

    if (enable == RSCMWGS_VAL_VALUE)
    {
        viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_INITIAL_POWER_REDUCTION_VALUE, value),
        		4, "Value");
    }
    else
    {
        viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap,
            RSCMWGS_ATTR_NETWORK_CELL_INITIAL_POWER_REDUCTION_ENABLED, (ViBoolean) enable), 3, "enable");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables/disables the MS to camp to the R&S CMW cell.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR cellBaring/Enables/disables the MS to camp to the R&S CMW cell.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellBaring(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViBoolean cellBaring)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_BARING, cellBaring),
    		3, "Cell Baring");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Network Cell Circuit Switched
 * Purpose:  This function configures the circuit switched network cell
 *           settings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellCircuitSwitched(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean earlyClassmarkSending)
{
    instrSession;
    instance;
    earlyClassmarkSending;
    return RS_ERROR_FUNCTION_NOT_SUPPORTED;
}

/*****************************************************************************
 * Function: Configure Network Cell Packet Switched Domain State
 * Purpose:  This function enables or disables the support of packet switched
 *           connections by the emulated cell.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetwokCellPacketSwitchedDomainState(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean cellState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_CONECTIONS_ENABLE, cellState),
    		3, "Cell State");

Error:
	(void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If enabled, the R&S CMW allows only the default IMSI to execute
/// HIFN  location update and attach.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_NETWORK_CELL_IMSI_FILTER
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CELL:IMSI:FILTer
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR imsiFilter/If enabled, the R&S CMW allows only the default IMSI to execute
/// HIPAR imsiFilter/location update and attach.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellIMSIFilter(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViBoolean imsiFilter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_IMSI_FILTER, imsiFilter),
    		3, "IMSI Filter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the support of GPRS or EGPRS in packet domain.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_NETWORK_CELL_SUPPORT
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CELL:NSUPport
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR support/Selects the support of GPRS or EGPRS in packet domain.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellSupport(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   support)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_SUPPORT, support),
    		3, "Support");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables MS enhanced measurement reports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enhancedMeasurementReport/Enables or disables MS enhanced measurement reports.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellCircuitSwitchedEnhancedMeasurementReport(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enhancedMeasurementReport)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_CIRCUIT_SWITCHED_ENHANCED_MEASUREMENT_REPORT, enhancedMeasurementReport),
    		3, "Enhanced Measurement Report");

Error:
	(void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Network Cell Packet Switched
 * Purpose:  This function configures the packet switched network cell
 *           settings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellPacketSwitched(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   pdpContextActivation,
                                                             ViInt32   signalLevelFilterPeriod,
                                                             ViInt32   bepPeriod,
                                                             ViInt32   pcMeasChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
             signalLevelFilterPeriod;
             bepPeriod;
             pcMeasChannel;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_PDP_CONTEXT_ACTIVATION, pdpContextActivation),
    		3, "PDP Context Activation");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_SIGNAL_LEVEL_FILTER_PERIOD, signalLevelFilterPeriod),
    		4, "Signal Level Filter Period");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_BEP_PERIOD, bepPeriod),
    		5, "BEP Period");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_PACKET_SWITCHED_PC_MEAS_CHANNEL, pcMeasChannel),
    		6, "PC Meas Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Network Timers And Constants
 * Purpose:  This function configures the parameters that control the timing
 *           of the connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimersAndConstants(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   radiolinkTimeoutMS,
                                                             ViInt32   radiolinkTimeoutBS,
                                                             ViInt32   t3212,
                                                             ViInt32   t3312,
                                                             ViInt32   alertingTimeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_RADIOLINK_TIMEOUT_MS, radiolinkTimeoutMS),
    		3, "Radiolink Timeout MS");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_RADIOLINK_TIMEOUT_BS, radiolinkTimeoutBS),
    		4, "Radiolink Timeout BS");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIMER_T3212, t3212),
    		5, "T3212");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIMER_T3312, t3312),
    		6, "T3312");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_ALERTING_TIMEOUT, alertingTimeout),
    		7, "Alerting Timeout");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the time period of R&S CMW alerting state.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_NETWORK_MOC_ALERTING_TIMEOUT
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CELL:ATIMeout:MOC
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mocAlertingTimeout/This control defines the mobile originated call alerting timeout
/// HIPAR mocAlertingTimeout/value.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkMOCAlertingTimer(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   mocAlertingTimeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_MOC_ALERTING_TIMEOUT, mocAlertingTimeout),
    		3, "MOC Alerting Timeout");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Sets the immediate assignment reject timers for CS (T3122) / PS(T3142).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR t3122/Sets the immediate assignment reject timers for CS (T3122).
/// HIPAR t3142/Sets the immediate assignment reject timers for PS (T3142).
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkImmediateAssignmentTimers(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   t3122,
							ViInt32   t3142)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIMER_T3122, t3122),
    		3, "T3122");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIMER_T3142, t3142),
    		3, "T3142");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the TBF release timer for PS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR t3192/Defines the TBF release timer for PS.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkReleaseTimer(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   t3192)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_RELEASE_TIMER_T3192, t3192),
    		3, "t3192");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the rejection of location update requests and
/// HIFN     attach requests received from the MS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR locationUpdate/Enables or disables the rejection of location update requests and
/// HIPAR locationUpdate/selects the rejection cause to be transmitted.
/// HIPAR gmmAttach/Enables or disables the rejection of location update requests and
/// HIPAR gmmAttach/selects the rejection cause to be transmitted.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkRejectCauses(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   locationUpdate,
                                                       ViInt32   gmmAttach,
                                                       ViInt32   cmService)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_LOCATION_UPDATE, locationUpdate),
    		3, "Location Update");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_GMM_ATTACH, gmmAttach),
    		4, "Gmm Attach");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_CM_SERVICE, cmService),
    		5, "CM Service");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables or disables the rejection of routing area update requests and
/// HIFN  selects the rejection cause to be transmitted.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_GMM_ROUTING_AREA
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CELL:RCAuse:RAUPdate
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR cause/Enables or disables the rejection of routing area update requests and
/// HIPAR cause/selects the rejection cause to be transmitted.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkGmmRoutingAreaRejectCause(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   cause)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_GMM_ROUTING_AREA, cause),
    		3, "Cause");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies, to which type of CM service a request reject applies.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_CM_TYPE
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CELL:RCAuse:CSTYpe
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR cmType/Specifies, to which type of CM service a request reject applies.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkRejectCausesCMType(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   cmType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_REJECT_CAUSES_CM_TYPE, cmType),
    		3, "CM Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN defines the cell reselection information to be transmitted in
/// HIFN the BCCH.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR rxLevMinAccess/Defines the minimum RX level at an MS antena required for access
/// HIPAR                to the GSM cell.
/// HIPAR qRxLevMinEUTRAN/Defines the minimum RX level at a UE antena required for access
/// HIPAR                 to the LTE cell.
/// HIPAR qRxLevMinUTRAN/Defines the minimum RX level at a UE antena required for access
/// HIPAR                to the UMTS cell.
/// HIPAR tReselection/Sets the time hysteresis for the cell reselection algorithm.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellReselection(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViReal64  rxLevMinAccess,
                                                          ViReal64  qRxLevMinEUTRAN,
                                                          ViReal64  qRxLevMinUTRAN,
                                                          ViInt32   tReselection)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_QUALITY_RXLEVMIN_ACCESS, rxLevMinAccess),
    		3, "RXLevMin Access");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_QUALITY_RXLEVMIN_EUTRAN, qRxLevMinEUTRAN),
    		4, "RXLevMin E-UTRAN");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_QUALITY_RXLEVMIN_UTRAN, qRxLevMinUTRAN),
    		5, "RXLevMin UTRAN");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_TRESELECTION, tReselection),
    		6, "T Reselection");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN Sets the hysteresis for the cell reselection algorithm.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR hysteresis/Sets the hysteresis for the cell reselection algorithm.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellReselectionHysteresis(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));
    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap,
        RSCMWGS_ATTR_NETWORK_CELL_RESELECTION_HYSTERESIS, (ViInt32)hysteresis), 3, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies the allowed DL traffic channels within the simulated GSM cell.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Defines size of array passed in parameter 'Allowed Channels'.
/// HIPAR allowedChannels/64 entries: one or several channel numbers in parallel or OFF.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellAllowedDLChannels(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32   allowedChannels[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *p2buf;
    ViInt32  i=0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CELL:CDES ", instance);
    for (i = 0; i < arraySize; i++)
    {
        if (allowedChannels[i] == -1)
            p2buf += sprintf (p2buf, "OFF,");
        else
            p2buf += sprintf (p2buf, "%ld,", allowedChannels[i]);
    }

    *p2buf = '\0';

    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN Specifies the handling of the MS originating CS/PS connection request.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR connectionType/Selects the connection type.
/// HIPAR connectionRequest/Selects connection request mode.
/// HIPAR acceptAfter/Defines connection handling if connection request is set to Ignore.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellConnectionRequest(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   connectionType,
							ViInt32   connectionRequest,
							ViInt32   acceptAfter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd [RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, connectionType, RSCMWGS_VAL_CS, RSCMWGS_VAL_PS),
    		3, "Connection Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, connectionRequest, RSCMWGS_VAL_CONNECTION_REQUEST_REJECT, RSCMWGS_VAL_CONNECTION_REQUEST_IGNORE),
    		4, "Connection Request");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, acceptAfter, 0, 7),
    		5, "Accept After");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CELL:%s:CREQ %s", instance,
             gs_ConnectionTypeArr[connectionType],
             gs_ConnectionRequestArr[connectionRequest]
             );

    if (connectionRequest == RSCMWGS_VAL_CONNECTION_REQUEST_IGNORE)
    {
        if (acceptAfter == 0)
        {
            strcat (cmd, ",IALL\n");
        }
        else
        {
            sprintf (p2buf, ",AA%ld\n", acceptAfter);
        }
    }
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures synchronization for the signaling application.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR offset/Configures the timing offset relative to the time zone.
/// HIPAR zone/Selects connection request mode.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkCellSynchronization(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  offset,
							ViInt32   zone)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_SYNCHRONIZATION_OFFSET, offset),
    		3, "Offset");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_CELL_SYNCHRONIZATION_ZONE, zone),
    		4, "Zone");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures the high threshold value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR setFor/Defines the threshold is set for.
/// HIPAR threshold/Defines the threshold value.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellThreshold(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   setFor,
							ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    switch (setFor){
        case RSCMWGS_VAL_NCELL_THRESHOLD_MODE_ALL:
            viCheckParm(RsCore_InvalidViReal64Range(instrSession, threshold, 0.0, 31.0), 4, "Threshold");
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:NCELl:ALL:THR:HIGH ON,%le\n", instance, threshold);
            checkErr(RsCore_Write(instrSession, cmd));
            checkErr(rscmwgs_CheckStatus(instrSession));
        break;
        case RSCMWGS_VAL_NCELL_THRESHOLD_MODE_LTE:
            viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NEIGHBOR_CELL_THRESHOLD_LTE, threshold),
            		4, "Threshold");
        break;
        case RSCMWGS_VAL_NCELL_THRESHOLD_MODE_WCDMA:
            viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NEIGHBOR_CELL_THRESHOLD_WCDMA, threshold),
            		4, "Threshold");
        break;
        case RSCMWGS_VAL_NCELL_THRESHOLD_MODE_TDSCDMA:
            viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NEIGHBOR_CELL_THRESHOLD_TDSCDMA, threshold),
            		4, "Threshold");
        break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, setFor), 3, "Set For");
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures an entry of the neighbor cell list for GSM.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of the entry.
/// HIPAR state/Enables or disables the entry.
/// HIPAR band/This control sets the band.
/// HIPAR channel/Defines the channel number used for the Broadcast Control Channel
/// HIPAR measurementEnabled/Enables or disables the MS neighbor cell measurement.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellGSM(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   number,
                                                          ViBoolean state,
                                                          ViInt32   band,
                                                          ViInt32   channel,
                                                          ViBoolean measurementEnabled,
                                                          ViInt32   BSIC)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 16),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMW_VAL_NCELL_GSM_BAND_G085, RSCMW_VAL_NCELL_GSM_BAND_G19),
    		5, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, BSIC, 0, 63),
    		8, "BSIC");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:NCEL:GSM:CELL%ld %s,%s,%ld,%s,%ld\n",
                                        instance,
                                        number,
                                        (state==VI_FALSE)?"OFF":"ON",
                                        gsmNcellBandArr[band],
                                        channel,
                                        measurementEnabled ? "ON":"OFF",
                                        BSIC);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures an entry of the neighbor cell list for LTE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of the entry.
/// HIPAR state/Enables or disables the entry.
/// HIPAR band/This control sets the band.
/// HIPAR channel/Defines the downlink channel number.
/// HIPAR cellID/Defines the channel number used for the Broadcast ControlChannel
/// HIPAR measurementEnabled/Enables or disables the MS neighbor cell measurement.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellLTE(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   number,
                                                          ViBoolean state,
                                                          ViInt32   band,
                                                          ViInt32   channel,
                                                          ViInt32   cellID,
                                                          ViBoolean measurementEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMW_VAL_NCELL_LTE_BAND_OB1, RSCMW_VAL_NCELL_LTE_BAND_OB255),
    		5, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 0, 45589),
    		6, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cellID, 0, 503),
    		7, "Cell ID");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:NCEL:LTE:CELL%ld %s,%s,%ld,%ld,%s\n",
                                        instance,
                                        number,
                                        (state==VI_FALSE)?"OFF":"ON",
                                        lteNcellBandArr[band],
                                        channel,
                                        cellID,
                                        measurementEnabled ? "ON":"OFF");
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures an entry of the neighbor cell list for WCDMA.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of the entry.
/// HIPAR state/Enables or disables the entry.
/// HIPAR band/This control sets the band.
/// HIPAR channel/Defines the downlink channel number.
/// HIPAR scramblingCode/Primary scramblig code in hex format.
/// HIPAR measurementEnabled/Enables or disables the MS neighbor cell measurement.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellWCDMA(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   number,
                                                            ViBoolean state,
                                                            ViInt32   band,
                                                            ViInt32   channel,
                                                            ViInt32   scramblingCode,
                                                            ViBoolean measurementEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMW_VAL_NCELL_WCDMA_BAND_OB1, RSCMW_VAL_NCELL_WCDMA_BAND_OB26),
    		5, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 412, 11000),
    		6, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, scramblingCode, 0x0, 0x1FF),
    		7, "Scrambling Code");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:NCEL:WCDM:CELL%ld %s,%s,%ld,#H%lX,%s\n",
                                        instance,
                                        number,
                                        (state==VI_FALSE)?"OFF":"ON",
                                        wcdmaNcellBandArr[band],
                                        channel,
                                        scramblingCode,
                                        measurementEnabled ? "ON":"OFF");
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures an entry of the neighbor cell list for TD-SCDMA.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of the entry.
/// HIPAR state/Enables or disables the entry.
/// HIPAR band/This control sets the band.
/// HIPAR channel/Defines the downlink channel number.
/// HIPAR scramblingCode/Primary scramblig code in hex format.
/// HIPAR measurementEnabled/Enables or disables the MS neighbor cell measurement.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkNeighborCellTDSCDMA(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViBoolean state,
							ViInt32   band,
							ViInt32   channel,
							ViInt32   scramblingCode,
							ViBoolean measurementEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMW_VAL_NCELL_TDSCDMA_BAND_OB1, RSCMW_VAL_NCELL_TDSCDMA_BAND_OB3),
    		5, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 9404, 11996),
    		6, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, scramblingCode, 0x0, 0x7F),
    		7, "Scrambling Code");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:NCEL:TDSC:CELL%ld %s,%s,%ld,#H%lX,%s\n",
                                        instance,
                                        number,
                                        (state==VI_FALSE)?"OFF":"ON",
                                        gs_TDSCDMANcellBandArr[band],
                                        channel,
                                        scramblingCode,
                                        measurementEnabled ? "ON":"OFF");
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the RSSI value reported for a selected GSM neighbor cell as dimensionless index.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of GSM neighbor cell.
/// HIPAR RSSI/Returns the RSSI value reported for a selected GSM neighbor cell as dimensionless index.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellGSMRSSI(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   number,
                                                          ViInt32   *RSSI)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 16),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSSI), 4, "RSSI");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:GSM:CELL%ld?", instance, number);
    checkErr(RsCore_QueryViInt32(instrSession, cmd, RSSI));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the value range corresponding to the dimensionless RSSI index value reported for a selected GSM neighbor cell.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of GSM neighbor cell.
/// HIPAR RSSIMin/RSSI minimum value.
/// HIPAR RSSIMax/RSSI maximum value.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellGSMRSSIRange(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViReal64  *RSSIMin,
							ViReal64  *RSSIMax)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 16),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSSIMin), 4, "RSSI Min");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSSIMax), 5, "RSSI Max");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:GSM:CELL%ld:RANG?", instance, number);
	checkErr(RsCore_QueryTupleViReal64(instrSession, cmd, RSSIMin, RSSIMax, NULL, NULL));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns measurement report values for a selected LTE neighbor cell.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of LTE neighbor cell.
/// HIPAR RSRP/RSRP as dimensionless index.
/// HIPAR RSRQ/RSRQ as dimensionless index.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellLTERSRPRSRQ(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViInt32   *RSRP,
							ViInt32   *RSRQ)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSRP), 4, "RSRP");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSRQ), 5, "RSRQ");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:LTE:CELL%ld?", instance, number);
	checkErr(RsCore_QueryTupleViInt32(instrSession, cmd, RSRP, RSRQ, NULL, NULL));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Document your function here.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of LTE neighbor cell.
/// HIPAR RSRPMin/RSRP minimum value.
/// HIPAR RSRPMax/RSRP maximum value.
/// HIPAR RSRQMin/RSRQ minimum value.
/// HIPAR RSRQMax/RSRQ maximum value.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellLTERSRPRSRQRange(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViReal64  *RSRPMin,
							ViReal64  *RSRPMax,
							ViReal64  *RSRQMin,
							ViReal64  *RSRQMax)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSRPMin), 4, "RSRP Min");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSRPMax), 5, "RSRP Max");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSRQMin), 6, "RSRQ Min");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSRQMax), 7, "RSRQ Max");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:LTE:CELL%ld:RANG?", instance, number);
	checkErr(RsCore_QueryTupleViReal64(instrSession, cmd, RSRPMin, RSRPMax, RSRQMin, RSRQMax));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Document your function here.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of WCDMA neighbor cell.
/// HIPAR RSCP/RSCP as dimensionless index.
/// HIPAR ecNo/Ec/No as dimensionless index.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellWCDMARSCPEcNo(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViInt32   *RSCP,
							ViInt32   *ecNo)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSCP), 4, "RSCP");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, ecNo), 5, "Ec/No");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:WCDM:CELL%ld?", instance, number);
	checkErr(RsCore_QueryTupleViInt32(instrSession, cmd, RSCP, ecNo, NULL, NULL));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the value ranges corresponding to the dimensionless index values reported for a selected WCDMA neighbor cell.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of WCDMA neighbor cell.
/// HIPAR RSCPMin/RSCP minimum value.
/// HIPAR RSCPMax/RSCP maximum value.
/// HIPAR ecNoMin/Ec/No minimum value.
/// HIPAR ecNoMax/Ec/No maximum value.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellWCDMARSCPEcNoRange(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViReal64  *RSCPMin,
							ViReal64  *RSCPMax,
							ViReal64  *ecNoMin,
							ViReal64  *ecNoMax)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSCPMin), 4, "RSCP Min");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSCPMax), 5, "RSCP Max");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, ecNoMin), 6, "Ec/No Min");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, ecNoMax), 7, "Ec/No Max");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:WCDM:CELL%ld:RANG?", instance, number);
	checkErr(RsCore_QueryTupleViReal64(instrSession, cmd, RSCPMin, RSCPMax, ecNoMin, ecNoMax));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the RSCP value reported for a selected TD-SCDMA neighbor cell as dimensionless index.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of TD-SCDMA neighbor cell.
/// HIPAR RSCP/Returns the RSCP value reported for a selected TD-SCDMA neighbor cell as dimensionless index.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellTDSCDMARSCP(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViInt32   *RSCP)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSCP), 4, "RSCP");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:TDSC:CELL%ld?", instance, number);
	checkErr(RsCore_QueryViInt32(instrSession, cmd, RSCP));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the value range corresponding to the dimensionless RSCP index value reported for a selected TD-SCDMA neighbor cell.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR number/Number of TD-SCDMA neighbor cell.
/// HIPAR RSCPMin/RSCP minimum value.
/// HIPAR RSCPMax/RSCP maximum value.
ViStatus _VI_FUNC rscmwgs_QueryNetworkNeighborCellTDSCDMARSCPRange(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   number,
							ViReal64  *RSCPMin,
							ViReal64  *RSCPMax)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, number, 1, 4),
    		3, "Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSCPMin), 4, "RSCP Min");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RSCPMax), 5, "RSCP Max");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:RREP:NCEL:TDSC:CELL%ld:RANG?", instance, number);
	checkErr(RsCore_QueryTupleViReal64(instrSession, cmd, RSCPMin, RSCPMax, NULL, NULL));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function selects the date and time source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR source/Selects the date and time source.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeSource(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIME_SOURCE, source),
    		3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function specifies the UTC date for the time source 'User Defined'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR year/Year
/// HIPAR month/Month
/// HIPAR day/Day
/// HIPAR hour/Hour
/// HIPAR minute/Minute
/// HIPAR second/Second
/// HIPAR DST/Enables daylight saving time (DST).
/// HIPAR DSTTimeShift/Specifies a Daylight Saving Time (DST) offset for the time source 'User Defined'.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeDate(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   year,
                                                   ViInt32   month,
                                                   ViInt32   day,
                                                   ViInt32   hour,
                                                   ViInt32   minute,
                                                   ViInt32   second,
                                                   ViInt32   DST,
                                                   ViInt32   DSTTimeShift)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, year, 2011, 9999),
    		3, "Year");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, month, 1, 12),
    		4, "Month");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, day, 1, 31),
    		5, "Day");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, hour, 0, 23),
    		6, "Hour");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, minute, 0, 59),
    		7, "Minute");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, second, 0, 59),
    		8, "Second");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CELL:TIME:DATE %ld,%ld,%ld\n", instance, day, month, year);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));
    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CELL:TIME:TIME %ld,%ld,%ld\n", instance, hour, minute, second);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));
    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap,
        RSCMWGS_ATTR_NETWORK_TIME_DST_ENABLED, (ViBoolean) DST), 9, "DST");
    if (DST == RSCMWGS_VAL_DEFINE_TIME_SHIFT)
    {
        viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIME_DST_SHIFT, DSTTimeShift),
        		10, "DST Shift");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables the transfer of the date and time information to
/// HIFN  the MS at attach and location update.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enable/Enables the transfer of the date and time information to the MS at
/// HIPAR enable/attach and location update.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeTransfer(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViBoolean enable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIME_TRANSFER_ENABLED, enable),
    		3, "Enable");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sends the full and short network name within date and time signaling to the MS.
/// HIFN
/// HIFN  Attribute(s):
/// HIFN  RSCMWGS_ATTR_NETWORK_TIME_SEND_NETWORK_NAME
/// HIFN
/// HIFN  Remote-control command(s):
/// HIFN  CONFigure:GSM:SIGN:CELL:TIME:SNName
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enable/Enables the sends the full and short network name within date and time signaling to the MS.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeSendNetworkName(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIME_SEND_NETWORK_NAME, enable),
    		3, "Enable");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies a time zone offset for the time source DATE.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_NETWORK_TIME_LOCAL_TIME_ZONE_OFFSET
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CELL:TIME:LTZoffset
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR localZoneOffset/Specifies a time zone offset for the time source DATE.
ViStatus _VI_FUNC rscmwgs_ConfigureNetworkTimeLocalZoneOffset(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  localZoneOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIME_LOCAL_TIME_ZONE_OFFSET, localZoneOffset),
    		3, "Local Zone Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Triggers the transfer of the date and time information to the MS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_ApplyNetworkTime(ViSession instrSession,
                                           ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_NETWORK_TIME_TRANSFER, NULL),
    		3, "Time Transfer");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures frequency offset.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR randomFrequencyOffset/Enables random frequency offset for the traffic channel. The CMW randomly applies the positive and negative frequency offset.
/// HIPAR downlinkFrequencyOffset/Sets the positive or negative offset to the center frequency of the downlink traffic channel.
/// HIPAR uplinkFrequencyOffset/Sets the positive or negative offset to the center frequency of the uplink traffic channel.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionFrequencyOffset(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViBoolean randomFrequencyOffset,
                                                             ViReal64  downlinkFrequencyOffset,
                                                             ViReal64  uplinkFrequencyOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_RANDOM_FREQUENCY_OFFSET_ENABLED, randomFrequencyOffset),
    		3, "Random Frequency Offset Enabled");

    if (!randomFrequencyOffset)
    {
        viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_FREQUENCY_OFFSET_DOWNLINK, downlinkFrequencyOffset),
        		4, "Downlink Frequency Offset");

        viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_FREQUENCY_OFFSET_UPLINK, uplinkFrequencyOffset),
        		5, "Uplink Frequency Offset");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the value which the MS uses to advance its UL timing.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR timingAdvance/Specifies the value which the MS uses to advance its UL timing.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionTimingAdvance(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   timingAdvance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_TIMING_ADVANCE, timingAdvance),
    		3, "Timing Advance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures extended uplink TBF.
/// HIFN
/// HIFN Attribute(s):
/// HIFN RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_NW_EXT_UTBF
/// HIFN RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_EXT_UTBF_NODATA
/// HIFN
/// HIFN Remote-control command(s):
/// HIFN CONFigure:GSM:SIGN:CELL:PSWitched:NEUTbf
/// HIFN CONFigure:GSM:SIGN:CELL:PSWitched:EUNodata
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR extendedUplinkTBF/
/// HIPAR extendedUplinkTBFNodata/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionExtendedUplinkTBF(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean extendedUplinkTBF,
							ViBoolean extendedUplinkTBFNodata)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_NW_EXT_UTBF, extendedUplinkTBF),
    		3, "Extended Uplink TBF");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_EXT_UTBF_NODATA, extendedUplinkTBFNodata),
    		4, "Extended Uplink TBF Nodata");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns error information related to the active CS/PS connection.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR domain/Document parameter here.
/// HIPAR connectionError/Document parameter here.
ViStatus _VI_FUNC rscmwgs_QueryConnectionError(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   domain,
                                               ViInt32   *connectionError)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    switch (domain)
    {
        case RSCMWGS_VAL_CS:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_ERROR, connectionError),
            		4, "Connection Error");
            break;
        case RSCMWGS_VAL_PS:
            viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_ERROR, connectionError),
            		4, "Connection Error");
            break;
        default:
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, domain), 3, "Domain");
            break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Circuit Switched
 * Purpose:  This function configures the traffic channel (TCH) for the
 *           circuit switched connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitched(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   timeslot,
                                                             ViInt32   trafficMode,
                                                             ViInt32   dataSource,
                                                             ViInt32   loop,
                                                             ViString  callerId,
                                                             ViBoolean reCloseLoop,
                                                             ViInt32   tchAssignment,
                                                             ViInt32   msPowerChange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
             dataSource;
             msPowerChange;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_TIMESLOT, timeslot),
    		3, "Timeslot");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_TRAFFIC_MODE, trafficMode),
    		4, "Traffic Mode");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_DATA_SOURCE, dataSource),
    		5, "Data Source");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_LOOP, loop),
    		6, "Loop");

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_CALLER_ID, callerId),
    		7, "Caller Id");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_LOOP_RECLOSE, reCloseLoop),
    		8, "ReClose Loop");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_TCH_ASSIGNMENT, tchAssignment),
    		9, "TCH Assignment");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the time that the R&S CMW waits before it loops
/// HIFN  back the received data in Echo mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR echoDelay/Defines the time that the R&S CMW waits before it loops back the
/// HIPAR echoDelay/received data in Echo mode.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedEchoDelay(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   echoDelay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_ECHO_DELAY, echoDelay),
    		3, "Echo Delay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the discontinuous transmission of the R&S
/// HIFN  CMW.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enable/Enable / disable DL DTX.
/// HIPAR noDataFrames/Relative level in the DL DTX frames, where no SID frames and
/// HIPAR sidFrames2Part/Relative level of the second part of SID frames. This level is
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedDTXDL(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enable,
							ViReal64  noDataFrames,
							ViReal64  sidFrames2Part)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, noDataFrames, -40.0, 0.0), 4, "No Data Frames");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, sidFrames2Part, -40.0, 0.0), 5, "Sid Frames 2 Part");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:CSW:DTX:DL %s,%le,%le", instance, switchArr[enable], noDataFrames, sidFrames2Part);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies the signaling volume during the call release.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR callRelease/Specifies the signaling volume during the call release.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedCallRelease(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   callRelease)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_CALL_RELEASE, callRelease),
    		3, "Connection Call Release");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Circuit Switched Traffic Channels State
 * Purpose:  Enables/disables repeated FACCH and repeated SACCH transmission
 *           in the DL GSM signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedTrafficChannelsState(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   controlChannel,
							ViBoolean enable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString ControlChannelArr[] = {",RFACch", ",RSACch"};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, controlChannel, RSCMWGS_VAL_RFACCH, RSCMWGS_VAL_RSACCH),
    		3, "Control Channel");

    strcat(repCap, ControlChannelArr[controlChannel]);

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_TRAFFIC_CHANNEL_STATE, enable),
    		4, "Enable");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Circuit Switched AMR Rate
 * Purpose:  This function Configures up to four supported modes for the full
 *           and half rate narrowband AMR codec, i.e. assigns data rates to
 *           the modes.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRRate(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   rate,
							ViInt32   codecModeRate4,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  max = 0;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWGS_VAL_FRATE, RSCMWGS_VAL_HRATE),
    		3, "Rate");

    if (rate == RSCMWGS_VAL_FRATE)
        max = RSCMWGS_VAL_RSET_RATE_C1220;
    else
        max = RSCMWGS_VAL_RSET_RATE_C0795;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate4, RSCMWGS_VAL_RSET_RATE_OFF, max),
    		4, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate3, RSCMWGS_VAL_RSET_RATE_OFF, max),
    		5, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate2, RSCMWGS_VAL_RSET_RATE_OFF, max),
    		6, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate1, RSCMWGS_VAL_RSET_RATE_OFF, max),
    		7, "Codec Mode Rate");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:CSW:AMR:RSET:NB:%s:GMSK %s,%s,%s,%s\n", instance,
                                                                                                     rate?"HRAT":"FRATE",
                                                                                                     codecRateArr[codecModeRate4],
                                                                                                     codecRateArr[codecModeRate3],
                                                                                                     codecRateArr[codecModeRate2],
                                                                                                     codecRateArr[codecModeRate1]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Circuit Switched AMR Codec Mode
 * Purpose:  Select the codec modes to be used by the R&S CMW500 (downlink)
 *           and the MS (uplink) for the full or half rate narrowband AMR
 *           codec.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRCodecMode(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   codecModeDownlink,
							ViInt32   codecModeUplink)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString BandArr[] = {",NB", ",WB"};
    ViString rateArr[] = {",Full",",Half"};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMWGS_VAL_NB, RSCMWGS_VAL_WB),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWGS_VAL_FRATE, RSCMWGS_VAL_HRATE),
    		4, "Rate");

    strcat(repCap, BandArr[band]);
    strcat(repCap, rateArr[rate]);

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_AMR_CODEC_MODE_DOWNLINK, codecModeDownlink),
    		5, "Codec Mode Downlink");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_AMR_CODEC_MODE_UPLINK, codecModeUplink),
    		6, "Codec Mode Uplink");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies AMR signaling mode.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CONNECTION_AMR_SIGNALING_MODE
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CONNection:CSWitched:AMR:SIGNaling:MODE
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR signalingMode/Specifies AMR signaling mode.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRSignalingMode(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   signalingMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_AMR_SIGNALING_MODE, signalingMode),
    		3, "Signaling Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Connection Circuit Switched AMR MS Codec Mode
 * Purpose:  Query the DL codec mode requested by the MS and the actual UL
 *           codec mode used by the MS, for the Half-rate or full-rate
 *           narrowband AMR codec.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedAMRMSCodecMode(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   *codecModeDownlink,
							ViInt32   *codecModeUplink)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString BandArr[] = {",NB", ",WB"};
    ViString rateArr[] = {",Full",",Half"};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMWGS_VAL_NB, RSCMWGS_VAL_WB),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWGS_VAL_FRATE, RSCMWGS_VAL_HRATE),
    		4, "Rate");

    strcat(repCap, BandArr[band]);
    strcat(repCap, rateArr[rate]);

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_MS_CODEC_MODE_DOWNLINK, codecModeDownlink),
    		5, "Codec Mode Downlink");

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_MS_CODEC_MODE_UPLINK, codecModeUplink),
    		6, "Codec Mode Uplink");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Circuit Switched Wideband AMR Rate
 * Purpose:  Configures up to four supported modes for the half-rate
 *           narrowband AMR codec, i.e. assigns data rates to the modes.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedWidebandAMRRate(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate3, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1220),
    		3, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate2, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1220),
    		4, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate1, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1220),
    		5, "Codec Mode Rate");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:CSW:AMR:RSET:WB:FRAT:GMSK %s,%s,%s\n", instance,
                                                                                                     codecRateWBArr[codecModeRate3],
                                                                                                     codecRateWBArr[codecModeRate2],
                                                                                                     codecRateWBArr[codecModeRate1]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures up to four supported modes for the
/// HIFN  half rate narrowband AMR codec, i.e. assigns data rates to the modes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR codecModeRate4/Selects the AMR Rate.
/// HIPAR codecModeRate3/Selects the AMR Rate.
/// HIPAR codecModeRate2/Selects the AMR Rate.
/// HIPAR codecModeRate1/Selects the AMR Rate.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRNarrowBand8PSKHalfRate(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   codecModeRate4,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate4, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1220),
    		3, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate3, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1220),
    		4, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate2, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1220),
    		5, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate1, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1220),
    		6, "Codec Mode Rate");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:CSW:AMR:RSET:NB:HRAT:EPSK %s,%s,%s,%s\n",  instance,
                                                                                                     codecRateArr[codecModeRate4],
                                                                                                     codecRateArr[codecModeRate3],
                                                                                                     codecRateArr[codecModeRate2],
                                                                                                     codecRateArr[codecModeRate1]);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures up to four supported modes for the
/// HIFN  full rate wide band AMR codec, i.e. assigns data rates to the modes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR codecModeRate4/Selects the AMR Rate.
/// HIPAR codecModeRate3/Selects the AMR Rate.
/// HIPAR codecModeRate2/Selects the AMR Rate.
/// HIPAR codecModeRate1/Selects the AMR Rate.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRWideBand8PSKFullRate(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   codecModeRate4,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate4, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C2385),
    		3, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate3, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C2385),
    		4, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate2, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C2385),
    		5, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate1, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C2385),
    		6, "Codec Mode Rate");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:CSW:AMR:RSET:WB:FRAT:EPSK %s,%s,%s,%s\n",  instance,
                                                                                                     codecRateWBArr[codecModeRate4],
                                                                                                     codecRateWBArr[codecModeRate3],
                                                                                                     codecRateWBArr[codecModeRate2],
                                                                                                     codecRateWBArr[codecModeRate1]);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures up to four supported modes for the
/// HIFN  half rate wide band AMR codec, i.e. assigns data rates to the modes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR codecModeRate3/Selects the AMR Rate.
/// HIPAR codecModeRate2/Selects the AMR Rate.
/// HIPAR codecModeRate1/Selects the AMR Rate.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMRWideBand8PSKHalfRate(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   codecModeRate3,
							ViInt32   codecModeRate2,
							ViInt32   codecModeRate1)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate3, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1265),
    		3, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate2, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1265),
    		4, "Codec Mode Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codecModeRate1, RSCMWGS_VAL_RSET_RATE_OFF, RSCMWGS_VAL_RSET_RATE_C1265),
    		5, "Codec Mode Rate");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:CSW:AMR:RSET:WB:HRAT:EPSK %s,%s,%s\n",  instance,
                                                                                                     codecRateWBArr[codecModeRate3],
                                                                                                     codecRateWBArr[codecModeRate2],
                                                                                                     codecRateWBArr[codecModeRate1]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Select the codec modes to be used by the R&S CMW500 (downlink) and the
/// HIFN  MS (uplink) for the full or half rate narrowband AMR codec.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR band/Selectes the band.
/// HIPAR rate/Selectes witch rate will be configured.
/// HIPAR codecModeDownlink/Sets the downlink codec mode.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMR8PSKCodecModeDownlink(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   codecModeDownlink)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString BandArr[] = {",NB", ",WB"};
    ViString rateArr[] = {",Full",",Half"};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMWGS_VAL_NB, RSCMWGS_VAL_WB),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWGS_VAL_FRATE, RSCMWGS_VAL_HRATE),
    		4, "Rate");

    strcat(repCap, BandArr[band]);
    strcat(repCap, rateArr[rate]);

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_AMR_8PSK_CODEC_MODE_DOWNLINK, codecModeDownlink),
    		5, "Codec Mode Downlink");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Select the codec modes to be used by the R&S CMW500 (downlink) and the
/// HIFN  MS (uplink) for the full or half rate narrowband AMR codec.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR band/Selectes the band.
/// HIPAR rate/Selectes witch rate will be configured.
/// HIPAR codecModeUplink/Sets the uplink codec mode.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAMR8PSKCodecModeUplink(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   codecModeUplink)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString BandArr[] = {",NB", ",WB"};
    ViString rateArr[] = {",Full",",Half"};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMWGS_VAL_NB, RSCMWGS_VAL_WB),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWGS_VAL_FRATE, RSCMWGS_VAL_HRATE),
    		4, "Rate");

    strcat(repCap, BandArr[band]);
    strcat(repCap, rateArr[rate]);

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_AMR_8PSK_CODEC_MODE_UPLINK, codecModeUplink),
    		5, "Codec Mode Uplink");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Query the DL codec mode requested by the MS and the actual UL codec
/// HIFN  mode used by the MS, for the Half-rate or full-rate narrowband AMR
/// HIFN  codec.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CONNECTION_AMR_8PSK_CODEC_MODE_DOWNLINK
/// HIFN     RSCMWGS_ATTR_CONNECTION_AMR_8PSK_CODEC_MODE_UPLINK
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     SENSe:GSM:SIGNaling<instance>:MSSinfo:AMR:CMODe:NB:HRATe:EPSK:DL?
/// HIFN     SENSe:GSM:SIGNaling<instance>:MSSinfo:AMR:CMODe:NB:HRATe:EPSK:UL?
/// HIFN     SENSe:GSM:SIGNaling<instance>:MSSinfo:AMR:CMODe:WB:FRATe:EPSK:DL?
/// HIFN     SENSe:GSM:SIGNaling<instance>:MSSinfo:AMR:CMODe:WB:FRATe:EPSK:UL?
/// HIFN     SENSe:GSM:SIGNaling<instance>:MSSinfo:AMR:CMODe:WB:HRATe:EPSK:DL?
/// HIFN     SENSe:GSM:SIGNaling<instance>:MSSinfo:AMR:CMODe:WB:HRATe:EPSK:UL?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR band/Selectes the band.
/// HIPAR rate/Selectes witch rate will be confifured.
/// HIPAR codecModeDownlink/Downlink codec mode requested by the MS.
/// HIPAR codecModeUplink/Uplink codec mode used by the MS.
ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedAMR8PSKMSCodecMode(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32*  codecModeDownlink,
							ViInt32*  codecModeUplink)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString BandArr[] = {",NB", ",WB"};
    ViString rateArr[] = {",Full",",Half"};

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMWGS_VAL_NB, RSCMWGS_VAL_WB),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWGS_VAL_FRATE, RSCMWGS_VAL_HRATE),
    		4, "Rate");

    strcat(repCap, BandArr[band]);
    strcat(repCap, rateArr[rate]);

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_MS_8PSK_CODEC_MODE_DOWNLINK, codecModeDownlink),
    		5, "Codec Mode Downlink");

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_MS_8PSK_CODEC_MODE_UPLINK, codecModeUplink),
    		6, "Codec Mode Uplink");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Circuit Switched VAMOS
 * Purpose:  This function configures the circuit switched VAMOS settings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedVAMOS(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean VAMOSEnable,
							ViInt32   activeSubchannel,
							ViInt32   TSC,
							ViInt32   TSCSet,
							ViInt32   TSCOther,
							ViInt32   TSCSetOther,
							ViReal64  subchanPowerImbalanceRatio,
							ViInt32   VAMOSProfile)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, activeSubchannel, 0, 1),
    		4, "Active Subchannel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, TSC, 0, 7),
    		5, "TSC");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, TSCSet, 0, 2),
    		6, "TSC Set");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, TSCOther, 0, 7),
    		7, "TSC Other");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, TSCSetOther, 0, 2),
    		8, "TSC Set Other");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, subchanPowerImbalanceRatio, -15.0, 15.0), 4, "Subchan Power Imbalance Ratio");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, VAMOSProfile, 1, 3),
    		4, "TSC");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_VAMOS_ENABLE, VAMOSEnable),
    		3, "VAMOS Enable");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:CSW:VAM %ld,%ld,%ld,%ld,%ld,%le,%s\n", instance,
                                                                                                    activeSubchannel,
                                                                                                    TSC,
                                                                                                    TSCSet,
                                                                                                    TSCOther,
                                                                                                    TSCSetOther,
                                                                                                    subchanPowerImbalanceRatio,
                                                                                                    VAMOSProfileArr[VAMOSProfile]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Circuit Switched VAMOS Support Level
 * Purpose:  Selects the VAMOS support level of the mobile.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedVAMOSSupportLevel(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   mobileSupportLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_VAMOS_MOBILE_SUPPORT_LEVEL, mobileSupportLevel),
    		3, "Mobile Support Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the subchannel to be used for half-rate coding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR hrSubchannel/Selects the subchannel to be used for half-rate coding.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedHalfRateSubchannel(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   hrSubchannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_HALF_RATE_SUBCHANNEL, hrSubchannel),
    		3, "HR Subchannel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures the upper and lower limits for the codec mode
/// HIFN swapping.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR band/Selects the band.
/// HIPAR rate/Selects witch rate will be configured.
/// HIPAR modulation/Selects the modulation
/// HIPAR thresholdState/This control sets the threshold state. An array of 6 values is
/// HIPAR expected. Each value indicates the threshold state ON/OFF.
/// HIPAR threshold/This control sets the upper and lower limits for the codec mode swapping.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedWidebandAMRThreshold(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   rate,
							ViInt32   modulation,
							ViBoolean thresholdState[],
							ViReal64  threshold[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   buffer[RS_MAX_MESSAGE_BUF_SIZE]="\0";
    ViChar   *pbuffer;
    ViInt32  i=0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMWGS_VAL_NB, RSCMWGS_VAL_WB),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWGS_VAL_FRATE, RSCMWGS_VAL_HRATE),
    		4, "Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulation, RSCMWGS_VAL_MODULATION_GMSK, RSCMWGS_VAL_MODULATION_EPSK),
    		5, "Modulation");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, thresholdState),
			6, "NULL for Threshold State Array");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, threshold),
			7, "NULL for Threshold Array");

    pbuffer=buffer;
    pbuffer += sprintf (pbuffer, "CONF:GSM:SIGN%ld:CONN:CSW:AMR:THR:%s:%s:%s ",instance, modulationBandArr[band],
                        modulationRateArr[rate], modulationArr[modulation]);

    for (i=0;i<6;i++)
    {
        if (thresholdState[i]==VI_FALSE)
            pbuffer=pbuffer+sprintf(pbuffer,"OFF,");
        else
            pbuffer += sprintf(pbuffer,"%.12lG,", threshold[i]);
    }
    pbuffer--;
    *pbuffer='\n';

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "%s", buffer);
    checkErr(RsCore_Write(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the counters of connection attempt to zero.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedAttempt(
							ViSession instrSession,
							ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_ATTEMPT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the counters of connection reject to zero.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionCircuitSwitchedReject(
							ViSession instrSession,
							ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_REJECT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the counters of connection attempt to zero.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR attempt/Queries the counters of connection attempt.
ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedAttempt(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32*  attempt)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_ATTEMPT_QUERY, attempt),
    		3, "Attempt");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the counters of connection reject to zero.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR reject/Queries the counters of connection reject.
ViStatus _VI_FUNC rscmwgs_QueryConnectionCircuitSwitchedReject(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32*  reject)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_REJECT_QUERY, reject),
    		3, "Reject");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Enables/disables the automatic setting of the PS parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR autoSlotConfigEnabled/Enables/disables the automatic setting of the PS parameters.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedAutoSlot(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean autoSlotConfigEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_AUTO_SLOT_CONFIG_ENABLED, autoSlotConfigEnabled),
    		3, "Auto Slot Config Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables/disables the automatic setting of the PS parameters in Slot
/// HIFN  Configuration Dialog for dual transfer mode.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_AUTO_DUAL_TRANSFER_MODE
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CONNection:DSConfig
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR autoDualSlotConfigEnabled/Enables/disables the automatic setting of the PS parameters in Slot
/// HIPAR autoDualSlotConfigEnabled/Configuration Dialog for dual transfer mode.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedAutoDualSlot(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean autoDualSlotConfigEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_AUTO_DUAL_TRANSFER_MODE, autoDualSlotConfigEnabled),
    		3, "Auto Dual Slot Config Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Service
 * Purpose:  This function configures the packet switched connection service.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedService(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   serviceSelection,
							ViBoolean testmodeBwithUlAck,
							ViBoolean testmodeRfLevelReporting,
							ViBoolean testmodeSsrbwithSysInfo,
							ViInt32   blerPollingRadioBlocks)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
             testmodeBwithUlAck;
             testmodeRfLevelReporting;
             testmodeSsrbwithSysInfo;
             blerPollingRadioBlocks;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_SERVICE, serviceSelection),
    		3, "Service Selection");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Data Source
 * Purpose:  This function configures the packet switched connection data
 *           source.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedDataSource(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   dataSource,
							ViString  userPattern)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
             userPattern;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DATA_SOURCE, dataSource),
    		3, "Data Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Settings
 * Purpose:  This function configures the packet switched connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSettings(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   extendedDynamicAllocation,
							ViInt32   numberofProtocolDataUnits,
							ViInt32   slotOffset,
							ViInt32   controlAckType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
             extendedDynamicAllocation;
             controlAckType;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_EXTENDED_DYNAMIC_ALLOCATION, extendedDynamicAllocation),
    		3, "Extended Dynamic Allocation");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_NUMBER_OF_PROTOCOL_DATA_UNITS, numberofProtocolDataUnits),
    		4, "Number of Protocol Data Units");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_SLOT_OFFSET, slotOffset),
    		5, "Slot Offset");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_CONTROL_ACK_TYPE, controlAckType),
    		6, "Control Ack Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Slot Config
 * Purpose:  This function configures the generated GSM downlink signal and
 *           control the UL signals of the mobile station under test, in
 *           particular for Packet Switched (PS) connections and multislot
 *           operation.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfig(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   TBFLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_TBF_LEVEL, TBFLevel),
    		3, "TBF Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Slot Config Uplink
 * Purpose:  This function configures slot config uplink of the packet
 *           switched connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfigUplink(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   uplinkCodingScheme,
							ViInt32   number_ofSlots,
							ViBoolean used[],
							ViInt32   uplinkGamma[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[512]="";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   usedList[512]="";
    ViChar   gammaList[512]="";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  i=0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_CODING_SCHEME_UPLINK, uplinkCodingScheme),
    		3, "Uplink Coding Scheme");

    for (i=0; i<8; i++)
    {
        if(i < number_ofSlots)
        {
            strcat(usedList, used[i]?",ON":",OFF");

            viCheckParm(RsCore_InvalidViInt32Range(instrSession, uplinkGamma[i], 0, 31),
            		6, "Uplink Gamma");
            sprintf(buffer, ",%ld", uplinkGamma[i]);
            strcat(gammaList, buffer);
        }
        else
        {
            strcat(usedList, ",OFF");
            strcat(gammaList, ",0");
        }
    }

    usedList[0] = ' ';
    gammaList[0] = ' ';

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:PSW:SCON:ENAB:UL%s", instance, usedList);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:PSW:SCON:GAMM:UL%s", instance, gammaList);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Slot Config Downlink
 * Purpose:  This function configures slot config downlink of the packet
 *           switched connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfigDownlink(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   number_ofSlots,
							ViBoolean used[],
							ViInt32   downlinkState[],
							ViReal64  downlinkLevel[],
							ViInt32   downlinkCodingScheme[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[512]="";
    ViChar   usedList[512]="";
    ViChar   DLLevelList[512]="";
    ViChar   DLSchemeList[512]="";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  i=0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    for (i=0; i<8; i++)
    {
        if(i < number_ofSlots)
        {
            strcat(usedList, used[i]?",ON":",OFF");

            viCheckParm(RsCore_InvalidViInt32Range(instrSession, downlinkState[i], RSCMWGS_VAL_DL_OFF, RSCMWGS_VAL_DL_VAL),
            		6, "Downlink State");

            switch (downlinkState[i])
            {
                case RSCMWGS_VAL_DL_OFF:
                    strcat(DLLevelList,",OFF");
                break;

                case RSCMWGS_VAL_DL_ON:
                    strcat(DLLevelList,",ON");
                break;

                case RSCMWGS_VAL_DL_VAL:
                    viCheckParm(RsCore_InvalidViReal64Range(instrSession, downlinkLevel[i], -40.0, 0), 7, "Downlink Level");
                    sprintf(buffer, ",%le", downlinkLevel[i]);
                    strcat(DLLevelList, buffer);

                break;

                default:
                    strcat(DLLevelList,",OFF");
                break;
            }

            viCheckParm(RsCore_InvalidViInt32Range(instrSession, downlinkCodingScheme[i], RSCMWGS_VAL_DOWN_CODING_SCHEME_C1, RSCMWGS_VAL_DOWN_CODING_SCHEME_DA12),
            		6, "Downlink Coding Scheme");
            strcat(DLSchemeList, ",");
            strcat(DLSchemeList, codeSchemeArr[downlinkCodingScheme[i]]);
        }
        else
        {
            strcat(usedList, ",OFF");
            strcat(DLLevelList, ",OFF");
            strcat(DLSchemeList, ",C1");
        }
    }

    usedList[0] = ' ';
    DLLevelList[0] = ' ';
    DLSchemeList[0] = ' ';

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:PSW:SCON:ENAB:DL:CARR%ld%s", instance, carrier, usedList);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:PSW:SCON:LEV:DL:CARR%ld%s", instance, carrier, DLLevelList);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:PSW:SCON:CSCH:DL:CARR%ld%s", instance, carrier, DLSchemeList);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the percentage of downlink GPRS radio blocks
/// HIFN  containing the USF assigned to the MS. In sum eight values are
/// HIFN  specified (slot 0 to slot 7).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR percentage/Percentage of downlink GPRS radio blocks containing the USF assigned
/// HIPAR percentage/to the MS. In sum eight values are specified (slot 0 to slot 7).
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedSlotConfigUSFDownlink(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   percentage[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CONN:PSW:SCON:UDCY:DL ", instance);
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, percentage, 8));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Enables or disables the incremental redundancy RLC mode for the downlink.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR incrementalRedundancy/Enables or disables the incremental redundancy RLC mode for the downlink.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedIncrementalRedundancy(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean incrementalRedundancy)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_INCREMENTAL_REDUNDANCY_ENABLED, incrementalRedundancy),
    		3, "Incremental Redundancy");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Downlink Dualcarrier
 * Purpose:  This function configures downlink dualcarrier of the packet
 *           switched connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedDownlinkDualcarrier(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enableDownlinkDualcarrier)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DOWNLINK_DUALCARRIER, enableDownlinkDualcarrier),
    		3, "Enable Downlink Dualcarrier");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures the BEP_PERIOD2 defined in 3GPP TS 45.008 that the MS uses for the mean BEP and the CV BEP calculation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR BEPPeriod2/Configures the BEP_PERIOD2 defined in 3GPP TS 45.008 that the MS uses for the mean BEP and the CV BEP calculation.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedBEPPeriod2(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   BEPPeriod2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_BEP_PERIOD_2, BEPPeriod2),
    		3, "BEP Period 2");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies volume of corrupted data the CMW generates.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR BCSDataCorruptionRate/Specifies volume of corrupted data the R&S CMW generates.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedBCSDataCorruptionRate(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  BCSDataCorruptionRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_BCS_DATA_CORRUPTION_RATE, BCSDataCorruptionRate),
    		3, "BCS Data Corruption Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configure downlink power control.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enabled/Enables/disables downlink power control.
/// HIPAR p0/Defines a power reduction relative to BCCH.
/// HIPAR powerReductionMode/Defines the power reduction mode of the downlink power control.
/// HIPAR powerReductionField/Indicates the power level reduction of the current RLC block.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedDownlinkPowerControl(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enabled,
							ViInt32   p0,
							ViInt32   powerReductionMode,
							ViInt32   powerReductionField)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DOWNLINK_POWER_CONTROL_ENABLED, enabled),
    		3, "Enabled");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_DOWNLINK_POWER_CONTROL_P0, p0),
    		4, "P0");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_POWER_REDUCTION_MODE, powerReductionMode),
    		5, "Power Reduction Mode");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_POWER_REDUCTION_FIELD, powerReductionField),
    		6, "Power Reduction Field");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Enables the filler dummy data blocks.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enabled/Document parameter here.
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedAlwaysSendRLCDataBlocks(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_ALWAYS_SEND_RLC_DATA_BLOCKS, enabled),
    		3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched Block Encoding
 * Purpose:  This function configures the packet switched connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedBlockEncoding(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   blockEncoding,
							ViInt32   usfMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_BLOCK_ENCODING, blockEncoding),
    		3, "Block Encoding");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_USF_MODE, usfMode),
    		4, "USF Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Packet Switched FANR
 * Purpose:  This function configures FANR settings of the packet switched
 *           connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureConnectionPacketSwitchedFANR(
							ViSession instrSession,
							ViInt32   instance,
							ViBoolean enableFarn,
							ViBoolean downlinkEventBased,
							ViBoolean downlinkPolled,
							ViInt32   uplinkMode,
							ViInt32   uplinkTimeshift)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_STATE, enableFarn),
    		3, "Enable FARN");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_DOWNLINK_EVENT_BASED, downlinkEventBased),
    		4, "Downlink Event Based");

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_DOWNLINK_POLLED, downlinkPolled),
    		5, "Downlink Polled");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_UPLINK_MODE, uplinkMode),
    		6, "Uplink Mode");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_FANR_UPLINK_TIMESHIFT, uplinkTimeshift),
    		7, "Uplink Timeshift");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures the packet switched connection service.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR direction/Selects the direction.
/// HIPAR throughput/Document parameter here.
ViStatus _VI_FUNC rscmwgs_QueryConnectionPacketSwitchedMaxThroughput(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   direction,
							ViReal64  *throughput)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    if (direction == RSCMWGS_VAL_DOWNLINK)
    {
        viCheckParm(rscmwgs_GetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_MAX_DOWNLINK_THROUGHPUT, throughput),
        		4, "Throughput");
    }
    else
    {
        viCheckParm(rscmwgs_GetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_CONNECTION_PACKET_SWITCHED_MAX_UPLINK_THROUGHPUT, throughput),
        		4, "Throughput");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Handover
 * Purpose:  This function configures the dual-band handover to another GSM
 *           band.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureHandover(ViSession instrSession,
                                            ViInt32   instance,
                                            ViInt32   destinationBand,
                                            ViInt32   destinationChannel,
                                            ViReal64  destinationLevel,
                                            ViInt32   destinationPCL,
                                            ViInt32   destinationTimeslot)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_DESTINATION_BAND, destinationBand),
    		3, "Destination Band");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_DESTINATION_CHANNEL, destinationChannel),
    		4, "Destination Channel");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_DESTINATION_LEVEL, destinationLevel),
    		5, "Destination Level");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_DESTINATION_PCL, destinationPCL),
    		6, "Destination PCL");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_DESTINATION_TIMESLOT, destinationTimeslot),
    		7, "Destination Timeslot");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the dual-band handover to another GSM band.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mobilityMode/Selects the mechanism to be used for handover to another signaling application.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverMobilityMode(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   mobilityMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_MOBILITY_MODE, mobilityMode),
    		3, "Mobility Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies the uplink timeslots the mobile shall use in a packet switched connection in the destination GSM band.
/// HIFN Timeslot 0 can not be enabled (always OFF).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR numberOfSlots/This control sets the number of configured slots (expected size of array).
/// HIPAR uplinkTimeslotEnabled/Specifies the uplink timeslots the mobile shall use in a packet switched connection in the destination GSM band.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverUplinkTimeslotsEnable(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   numberOfSlots,
							ViBoolean uplinkTimeslotEnabled[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   *p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, numberOfSlots, 8, 8),
    		3, "Number Of Slots");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, uplinkTimeslotEnabled), 4, "Uplink Timeslot Enabled");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:PSW:ENAB:UL ", instance);

	// 8 slots has to be set for command. If the numberOfSlots<8, next values are fill with OFF
    for (i = 0; i < 8; i++)
    {
        if (i<numberOfSlots)
            p2buf += sprintf (p2buf, "%s,", uplinkTimeslotEnabled[i] ? "ON":"OFF");
        else
            p2buf += sprintf (p2buf, "%s,", "OFF");
    }

    *p2buf = '\0';

    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Handover Uplink Gamma
 * Purpose:  This function configures the power control parameter gamma per
 *           UL timeslot in the destination GSM band.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverUplinkGamma(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   numberOfSlots,
                                                       ViInt32   uplinkGamma[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, numberOfSlots, 8, 8),
    		3, "numberOfSlots");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:PSW:GAMM:UL ", instance);
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, uplinkGamma, numberOfSlots));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies the downlink timeslots the mobile shall use in a
/// HIFN packet switched connection in the destination GSM band.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR numberOfSlots/This control sets the number of configured slots (expected size of array).
/// HIPAR carrier/Selects the carrier.
/// HIPAR downlinkTimeslotEnabled/Specifies the downlink timeslots the mobile shall use in a packet switched connection in the destination GSM band.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDownlinkTimeslotsEnable(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   numberOfSlots,
							ViBoolean downlinkTimeslotEnabled[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   *p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, numberOfSlots, 8, 8),
    		3, "Number Of Slots");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		4, "Carrier");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, downlinkTimeslotEnabled), 4, "Downlink Timeslot Enabled");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:PSW:ENAB:DL:CARR%ld ", instance, carrier);

    //8 slots has to be set for command. If the numberOfSlots<8, next values are fill with OFF
    for (i = 0; i < 8; i++)
    {
        if (i<numberOfSlots)
            p2buf += sprintf (p2buf, "%s,", downlinkTimeslotEnabled[i] ? "ON":"OFF");
        else
            p2buf += sprintf (p2buf, "%s,", "OFF");
    }

    *p2buf = '\0';

    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Handover Downlink Coding Scheme
 * Purpose:  configures downlink slots of the packet switched connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDownlinkCodingScheme(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   numberOfSlots,
							ViInt32   downlinkState[],
							ViReal64  downlinkLevel[],
							ViInt32   downlinkCodingScheme[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[512]="";
    ViChar   DLLevelList[512]="";
    ViChar   DLSchemeList[512]="";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  i=0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, numberOfSlots, 1, 8),
    		4, "Number Of Slots");

    for (i=0; i<8; i++)
    {
        if(i < numberOfSlots)
        {
            viCheckParm(RsCore_InvalidViInt32Range(instrSession, downlinkState[i], RSCMWGS_VAL_DL_OFF, RSCMWGS_VAL_DL_VAL),
            		5, "Downlink State");

            switch (downlinkState[i])
            {
                case RSCMWGS_VAL_DL_OFF:
                    strcat(DLLevelList,",OFF");
                break;

                case RSCMWGS_VAL_DL_ON:
                    strcat(DLLevelList,",ON");
                break;

                case RSCMWGS_VAL_DL_VAL:
                    viCheckParm(RsCore_InvalidViReal64Range(instrSession, downlinkLevel[i], -40.0, 0), 6, "Downlink Level");

                    sprintf(buffer, ",%le", downlinkLevel[i]);
                    strcat(DLLevelList, buffer);
                break;

                default:
                    strcat(DLLevelList,",OFF");
                break;
            }

            viCheckParm(RsCore_InvalidViInt32Range(instrSession, downlinkCodingScheme[i], RSCMWGS_VAL_CODING_SCHEME_C1, RSCMWGS_VAL_DOWN_CODING_SCHEME_DA12),
            		7, "Downlink Coding Scheme");
            strcat(DLSchemeList, ",");
            strcat(DLSchemeList, codeSchemeArr[downlinkCodingScheme[i]]);
        }
        else
        {
            strcat(DLLevelList, ",OFF");
            strcat(DLSchemeList, ",");
            strcat(DLSchemeList, codeSchemeArr[downlinkCodingScheme[0]]);
        }
    }

    DLLevelList[0] = ' ';
    DLSchemeList[0] = ' ';

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:PSW:CSCH:DL:CARR%ld%s", instance, carrier, DLSchemeList);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));
    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:PSW:LEV:DL:CARR%ld%s", instance, carrier, DLLevelList);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Handover Uplink Coding Scheme
 * Purpose:  Specifies the coding scheme for all uplink timeslots in the
 *           destination GSM band (packet switched domain, one value).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverUplinkCodingScheme(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   uplinkCodingScheme)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_UPLINK_CODING_SCHEME, uplinkCodingScheme),
    		3, "Uplink Coding Scheme");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies the handover destination. A complete list of all
/// HIFN supported values can be displayed using
/// HIFN PREPare:GSM:SIGN:HANDover:CATalog:DESTination?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR uplinkCodingScheme/.

ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDestination(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_DESTINATION, destination),
    		3, "Destination");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects a handover destination band/network used for TCH/PDCH and
/// HIFN  initiates a dual band GSM handover. This command executes handover even
/// HIFN  if the handover dialog is opened.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_HANDOVER_DUALBAND_TCH
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:DUALband:BAND:TCH
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR tch/Selects a handover destination band/network used for TCH/PDCH and
/// HIPAR tch/initiates a dual band GSM handover. This command executes handover even
/// HIPAR tch/if the handover dialog is opened.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDualbandTCH(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   tch)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_DUALBAND_TCH, tch),
    		3, "TCH");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects parameters of a handover destination and initiates a dual band
/// HIFN  GSM handover.
/// HIFN     This command executes handover even if the handover dialog is opened.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR band/Handover destination band/network used for TCH/PDCH:
/// HIPAR channel/TCH/PDCH channel in the destination GSM band.
/// HIPAR level/Absolute TCH/PDCH level in the destination GSM band.
/// HIPAR pcl/PCL of the MS in the destination GSM band.
/// HIPAR timeslot/Timeslot for the circuit switched connection the destination GSM
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverDualbandDestination(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   channel,
							ViReal64  level,
							ViInt32   pcl,
							ViInt32   timeslot)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, 0, 3),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 512, 885),
    		4, "Channel");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, level, -130.0, 0.0), 5, "Level");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, pcl, 0, 31),
    		6, "PCL");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, timeslot, 1, 7),
    		7, "Timeslot");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:DUAL:COMB:CS %s,%ld,%lf,%ld,%ld\n",
    		instance, gsmNcellBandArr[band], channel, level, pcl, timeslot);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Percentage of downlink GPRS radio blocks containing the USF to be
/// HIFN  assigned to the MS in the handover destination. In sum eight values are
/// HIFN  specified (slot 0 to slot 7).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR percentage/Percentage of downlink GPRS radio blocks containing the USF to be
/// HIPAR percentage/assigned to the MS in the handover destination. In sum eight values are
/// HIPAR percentage/specified (slot 0 to slot 7).
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverPercentageOfDownlink(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   percentage[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:PSW:UDCY:DL ", instance);
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, percentage, 8));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Handover Band
 * Purpose:  This function returns the current GSM band (source GSM band,
 *           before a handover).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryHandoverBand(ViSession instrSession,
                                            ViInt32   instance,
                                            ViInt32*  band)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_BAND, band),
    		3, "Band");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Initiate Handover
 * Purpose:  This function initiates a handover to a network selected with
 *           function rscmwgs_ConfigureHandover.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_InitiateHandover(ViSession instrSession,
                                           ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_INITIATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Handover State
 * Purpose:  This function returns the handover state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryHandoverState(ViSession instrSession,
                                             ViInt32   instance,
                                             ViInt32*  handoverState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SIGNALING_HANDOVER_STATE, handoverState),
    		3, "Handover State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the list of available handover destinations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the  List of Destination parameter
/// HIPAR listOfDestination/Comma separated list of all supported destinations. Each destination is represented as a string.
ViStatus _VI_FUNC rscmwgs_QueryHandoverDestinationCatalog(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   bufferSize,
                                                          ViChar    listOfDestination[],
                                                          ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, 2000000000),
    		3, "Buffer Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, listOfDestination), 4, "List Of Destination");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:CAT:DEST?\n", instance);
    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, cmd, bufferSize, listOfDestination, returnedValues));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN  Selects the target radio access technology for handover to another
/// HIFN  instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR destination/Selects the handover destination.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalDestination(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_HANDOVER_EXTERNAL_DESTINATION, destination),
    		3, "Destination");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the destination parameters for handover to a GSM
/// HIFN  destination at another instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR band/Selects the GSM band.
/// HIPAR dlChannel/Channel number used for the Broadcast Control Channel (BCCH).
/// HIPAR bandIndicator/Band Indicator for distinction of GSM 1800 and GSM 1900 bands.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareGSM(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   dlChannel,
							ViInt32   bandIndicator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMWGS_VAL_BAND_G085, RSCMWGS_VAL_BAND_G19),
    		3, "band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dlChannel, 1, 1023),
    		4, "DL Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandIndicator, RSCMWGS_VAL_BAND_G18, RSCMWGS_VAL_BAND_G19),
    		5, "Band Indicator");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:EXT:GSM %s,%ld,%s", instance, gsmNcellBandArr[band], dlChannel, gsmNcellBandArr[bandIndicator]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN  Configures the destination parameters for handover to an LTE
/// HIFN  destination at another instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR band/Configures the destination parameters for handover to an LTE
/// HIPAR band/destination at another instrument.
/// HIPAR dlChannel/Downlink channel number.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareLTE(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   dlChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");

    if(RsCore_InvalidViInt32Range(instrSession, band, 1, 46) != 0)
    {

        switch(band)
        {
            case(65):
            case(66):
            case(67):
            case(252):
            case(255):
                {
                    break;
                }
            default:
                {
					viCheckParm(RsCore_InvalidViInt32Value(instrSession, band), 3, "Band");
                    break;
                }
        }
    }

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:EXT:LTE OB%ld,%ld",
                          instance, band, dlChannel);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN  Configures the destination parameters for handover to a TD-SCDMA
/// HIFN  destination at another instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR band/Configures the destination parameters for handover to a TD-SCDMA
/// HIPAR band/destination at another instrument.
/// HIPAR dlChannel/Downlink channel number.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareTDSCDMA(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   dlChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMW_VAL_NCELL_TDSCDMA_BAND_OB1, RSCMW_VAL_NCELL_TDSCDMA_BAND_OB3),
    		3, "Band");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:EXT:TDSC %s,%ld",
                          instance, gs_TDSCDMANcellBandArr[band], dlChannel);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}


/// HIFN  Configures the destination parameters for handover to a WCDMA
/// HIFN  destination at another instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR band/Selects the Operating Band (OB).
/// HIPAR dlChannel/Downlink channel number.
ViStatus _VI_FUNC rscmwgs_ConfigureHandoverExternalPrepareWCDMA(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   band,
							ViInt32   dlChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, band, RSCMW_VAL_NCELL_WCDMA_BAND_OB1, RSCMW_VAL_NCELL_WCDMA_BAND_OB26),
    		3, "Band");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dlChannel, 412, 11000),
    		4, "DL Channel");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "PREP:GSM:SIGN%ld:HAND:EXT:WCDM %s,%ld",
                          instance, wcdmaNcellBandArr[band], dlChannel);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/*****************************************************************************
 * Function: Configure Trigger Frame Mode
 * Purpose:  This function configures the frame trigger mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureTriggerFrameMode(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   frameTriggerMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_TRIGGER_FRAME_MODE, frameTriggerMode),
    		3, "Frame Trigger Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Measurement Slot Settings
 * Purpose:  Specifies the uplink measurement slot, i.e. the slot evaluated
 *           by measurements running in parallel to the "GSM Signaling"
 *           application. The measurement slot is relevant for the GSM
 *           signaling measurements BER CS and BER PS and for "GSM Multi
 *           Evaluation" measurements. It is not relevant for GSM signaling
 *           BLER measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureMeasurementSlotSettings(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   slot)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_SLOT, slot),
    		3, "Slot");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Circuit Switched Statistical Settings
 * Purpose:  This function configures the scope of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedStatisticalSettings(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   mode,
							ViInt32   stopCondition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_MODE, mode),
    		3, "Mode");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_STOP_CONDITION, stopCondition),
    		4, "Stop Condition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Circuit Switched Measurement Timeout
 * Purpose:  This function configures the a timeout for the measurement. The
 *           timer is started when the measurement is initiated via a READ or
 *           INIT command. If the first measurement cycle has not been
 *           completed when the timer expires, the measurement is stopped.
 *           The measurement state changes to RDY and the reliability
 *           indicator is set to 1, indicating that a measurement timeout
 *           occurred.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedMeasurementTimeout(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  timeoutValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_TIMEOUT, timeoutValue),
    		3, "Timeout Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Circuit Switched Statistic Count
 * Purpose:  This function configures the scope of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedStatisticCount(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   statisticCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_STATISTIC_COUNT, statisticCount),
    		3, "Statistic Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Circuit Switched Limit
 * Purpose:  This function configures the upper limits for the results of
 *           the BER measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERCircuitSwitchedLimit(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViReal64  BERLimit,
                                                           ViReal64  classIIBits,
                                                           ViReal64  classlbBits,
                                                           ViReal64  ferLimit,
                                                           ViReal64  ferFACCH,
                                                           ViReal64  ferSACCH)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[5];

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_BER, BERLimit),
    		3, "BER Limits");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_CLASS_II_BITS, classIIBits),
    		4, "Class II Bits");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_CLASS_IB_BITS, classlbBits),
    		5, "Class lb Bits");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_FER, ferLimit),
    		6, "FER Limit");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_FER_FACCH, ferFACCH),
    		7, "FER FACCH");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_LIMIT_FER_SACCH, ferSACCH),
    		8, "FER SACCH");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BER Circuit Switched Measurement Init
 * Purpose:  Starts or restarts the measurement; the R&S CMW 500 enters the
 *           "RUN" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BERCircuitSwitchedMeasurementInit(ViSession instrSession,
                                                            ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_INIT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BER Circuit Switched Measurement Abort
 * Purpose:  Causes a running measurement to stop immediately; the R&S CMW
 *           enters the "OFF" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BERCircuitSwitchedMeasurementAbort(ViSession instrSession,
                                                             ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BER Circuit Switched Measurement Stop
 * Purpose:  Causes a running measurement to stop after the current
 *           evaluation period is terminated and valid results are available;
 *           the R&S CMW enters the "RDY" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BERCircuitSwitchedMeasurementStop(ViSession instrSession,
                                                            ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_STOP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query BER Circuit Switched Measurement Status
 * Purpose:  Queries the main measurement state and the measurement
 *           substates. Both measurement substates are relevant for running
 *           measurements only. Use INITiate..., STOP..., ABORt... to change
 *           the measurement state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryBERCircuitSwitchedMeasurementStatus(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32*  mainState,
							ViInt32*  syncState,
							ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, mainState), 3, "Main State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, syncState), 4, "Sync State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, resourcesState), 5, "Resources State");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BER:CSW:STAT:ALL?", instance);
    checkErr(rscmwgs_QueryMeasStatus(instrSession, buffer, mainState, syncState, resourcesState));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Read BER Circuit Switched Results
 * Purpose:  Starts a new single shot measurement and returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ReadBERCircuitSwitchedResults(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   *reliability,
                                                        ViInt32   *frames,
                                                        ViReal64  *ber,
                                                        ViInt32   *crcErrors,
                                                        ViReal64  *classII,
                                                        ViReal64  *classlb,
                                                        ViReal64  *fer,
                                                        ViInt32   *l2FramesRepeated,
                                                        ViInt32   *errorEvent,
                                                        ViInt32   *numberSIDFrames,
                                                        ViReal64  *SIDFrameErrorRate,
                                                        ViReal64  *falseBFIRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[11];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 3, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, frames), 4, "Frames");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, ber), 5, "BER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, crcErrors), 6, "CRC Errors");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, classII), 7, "Class II");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, classlb), 8, "Class lb");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, fer), 9, "FER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, l2FramesRepeated), 10, "L2 Frames Repeated");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorEvent), 11, "Error Event");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, numberSIDFrames), 12, "Number SID Frames");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, SIDFrameErrorRate), 13, "SID Frame Error Rate");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, falseBFIRate), 14, "False BFI Rate");

    sprintf (buffer, "READ:GSM:SIGN%ld:BER:CSW?\n", instance);

    checkErr(rscmwgs_GetMeas(instrSession, buffer, 6, reliability, dbl_res, &count));

    *frames    = (dbl_res[0] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[0];
    *ber       = dbl_res[1];
    *crcErrors = (dbl_res[2] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[2];
    *classII   = dbl_res[3];
    *classlb   = dbl_res[4];
    *fer       = dbl_res[5];
    *l2FramesRepeated = (dbl_res[6] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[6];
    *errorEvent = (dbl_res[7] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[7];
    *numberSIDFrames = (dbl_res[7] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[8];
    *SIDFrameErrorRate   = dbl_res[9];
    *falseBFIRate       = dbl_res[10];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Fetch BER Circuit Switched Results
 * Purpose:  Returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_FetchBERCircuitSwitchedResults(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   *reliability,
                                                         ViInt32   *frames,
                                                         ViReal64  *ber,
                                                         ViInt32   *crcErrors,
                                                         ViReal64  *classII,
                                                         ViReal64  *classlb,
                                                         ViReal64  *fer,
                                                         ViInt32   *l2FramesRepeated,
                                                         ViInt32   *errorEvent,
                                                         ViInt32   *numberSIDFrames,
                                                         ViReal64  *SIDFrameErrorRate,
                                                         ViReal64  *falseBFIRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[11];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 3, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, frames), 4, "Frames");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, ber), 5, "BER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, crcErrors), 6, "CRC Errors");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, classII), 7, "Class II");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, classlb), 8, "Class lb");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, fer), 9, "FER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, l2FramesRepeated), 10, "L2 Frames Repeated");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorEvent), 11, "Error Event");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, numberSIDFrames), 12, "Number SID Frames");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, SIDFrameErrorRate), 13, "SID Frame Error Rate");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, falseBFIRate), 14, "False BFI Rate");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BER:CSW?\n", instance);

    checkErr(rscmwgs_GetMeas(instrSession, buffer, 6, reliability, dbl_res, &count));

    *frames    = (dbl_res[0] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[0];
    *ber       = dbl_res[1];
    *crcErrors = (dbl_res[2] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[2];
    *classII   = dbl_res[3];
    *classlb   = dbl_res[4];
    *fer       = dbl_res[5];
    *l2FramesRepeated = (dbl_res[6] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[6];
    *errorEvent = (dbl_res[7] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[7];
    *numberSIDFrames = (dbl_res[7] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[8];
    *SIDFrameErrorRate   = dbl_res[9];
    *falseBFIRate       = dbl_res[10];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the intermediate results of the BER CS measurement in
/// HIFN mean BEP and signal quality mode. As indicated in the parameter
/// HIFN descriptions below, each measure mode provides valid results for
/// HIFN a subset of the parameters only. For the other parameters NCAP
/// HIFN is returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Indicates size of allocated arrays.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result; see Reliability Indicator.
/// HIPAR numberOfResults/Total number of segments to be displayed.
/// HIPAR segmentReliability/Integer value of the reliability indicator for the each segment.
/// HIPAR RXQualityFull/RX level as dimensionless index measured over the full set ofTDMA frames
/// HIPAR RXQualitySubset/RX level as dimensionless index measured in a subset of 4 SACCH frames.
/// HIPAR meanBEP/Mean BEP as dimensionless index.
/// HIPAR CVBEP/Coefficient of variation of BEP as dimensionless index.
/// HIPAR numberOfBlocks/Number of already of correctly decoded blocks.
/// HIPAR TDMAFrameNumber/Current TDMA frame number.
/// HIPAR BER/BER result (for mean BEP and signal quality mode).
ViStatus _VI_FUNC rscmwgs_FetchBERCircuitSwitchedIntermediateResults(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32   *reliability,
							ViInt32   *numberOfResults,
							ViInt32   segmentReliability[],
							ViInt32   RXQualityFull[],
							ViInt32   RXQualitySubset[],
							ViInt32   meanBEP[],
							ViInt32   CVBEP[],
							ViInt32   numberOfBlocks[],
							ViInt32   TDMAFrameNumber[],
							ViInt32   BER[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *ext_buf = 0;
    ViChar   *p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, numberOfResults), 5, "Number Of Results");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, segmentReliability), 6, "Segment Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RXQualityFull), 7, "RX Quality Full");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, RXQualitySubset), 8, "RX Quality Subset");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, meanBEP), 9, "Mean BEP");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, CVBEP), 10, "CVBEP");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, numberOfBlocks), 11, "Number Of Blocks");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, TDMAFrameNumber), 12, "TDMA Frame Number");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, BER), 13, "BER");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:INT:GSM:SIGN%ld:BER:CSW:MBEP?\n", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (ext_buf, ",\n");
    if (p2buf != NULL)
        *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    if (p2buf != NULL)
        *numberOfResults = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    i = 0;
    while ((p2buf != NULL) && (i < arraySize))
    {
        segmentReliability[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        RXQualityFull[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        RXQualitySubset[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        meanBEP[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        CVBEP[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        numberOfBlocks[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        TDMAFrameNumber[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        BER[i] = atol (p2buf);
        i++;
    }

Error:
    if (ext_buf != NULL) free (ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries duration in bursts the loopback signal needs from a transmission to detection by the R&S CMW.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR roundTripDelay/Returns duration in bursts the loopback signal needs from a transmission to detection by the R&S CMW.
ViStatus _VI_FUNC rscmwgs_QueryBERCircuitSwitchedRoundTripDelay(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   *roundTripDelay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BER_CIRCUIT_SWITCHED_ROUND_TRIP_DELAY, roundTripDelay),
    		3, "Round Trip Delay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Packet Switched Statistical Settings
 * Purpose:  This function configures the scope of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedStatisticalSettings(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   stopCondition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_STOP_CONDITION, stopCondition),
    		3, "Stop Condition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Packet Switched Measurement Timeout
 * Purpose:  This function configures the a timeout for the measurement. The
 *           timer is started when the measurement is initiated via a READ or
 *           INIT command. If the first measurement cycle has not been
 *           completed when the timer expires, the measurement is stopped.
 *           The measurement state changes to RDY and the reliability
 *           indicator is set to 1, indicating that a measurement timeout
 *           occurred.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedMeasurementTimeout(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  timeoutValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_TIMEOUT, timeoutValue),
    		3, "Timeout Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Packet Switched Statistic Count
 * Purpose:  This function configures the statistics count. The statistic
 *           count (also termed statistic length) is the integer number of
 *           measurement intervals per measurement cycle (statistics cycle,
 *           single-shot measurement). The length of a measurement interval
 *           is measurement-specific.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedStatisticCount(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   statisticCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_STATISTIC_COUNT, statisticCount),
    		3, "Statistic Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BER Packet Switched Limit
 * Purpose:  This function configures the limits for the results of the BER
 *           packet switched measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedLimit(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViReal64  classIIBits,
                                                          ViReal64  dblerLimit,
                                                          ViReal64  usfBlerLimit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_LIMIT_CLASS_II_BITS, classIIBits),
    		3, "Class II Bits");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_LIMIT_DBLER, dblerLimit),
    		4, "DBLER Limit");

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_LIMIT_USF_BLER, usfBlerLimit),
    		5, "USF BLER Limit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Defines the measurement mode for BER PS measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR measurementMode/Defines the measurement mode for BER PS measurements.
ViStatus _VI_FUNC rscmwgs_ConfigureBERPacketSwitchedMeasurementMode(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   measurementMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_MEASUREMENT_MODE, measurementMode),
    		3, "Measurement Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BER Packet Switched Measurement Init
 * Purpose:  Starts or restarts the measurement; the R&S CMW 500 enters the
 *           "RUN" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BERPacketSwitchedMeasurementInit(ViSession instrSession,
                                                           ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_INIT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BER Packet Switched Measurement Abort
 * Purpose:  Causes a running measurement to stop immediately; the R&S CMW
 *           enters the "OFF" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BERPacketSwitchedMeasurementAbort(ViSession instrSession,
                                                            ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BER Packet Switched Measurement Stop
 * Purpose:  Causes a running measurement to stop after the current
 *           evaluation period is terminated and valid results are available;
 *           the R&S CMW enters the "RDY" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BERPacketSwitchedMeasurementStop(ViSession instrSession,
                                                           ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BER_PACKET_SWITCHED_STOP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query BER Packet Switched Measurement Status
 * Purpose:  Queries the main measurement state and the measurement
 *           substates. Both measurement substates are relevant for running
 *           measurements only. Use INITiate..., STOP..., ABORt... to change
 *           the measurement state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryBERPacketSwitchedMeasurementStatus(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32*  mainState,
							ViInt32*  syncState,
							ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, mainState), 3, "Main State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, syncState), 4, "Sync State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, resourcesState), 5, "Resources State");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BER:PSW:STAT:ALL?", instance);
    checkErr(rscmwgs_QueryMeasStatus(instrSession, buffer, mainState, syncState, resourcesState));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Read BER Packet Switched Results
 * Purpose:  Starts a new single shot measurement and returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ReadBERPacketSwitchedResults(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   *reliability,
                                                       ViInt32   *frames,
                                                       ViReal64  *ber,
                                                       ViReal64  *dbler,
                                                       ViReal64  *usfBler,
                                                       ViReal64  *falseUsfDetect,
                                                       ViInt32   *CRCErrors,
                                                       ViInt32   *nonAssignedUSF)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[7];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 3, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, frames), 4, "Frames");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, ber), 5, "BER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, dbler), 6, "DBLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, usfBler), 7, "USF BLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, falseUsfDetect), 8, "False USF Detect");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, CRCErrors), 9, "CRC Errors");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, nonAssignedUSF), 10, "Non Assigned USF");

    sprintf (buffer, "READ:GSM:SIGN%ld:BER:PSW?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, 7, reliability, dbl_res, &count));

    *frames         = (dbl_res[0] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[0];
    *ber            = dbl_res[1];
    *dbler          = dbl_res[2];
    *usfBler        = dbl_res[3];
    *falseUsfDetect = dbl_res[4];
    *CRCErrors      = (dbl_res[5] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[5];
    *nonAssignedUSF = (dbl_res[6] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[6];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Fetch BER Packet Switched Results
 * Purpose:  Returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedResults(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   *reliability,
                                                        ViInt32   *frames,
                                                        ViReal64  *ber,
                                                        ViReal64  *dbler,
                                                        ViReal64  *usfBler,
                                                        ViReal64  *falseUsfDetect,
                                                        ViInt32   *crcErrors,
                                                        ViInt32   *nonAssignedUSF)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[7];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 3, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, frames), 4, "Frames");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, ber), 5, "BER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, dbler), 6, "DBLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, usfBler), 7, "USF BLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, falseUsfDetect), 8, "False USF Detect");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, crcErrors), 9, "CRC Errors");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, nonAssignedUSF), 10, "Non Assigned USF");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BER:PSW?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, 7, reliability, dbl_res, &count));

    *frames         = (ViInt32) dbl_res[0];
    *ber            = dbl_res[1];
    *dbler          = dbl_res[2];
    *usfBler        = dbl_res[3];
    *falseUsfDetect = dbl_res[4];
    *crcErrors      = (ViInt32) dbl_res[5];
    *nonAssignedUSF = (dbl_res[6] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[6];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the results of the BER PS measurement for the individual timeslots.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR carrier/Selects the carrier.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result; see Reliability Indicator.
/// HIPAR results/Returns the array of results for the BLER measurement.
ViStatus _VI_FUNC rscmwgs_ReadBERPacketSwitchedSingleCarrierResults(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   arraySize,
							ViInt32   *reliability,
							ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 5, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 6, "Results");

    sprintf (buffer, "READ:GSM:SIGN%ld:BER:PSW:CARR%ld?\n", instance, carrier);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the results of the BER PS measurement for the individual timeslots.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR carrier/Selects the carrier.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result; see Reliability Indicator.
/// HIPAR results/Returns the array of results for the BLER measurement.
ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedSingleCarrierResults(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   carrier,
							ViInt32   arraySize,
							ViInt32   *reliability,
							ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 5, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 6, "Results");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BER:PSW:CARR%ld?\n", instance, carrier);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the intermediate results of the BER PS measurement for
/// HIFN mean BEP measurement (TBF level EGPRS) in "Mean BEP" mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Document parameter here.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR numberOfResults/Total number of segments to be displayed.
/// HIPAR segmentReliability/Integer value of the reliability indicator for the each segment.
/// HIPAR meanBEPGMSK/Mean BEP (GMSK) as dimensionless index.
/// HIPAR CVBEPGMSK/Coefficient of variation of BEP (GMSK) as dimensionless index.
/// HIPAR meanBEP8PSK/Mean BEP (8PSK) as dimensionless index.
/// HIPAR CVBEP8PSK/Coefficient of variation of BEP (8PSK) as dimensionless index.
/// HIPAR TDMAFrameNumber/Current TDMA frame number.
/// HIPAR BER/BER result (for mean BEP and signal quality mode).
ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedIntermediateResults(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32   *reliability,
							ViInt32   *numberOfResults,
							ViInt32   segmentReliability[],
							ViInt32   meanBEPGMSK[],
							ViInt32   CVBEPGMSK[],
							ViInt32   meanBEP8PSK[],
							ViInt32   CVBEP8PSK[],
							ViInt32   TDMAFrameNumber[],
							ViInt32   BER[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *ext_buf = 0;
    ViChar   *p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, numberOfResults), 5, "Number Of Results");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, segmentReliability), 6, "Segment Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, meanBEPGMSK), 7, "Mean BEP GMSK");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, CVBEPGMSK), 8, "CV BEP GMSK");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, meanBEP8PSK), 9, "Mean BEP 8PSK");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, CVBEP8PSK), 10, "CV BEP 8PSK");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, TDMAFrameNumber), 11, "TDMA Frame Number");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, BER), 12, "BER");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:INT:GSM:SIGN%ld:BER:PSW:MBEP?\n", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (ext_buf, ",\n");
    if (p2buf != NULL)
        *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    if (p2buf != NULL)
        *numberOfResults = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    i = 0;
    while ((p2buf != NULL) && (i < arraySize))
    {
        segmentReliability[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        meanBEPGMSK[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        CVBEPGMSK[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        meanBEP8PSK[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        CVBEP8PSK[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        TDMAFrameNumber[i] = atol (p2buf);

        p2buf = strtok (NULL, ",\n");
        if (p2buf == NULL)
            break;
        BER[i] = atol (p2buf);
        i++;
    }

Error:
    if (ext_buf != NULL) free (ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the intermediate results of the BER PS measurement for enhanced mean BEP measurement (TBF level EGPRS2-A) in "Mean BEP" mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Indicates size of allocated arrays.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR numberOfResults/Total number of segments to be displayed.
/// HIPAR segmentsResults/Results for each measured segment.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwgs_FetchBERPacketSwitchedIntermediateEnhancedResults(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   arraySize,
							ViInt32   *reliability,
							ViInt32   *numberOfResults,
							ViInt32   segmentsResults[],
							ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  i = 0;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 3, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, numberOfResults), 4, "Number Of Results");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, segmentsResults), 5, "Segments Results");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:INT:GSM:SIGN%ld:BER:PSW:MBEP:ENH?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_RESPONSE;
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_RESPONSE;
    *numberOfResults = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_RESPONSE;
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            segmentsResults[i++] = atol (p2buf);
        }
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

Error:
    if (ext_buf != NULL) free (ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BLER Measurement Timeout
 * Purpose:  This function configures the a timeout for the measurement. The
 *           timer is started when the measurement is initiated via a READ or
 *           INIT command. If the first measurement cycle has not been
 *           completed when the timer expires, the measurement is stopped.
 *           The measurement state changes to RDY and the reliability
 *           indicator is set to 1, indicating that a measurement timeout
 *           occurred.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBLERMeasurementTimeout(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViReal64  timeoutValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_BLER_TIMEOUT, timeoutValue),
    		3, "Timeout Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure BLER Statistic Count
 * Purpose:  This function configures the statistics count. The statistic
 *           count (also termed statistic length) is the integer number of
 *           measurement intervals per measurement cycle (statistics cycle,
 *           single-shot measurement). The length of a measurement interval
 *           is measurement-specific.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ConfigureBLERStatisticCount(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   statisticCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_BLER_STATISTIC_COUNT, statisticCount),
    		3, "Statistic Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BLER Measurement Init
 * Purpose:  Starts or restarts the measurement; the R&S CMW 500 enters the
 *           "RUN" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BLERMeasurementInit(ViSession instrSession,
                                              ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BLER_INIT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BLER Measurement Abort
 * Purpose:  Causes a running measurement to stop immediately; the R&S CMW
 *           enters the "OFF" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BLERMeasurementAbort(ViSession instrSession,
                                               ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BLER_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: BLER Measurement Stop
 * Purpose:  Causes a running measurement to stop after the current
 *           evaluation period is terminated and valid results are available;
 *           the R&S CMW enters the "RDY" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_BLERMeasurementStop(ViSession instrSession,
                                              ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_BLER_STOP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query BLER Measurement Status
 * Purpose:  Queries the main measurement state and the measurement
 *           substates. Both measurement substates are relevant for running
 *           measurements only. Use INITiate..., STOP..., ABORt... to change
 *           the measurement state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryBLERMeasurementStatus(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  mainState,
                                                     ViInt32*  syncState,
                                                     ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, mainState), 3, "Main State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, syncState), 4, "Sync State");
    if (resourcesState == NULL)
    {
        viCheckParm(RsCore_InvalidNullPointer(instrSession, resourcesState),
        	5, "Resources State");
    }

    sprintf (buffer, "FETC:GSM:SIGN%ld:BLER:STAT:ALL?", instance);
    checkErr(rscmwgs_QueryMeasStatus(instrSession, buffer, mainState, syncState, resourcesState));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Starts a new single shot measurement and returns the results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR carrier/Selects the carrier.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR results/Returns the array of results for the BLER measurement.
ViStatus _VI_FUNC rscmwgs_ReadBLERSingleCarrierResults(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   carrier,
                                                       ViInt32   arraySize,
                                                       ViInt32   *reliability,
                                                       ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 5, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 6, "Results");

    sprintf (buffer, "READ:GSM:SIGN%ld:BLER:CARR%ld?\n", instance, carrier);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, &count));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR carrier/Selects the carrier.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR results/Returns the array of results for the BLER measurement.
ViStatus _VI_FUNC rscmwgs_FetchBLERSingleCarrierResults(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   carrier,
                                                        ViInt32   arraySize,
                                                        ViInt32   *reliability,
                                                        ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 5, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 6, "Results");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BLER:CARR%ld?\n", instance, carrier);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, &count));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Starts a new single shot measurement and returns the results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR results/Returns the array of results for the BLER measurement.
ViStatus _VI_FUNC rscmwgs_ReadBLEROverAllResults(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   arraySize,
                                                 ViInt32   *reliability,
                                                 ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 5, "Results");

    sprintf (buffer, "READ:GSM:SIGN%ld:BLER:OALL?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, &count));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Starts a new single shot measurement and returns the results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR results/Returns the array of results for the BLER measurement.
ViStatus _VI_FUNC rscmwgs_FetchBLEROverAllResults(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   arraySize,
                                                  ViInt32   *reliability,
                                                  ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 5, "Results");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BLER:OALL?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, &count));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function configures a timeout for the measurement. The
/// HIFN timer is started when the measurement is initiated via a READ or
/// HIFN INIT command.
/// HIFN It is not started if the measurement is initiated manually
/// HIFN (ON/OFF key or RESTART/STOP key).
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR timeoutValue/Defines a timeout value.
ViStatus _VI_FUNC rscmwgs_ConfigureRLCThroughputMeasurementTimeout(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  timeoutValue)
{
  ViStatus error = VI_SUCCESS;
  ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_RLC_THROUGHPUT_TIMEOUT, timeoutValue),
    		3, "Timeout Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN configures the scope of the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR repetition/Defines the repetition mode of the measurement. The repetition
/// HIPAR mode specifies whether the measurement is stopped after a
/// HIPAR single-shot or repeated continuously. Use parameter Window to
/// HIPAR configure the duration of a single shot.
/// HIPAR window/Defines duration of a single-shot measurement, i.e. the time
/// HIPAR interval covered by a throughput result trace.
ViStatus _VI_FUNC rscmwgs_ConfigureRLCThroughputMeasurement(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   repetition,
                                                            ViReal64  window)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_RLC_THROUGHPUT_REPETITION, repetition),
    		3, "Repetition");
    if (repetition == RSCMWGS_VAL_RLC_REP_SINGLE)
    {
        viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_RLC_THROUGHPUT_WINDOW, window),
        		4, "Window");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN Starts or restarts the measurement; the R&S CMW enters the "RUN" state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_RLCThroughputMeasurementInit(ViSession instrSession,
                                                       ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_RLC_THROUGHPUT_INIT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Causes a running measurement to stop immediately; the R&S CMW
/// HIFN enters the "OFF" state..
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_RLCThroughputMeasurementAbort(ViSession instrSession,
                                                        ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_RLC_THROUGHPUT_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Causes a running measurement to stop after the current
/// HIFN evaluation period is terminated and valid results are available;
/// HIFN the R&S CMW enters the "RDY" state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_RLCThroughputMeasurementStop(ViSession instrSession,
                                                       ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_RLC_THROUGHPUT_STOP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries the main measurement state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mainState/Returns main state.
ViStatus _VI_FUNC rscmwgs_QueryRLCThroughputMeasurementStatus(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   *mainState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_RLC_THROUGHPUT_STATE, mainState));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries the main measurement state and the measurement
/// HIFN substates. Both measurement substates are relevant for running
/// HIFN measurements only. Use INITiate..., STOP..., ABORt... to change
/// HIFN the measurement state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mainState/Queries the main measurement state and the measurement substates.
/// HIPAR syncState/Returns synchronization state.
/// HIPAR resourcesState/Returns resources state.
ViStatus _VI_FUNC rscmwgs_QueryRLCThroughputMeasurementStatusAll(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   *mainState,
							ViInt32   *syncState,
							ViInt32   *resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, mainState), 3, "Main State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, syncState), 4, "Sync State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, resourcesState), 5, "Resources State");

    sprintf (buffer, "FETC:GSM:SIGN%ld:THR:STAT:ALL?", instance);
    checkErr(rscmwgs_QueryMeasStatus(instrSession, buffer, mainState, syncState, resourcesState));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Starts a new single shot measurement and returns the values of
/// HIFN the throughput trace. The results of the downlink/uplink,
/// HIFN PDU/SDU, average/current traces can be retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR direction/Selects the direction.
/// HIPAR trace/Selects the trace..
/// HIPAR type/Selects the trace type.
/// HIPAR arraySize/Pass the size of Throughput Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire
/// HIPAR measurement result; see Reliability Indicator.
/// HIPAR throughput/Returns the array of n throughput trace values
/// HIPAR returnedValues/Returns the number of values, that was read from instrument.
ViStatus _VI_FUNC rscmwgs_ReadRLCThroughputSingleTraceResult(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   direction,
                                                             ViInt32   trace,
                                                             ViInt32   type,
                                                             ViInt32   arraySize,
                                                             ViInt32   *reliability,
                                                             ViReal64  throughput[],
                                                             ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, direction, RSCMWGS_VAL_DOWNLINK, RSCMWGS_VAL_UPLINK),
    		3, "Direction");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, RSCMWGS_VAL_RLC_PDU, RSCMWGS_VAL_RLC_SDU),
    		4, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, RSCMWGS_VAL_TRACE_TYPE_CURR, RSCMWGS_VAL_TRACE_TYPE_AVER),
    		5, "Type");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 7, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, throughput), 8, "Throughput");

    sprintf (buffer, "READ:GSM:SIGN%ld:THR:TRAC:%s:%s:%s?\n", instance, rlcDirectionArr[direction], rlcTrace[trace],rlcType[type]);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, throughput, returnedValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the values of the throughput trace. The results of the
/// HIFN downlink/uplink, PDU/SDU, average/current traces can be
/// HIFN retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR direction/Selects the direction.
/// HIPAR trace/Selects the trace..
/// HIPAR type/Selects the trace type.
/// HIPAR arraySize/Pass the size of Throughput Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire
/// HIPAR             measurement result; see Reliability Indicator.
/// HIPAR throughput/Returns the array of n throughput trace values
/// HIPAR returnedValues/Returns the number of values, that was read from instrument.
ViStatus _VI_FUNC rscmwgs_FetchRLCThroughputSingleTraceResult(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   direction,
							ViInt32   trace,
							ViInt32   type,
							ViInt32   arraySize,
							ViInt32   *reliability,
							ViReal64  throughput[],
							ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, direction, RSCMWGS_VAL_DOWNLINK, RSCMWGS_VAL_UPLINK),
    		3, "Direction");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, RSCMWGS_VAL_RLC_PDU, RSCMWGS_VAL_RLC_SDU),
    		4, "Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trace, RSCMWGS_VAL_TRACE_TYPE_CURR, RSCMWGS_VAL_TRACE_TYPE_AVER),
    		5, "Type");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 7, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, throughput), 8, "Throughput");

    sprintf (buffer, "FETC:GSM:SIGN%ld:THR:TRAC:%s:%s:%s?\n", instance, rlcDirectionArr[direction], rlcTrace[trace],rlcType[type]);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, throughput, returnedValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Starts a new single shot measurement and returns all single
/// HIFN value throughput results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire
/// HIPAR             measurement result; see Reliability Indicator.
/// HIPAR results/Returns the array of results for the RLC Throughput measurement.
ViStatus _VI_FUNC rscmwgs_ReadRLCThroughputResultsAll(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   arraySize,
                                                      ViInt32   *reliability,
                                                      ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 5, "Results");

    sprintf (buffer, "READ:GSM:SIGN%ld:THR?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, &count));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns all single value throughput results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Pass the size of Results Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire
/// HIPAR             measurement result; see Reliability Indicator.
/// HIPAR results/Returns the array of results for the RLC Throughput measurement.
ViStatus _VI_FUNC rscmwgs_FetchRLCThroughputResultsAll(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   arraySize,
                                                       ViInt32   *reliability,
                                                       ViReal64  results[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, results), 5, "Results");

    sprintf (buffer, "FETC:GSM:SIGN%ld:THR?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, arraySize, reliability, results, &count));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Defines a timeout for the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR timeoutValue/Defines a timeout for the measurement.
ViStatus _VI_FUNC rscmwgs_ConfigureCMRPerformanceMeasurementTimeout(
							ViSession instrSession,
							ViInt32   instance,
							ViReal64  timeoutValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_CMR_PERFORMANCE_TIMEOUT, timeoutValue),
    		3, "Timeout Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Target level reported to the MS during CMR performance test.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR targetLevel/Target level reported to the MS during CMR performance test.
ViStatus _VI_FUNC rscmwgs_ConfigureCMRPerformanceMeasurement(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64  targetLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViReal64(instrSession, repCap, RSCMWGS_ATTR_CMR_PERFORMANCE_TARGET_LEVEL, targetLevel),
    		3, "Target Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Starts or restarts the measurement; the R&S CMW enters the "RUN" state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_CMRPerformanceMeasurementInit(ViSession instrSession,
                                                        ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CMR_PERFORMANCE_INIT, NULL),
    		3, "CMR Performance Init");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Aborts the measurement
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_CMRPerformanceMeasurementAbort(ViSession instrSession,
                                                         ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CMR_PERFORMANCE_ABORT, NULL),
    		3, "CMR Performance Abort");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Stops the measurement
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
ViStatus _VI_FUNC rscmwgs_CMRPerformanceMeasurementStop(ViSession instrSession,
                                                        ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CMR_PERFORMANCE_STOP, NULL),
    		3, "CMR Performance Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries the main measurement state and the measurement substates
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR mainState/Returns main state.
/// HIPAR syncState/Returns synchronization state.
/// HIPAR resourcesState/Returns resources state.
ViStatus _VI_FUNC rscmwgs_QueryCMRPerformanceMeasurementStatusAll(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   *mainState,
							ViInt32   *syncState,
							ViInt32   *resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, mainState), 3, "Main State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, syncState), 4, "Sync State");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, resourcesState), 5, "Resources State");

    sprintf (buffer, "FETC:GSM:SIGN%ld:CPER:STAT:ALL?", instance);
    checkErr(rscmwgs_QueryMeasStatus(instrSession, buffer, mainState, syncState, resourcesState));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns all results of the signaling CMR performance measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Pass the size of Result Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR result/Returns used codec mode number.
/// HIPAR returnedValues/Returns the number of values, that was read from instrument.
ViStatus _VI_FUNC rscmwgs_ReadCMRPerformanceResult(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   *reliability,
                                                   ViInt32   result[],
                                                   ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *ext_buf = 0;
    ViChar   *p2buf = 0;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, result), 5, "Result");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:GSM:SIGN%ld:CPER?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_RESPONSE;
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_RESPONSE;
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            result[i++] = atol (p2buf);
        }
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

Error:
    if (ext_buf != NULL) free (ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns all results of the signaling CMR performance measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/Pass the size of Result Array
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement result
/// HIPAR result/Returns used codec mode number.
/// HIPAR returnedValues/Returns the number of values, that was read from instrument.
ViStatus _VI_FUNC rscmwgs_FetchCMRPerformanceResult(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   arraySize,
                                                    ViInt32   *reliability,
                                                    ViInt32   result[],
                                                    ViInt32   *returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *ext_buf = 0;
    ViChar   *p2buf = 0;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 7, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, result), 8, "Result");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:GSM:SIGN%ld:CPER?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_RESPONSE;
    *reliability = atol (p2buf);

    p2buf = strtok (NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_RESPONSE;
    while (p2buf != NULL)
    {
        if (i<arraySize)
        {
            result[i++] = atol (p2buf);
        }
        p2buf = strtok (NULL, ",\n");
    }
    if (returnedValues) *returnedValues=i;

Error:
    if (ext_buf != NULL) free (ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function sets the core network domain for the outgoing SMS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR domain/This control sets the core network domain for the outgoing SMS.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageDomain(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   domain)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_DOMAIN, domain),
    		3, "Domain");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN configures parameters of the Short Message Service (SMS)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR codingGroup/This control defines how to interprete SMS signaling information.
/// HIPAR messageClass/This control specifies default saving of SMS as defined in 3GPP TS 23.038.

/// HIPAR originatorSMSCAddress/This control specifies the phone number of SMS center.
/// HIPAR originatingAddress/This control specifies the phone number of the device which has
/// HIPAR                    sent SMS.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageInternalParameters(
							ViSession instrSession,
							ViInt32   instance,
							ViInt32   codingGroup,
							ViInt32   messageClass,
							ViString  originatorSMSCAddress,
							ViString  originatingAddress)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));
    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_CODING_GROUP, codingGroup),
    		3, "Coding Group");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_CLASS, messageClass),
    		4, "Message Class");

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_ORIGINATOR_SMSC_ADDRESS, originatorSMSCAddress),
    		5, "Originator SMSC Adddress");

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_ORIGINATING_ADDRESS, originatingAddress),
    		6, "Originating Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the date and time source for service center time
/// HIFN  stamp.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR source/Selects the date and time source.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingServiceTimeSource(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_SERVICE_TIME_SOURCE, source),
    		3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the service center time stamp time for the
/// HIFN  time source User.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR year/Year.
/// HIPAR month/Month.
/// HIPAR day/Day.
/// HIPAR hour/Hour.
/// HIPAR minute/Minute
/// HIPAR second/Second.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingServiceTimeDate(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   year,
                                                     ViInt32   month,
                                                     ViInt32   day,
                                                     ViInt32   hour,
                                                     ViInt32   minute,
                                                     ViInt32   second)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, year, 2011, 9999),
    		3, "Year");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, month, 1, 12),
    		4, "Month");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, day, 1, 31),
    		5, "Day");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, hour, 0, 23),
    		6, "Hour");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, minute, 0, 59),
    		7, "Minute");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, second, 0, 59),
    		8, "Second");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:SMS:OUTG:SCTS:DATE %ld,%ld,%ld\n",
                                                                instance, day, month, year);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:SMS:OUTG:SCTS:TIME %ld,%ld,%ld\n", instance, hour, minute, second);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: SMS Outgoing Message Text
 * Purpose:  This function defines the message text for SMS messages to be
 *           sent to the MS. It is encoded as 7-bit ASCII text.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageText(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViString  messageText)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_DATA_CODING, RSCMW_VAL_SMS_OUT_DATA_CODING_BIT7));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_TEXT, messageText),
    		3, "Message Text");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function defines the SMS message encoded as 8-bit binary data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR arraySize/This control defines the size of Message array (message length).
/// HIPAR messageText/The message in hexadecimal format.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingMessageBinary(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViUInt8   message[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   buffer[RS_MAX_MESSAGE_BUF_SIZE]="";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   *p2buf;
    ViInt32  i=0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, arraySize, 1, 2000000000),
    		3, "Array Size");

    checkErr(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_MESSAGE_DATA_CODING, RSCMW_VAL_SMS_OUT_DATA_CODING_BIT8));

	p2buf = buffer;
    for (i=0;i<arraySize;i++)
		p2buf += sprintf (p2buf,"%X",message[i]);

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:SMS:OUTG:BIN #H%s", instance, buffer);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the status of the last sent message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR lastMessageSent/Queries the status of the last sent message.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingLastMessageSent(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  lastMessageSent)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_LAST_MESSAGE_SENT, lastMessageSent),
    		3, "Last Message Sent");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: SMS Incoming Message Reset
 * Purpose:  This function resets all parameters related to a received SMS
 *           message. The message text and the information about the message
 *           length are deleted. The "message read" flag is set to true.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_SMSIncomingMessageReset(ViSession instrSession,
                                                  ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the TP protocol identifier (TP-PID) value to be sent.
/// HIFN
/// HIFN  Attribute(s):
/// HIFN  RSCMWGS_ATTR_SMS_OUTGOING_PROTOCOL_IDENTIFIER
/// HIFN
/// HIFN  Remote-control command(s):
/// HIFN  CONFigure:GSM:SIGN:SMS:OUTGoing:PIDentifier
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR protocolIdentifier/Specifies the TP protocol identifier (TP-PID) value to be sent.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingProtocolIdentifier(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViString  protocolIdentifier)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:SMS:OUTG:PID #H%s", instance, protocolIdentifier);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the TP user data header.
/// HIFN
/// HIFN  Attribute(s):
/// HIFN  RSCMWGS_ATTR_SMS_OUTGOING_USER_DATA_HEADER_STATE
/// HIFN  RSCMWGS_ATTR_SMS_OUTGOING_USER_DATA_HEADER
/// HIFN
/// HIFN  Remote-control command(s):
/// HIFN  CONFigure:GSM:SIGN:SMS:OUTGoing:UDHeader
/// HIFN  CONFigure:GSM:SIGN:SMS:OUTGoing:UDHeader
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enable/Enables / disables sending the user data header.
/// HIPAR userDataHeader/Configures the TP user data header.
ViStatus _VI_FUNC rscmwgs_SMSOutgoingUserDataHeader(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViBoolean enable,
                                                    ViString  userDataHeader)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_SMS_OUTGOING_USER_DATA_HEADER_STATE, enable),
    		3, "Enable");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:SMS:OUTG:UDH #H%s", instance, userDataHeader);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the currently processed SMS segment and the total number of
/// HIFN  segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR current/Current number of concatenated SMS.
/// HIPAR total/Total number of concatenated SMS.
ViStatus _VI_FUNC rscmwgs_QuerySMSOutgoingMessageSegment(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   *current,
                                                         ViInt32   *total)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, current), 3, "Current");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, total), 4, "Total");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:SMS:OUTG:INFO:SEGM?", instance);
    checkErr(RsCore_QueryTupleViInt32(instrSession, cmd, current, total, NULL, NULL));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query SMS Incoming Message Status
 * Purpose:  This function queries parameters related to a last received SMS
 *           message.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageStatus(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViBoolean *status,
                                                        ViInt32   *messageLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_READ_FLAG, status),
    		3, "Status");

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_LENGTH, messageLength),
    		4, "Message Length");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query SMS Incoming Message Text
 * Purpose:  Returns the text of the last SMS message received from the MS.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageText(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   bufferSize,
                                                      ViChar    *messageText)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_SMS_INCOMING_MESSAGE_TEXT,
    		bufferSize, messageText),
    		3, "Message Text");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the information of the last received SMS message coding.
/// HIFN The message can be coded as a 7 bit ASCII text or 8 bit binary data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR messageCoding/Returns the last received SMS message coding
ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageDataCoding(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   *messageCoding)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_GetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_SMS_INCOMMING_MESSAGE_DATA_CODING, messageCoding),
    		3, "Message Coding");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Queries the current number and the total number of the concatenated SMS message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR current/Current number of concatenated SMS.
/// HIPAR total/Total number of concatenated SMS.
ViStatus _VI_FUNC rscmwgs_QuerySMSIncomingMessageSegment(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   *current,
                                                         ViInt32   *total)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, current), 3, "Current");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, total), 4, "Total");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:GSM:SIGN%ld:SMS:INC:INFO:SEGM?", instance);
    checkErr(RsCore_QueryTupleViInt32(instrSession, cmd, current, total, NULL, NULL));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables CBS generally.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_GENERALLY_ENABLED
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:CBCH:ENABle
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enabled/Enables CBS generally.
ViStatus _VI_FUNC rscmwgs_CBSGenerallyEnabled(ViSession instrSession,
                                              ViInt32   instance,
                                              ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CBS_GENERALLY_ENABLED, enabled),
    		3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables the particular CB message.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_GENERALLY_ENABLED
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:MESSage:ENABle
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enabled/Enables the particular CB message.
ViStatus _VI_FUNC rscmwgs_CBSMessageEnabled(ViSession instrSession,
                                            ViInt32   instance,
                                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CBS_MESSAGE_ENABLED, enabled),
    		3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function identifies source or type of a CB message. Edit this
/// HIFN  parameter for user defined settings. Additionally, hexadecimal values
/// HIFN  are displayed for information.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_MESSAGE_ID
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:MESSage:ID
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR id/Identifies source or type of a CB message. Edit this parameter for
/// HIPAR id/user defined settings. Additionally, hexadecimal values are displayed
/// HIPAR id/for information.
ViStatus _VI_FUNC rscmwgs_CBSMessageID(ViSession instrSession,
                                       ViInt32   instance,
                                       ViInt32   id)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CBS_MESSAGE_ID, id),
    		3, "ID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the severity of the message ID.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_MESSAGE_ID_TYPE
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:MESSage:IDTYpe
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR idType/Specifies the severity of the message ID.
ViStatus _VI_FUNC rscmwgs_CBSMessageIDType(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   idType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CBS_MESSAGE_ID_TYPE, idType),
    		3, "ID Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies language using the GSM 7 bit default alphabet.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_MESSAGE_DATA_CODE_SCHEME
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:MESSage:DCSCheme
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR dataCodeScheme/Specifies language using the GSM 7 bit default alphabet.
ViStatus _VI_FUNC rscmwgs_CBSMessageDataCodeScheme(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   dataCodeScheme)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CBS_MESSAGE_DATA_CODE_SCHEME, dataCodeScheme),
    		3, "Data Code Scheme");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function indicates the privilege category of a CB message.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_MESSAGE_CATEGORY
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:MESSage:CATegory
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR category/Indicates the privilege category of a CB message.
ViStatus _VI_FUNC rscmwgs_CBSMessageCategory(ViSession instrSession,
                                             ViInt32   instance,
                                             ViInt32   category)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CBS_MESSAGE_CATEGORY, category),
    		3, "Category");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines the CB message text. Up to 160 characters.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_MESSAGE_DATA
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:MESSage:DATA
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR data/Defines the CB message text. Up to 160 characters.
ViStatus _VI_FUNC rscmwgs_CBSMessageData(ViSession instrSession,
                                         ViInt32   instance,
                                         ViString  data)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViString(instrSession, repCap, RSCMWGS_ATTR_CBS_MESSAGE_DATA, data),
    		3, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the repetition period to broadcast the CB
/// HIFN  message again.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_MESSAGE_PERIOD
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:MESSage:PERiod
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR period/Specifies the repetition period to broadcast the CB message again.
ViStatus _VI_FUNC rscmwgs_CBSMessagePeriod(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   period)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CBS_MESSAGE_PERIOD, period),
    		3, "Period");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the unique CB message identification.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR geoScope/Sets the geographical area over which the message code is unique.
/// HIPAR messageCode/CB message identification.
/// HIPAR autoIncrement/Sets the Auto Increment.
/// HIPAR updateNumber/Indication of a content change of the same CB message.
ViStatus _VI_FUNC rscmwgs_CBSMessageSerial(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   geoScope,
                                           ViInt32   messageCode,
                                           ViBoolean autoIncrement,
                                           ViInt32   updateNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, geoScope, 0, 3),
    		3, "Geo Scope");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, messageCode, 0, 1023),
    		4, "Message Code");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, updateNumber, 0, 15),
    		6, "Update Number");

    snprintf (cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:CBS:MESS:SER %s,%ld,%s,%ld\n", instance, geoScopeArr[geoScope], messageCode, switchArr[autoIncrement], updateNumber);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables DRX for CBS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR enabled/Enables DRX for CBS.
ViStatus _VI_FUNC rscmwgs_CBSDRXEnabled(ViSession instrSession,
                                        ViInt32   instance,
                                        ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_CBS_DRX_ENABLED, enabled),
    		3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the length of DRX (L) that the MS can use for
/// HIFN  the processing of particular CB message. Define the value matching with
/// HIFN  the position of the specific CB message within the CBS sheduling
/// HIFN  period.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_DRX_LENGTH_OF_PERIOD
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:DRX:LENGth
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR lengthOfPeriod/Specifies the length of DRX (L) that the MS can use for the processing
/// HIPAR lengthOfPeriod/of particular CB message. Define the value matching with the position
/// HIPAR lengthOfPeriod/of the specific CB message within the CBS sheduling period.
ViStatus _VI_FUNC rscmwgs_CBSDRXLengthOfPeriod(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   lengthOfPeriod)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CBS_DRX_LENGTH_OF_PERIOD, lengthOfPeriod),
    		3, "Length Of Period");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the offset (O) within period of scheduling message.
/// HIFN  This offset is used for the transmission of a scheduling message.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSCMWGS_ATTR_CBS_DRX_OFFSET
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CONFigure:GSM:SIGN:CBS:DRX:OFFSet
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR offset/Offset (O) within period of scheduling message. This offset is used
/// HIPAR offset/for the transmission of a scheduling message.
ViStatus _VI_FUNC rscmwgs_CBSDRXOffset(ViSession instrSession,
                                       ViInt32   instance,
                                       ViInt32   offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_CBS_DRX_OFFSET, offset),
    		3, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the MS measurement report.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR report/Enables or disables the MS measurement report.
/// HIPAR wcdmaMeasurementQuantity/Selects whether the MS shall determine the RSCP or the Ec/No during
/// HIPAR wcdmaMeasurementQuantity/WCDMA neighbor cell measurements.
/// HIPAR lteMeasurementQuantity/Selects whether the MS shall determine the RSRP or the RSRQ during LTE
/// HIPAR lteMeasurementQuantity/neighbor cell measurements.
ViStatus _VI_FUNC rscmwgs_ConfigureMeasurementReportSettings(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViBoolean report,
                                                             ViInt32   WCDMAMeasurementQuantity,
                                                             ViInt32   LTEMeasurementQuantity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORT_ENABLED, report),
    		3, "Report");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORT_WCDMA_QUANTITY, WCDMAMeasurementQuantity),
    		4, "WCDMA Measurement Quantity");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MEASUREMENT_REPORT_LTE_QUANTITY, LTEMeasurementQuantity),
    		5, "LTE Measurement Quantity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Messages exchanged between the GSM signaling application and the MS can be monitored. For this purpose, the messages are sent to an external PC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR addGSMSignalingToLogging/Enables or disables message monitoring for the GSM signaling application.
/// HIPAR loggingPCIPv4Address/Selects the IP address to which signaling messages have to be sent for message monitoring.
ViStatus _VI_FUNC rscmwgs_ConfigureMessageMonitoring(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViBoolean addGSMSignalingToLogging,
                                                     ViInt32   loggingPCIPv4Address)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwgs_SetAttributeViBoolean(instrSession, repCap, RSCMWGS_ATTR_MESSAGE_MONITORING_ADD_GSM_SIGNALING_TO_LOGGING, addGSMSignalingToLogging),
    		3, "Add GSM Signaling To Logging");

    viCheckParm(rscmwgs_SetAttributeViInt32(instrSession, repCap, RSCMWGS_ATTR_MESSAGE_MONITORING_LOGGING_PC_IPV4_ADDRESS, loggingPCIPv4Address),
    		4, "Logging PC IPv4 Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries configured IP address.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of firmware application.
/// HIPAR bufferSize/Defines the size of buffer in 'IP Address'.
/// HIPAR loggingPCIPv4Address/Selects the IP address to which signaling messages have to be sent for message monitoring.
/// HIPAR IPAddress/Returns resulting IP address.
ViStatus _VI_FUNC rscmwgs_QueryMessageMonitoringIPAddress(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   bufferSize,
                                                          ViInt32   *loggingPCIPv4Address,
                                                          ViChar    IPAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[RS_MAX_SHORT_MESSAGE_BUF_SIZE] = "";
    ViChar   tempIP[RS_MAX_SHORT_MESSAGE_BUF_SIZE] = "";
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:GSM:SIGN%ld:MMON:STAT:IPAD?\n", instance);
    checkErr(RsCore_QueryViStringShort(instrSession, cmd, buffer));

    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (buffer, ",");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_STATE;

    *loggingPCIPv4Address = RsCore_FindStringIndex(LoggingPCIPv4AddressArr, p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        return RSCMWGS_ERROR_INCORRECT_STATE;

    sscanf (p2buf, "%*1[\"']%[^'\"]", tempIP );
    strncpy (IPAddress, tempIP, bufferSize);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: rscmwgs_SetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to set
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_SetAttributeViInt32(ViSession instrSession,
                                              ViString  channelName,
                                              ViUInt32  attributeId,
                                              ViInt32   value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_SetAttributeViInt32(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rscmwgs_SetAttributeViReal64(ViSession instrSession,
                                               ViString  channelName,
                                               ViUInt32  attributeId,
                                               ViReal64  value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_SetAttributeViReal64(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViString */
ViStatus _VI_FUNC rscmwgs_SetAttributeViString(ViSession instrSession,
                                               ViString  channelName,
                                               ViUInt32  attributeId,
                                               ViString  value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_SetAttributeViString(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rscmwgs_SetAttributeViBoolean(ViSession instrSession,
                                                ViString  channelName,
                                                ViUInt32  attributeId,
                                                ViBoolean value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_SetAttributeViBoolean(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViSession */
ViStatus _VI_FUNC rscmwgs_SetAttributeViSession(ViSession instrSession,
                                                ViString  channelName,
                                                ViUInt32  attributeId,
                                                ViSession value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_SetAttributeViSession(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: rscmwgs_GetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to get
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession attributes.
 *****************************************************************************/

/* ViInt32 */
ViStatus _VI_FUNC rscmwgs_GetAttributeViInt32(ViSession instrSession,
                                              ViString  channelName,
                                              ViUInt32  attributeId,
                                              ViInt32   *value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);
	error = RsCore_GetAttributeViInt32(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rscmwgs_GetAttributeViReal64(ViSession instrSession,
                                               ViString  channelName,
                                               ViUInt32  attributeId,
                                               ViReal64  *value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_GetAttributeViReal64(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViString */
ViStatus _VI_FUNC rscmwgs_GetAttributeViString(ViSession instrSession,
                                               ViString  channelName,
                                               ViUInt32  attributeId,
                                               ViInt32   bufSize,
                                               ViChar    value[])
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_GetAttributeViString(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, bufSize,
	                                    value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rscmwgs_GetAttributeViBoolean(ViSession instrSession,
                                                ViString  channelName,
                                                ViUInt32  attributeId,
                                                ViBoolean *value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_GetAttributeViBoolean(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViSession */
ViStatus _VI_FUNC rscmwgs_GetAttributeViSession(ViSession instrSession,
                                                ViString  channelName,
                                                ViUInt32  attributeId,
                                                ViSession *value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_GetAttributeViSession(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN Function used by Hi-level functions to obtain a repCap name from:
/// HIFN - attributeID
/// HIFN - repCapNameID
/// HIFN - 0-based index in the repCapNames
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repCapNameId/RepCap Name ID.
/// HIPAR index/Zero based index in the repCapNames.
/// HIPAR bufferSize/Pass the number of bytes in the string you allocate for the repCapName.
/// HIPAR repCapName/String returning RepCap name
ViStatus _VI_FUNC rscmwgs_GetAttributeRepCapName(ViSession instrSession,
                                                 ViUInt32  attributeId,
                                                 ViString  repCapNameId,
                                                 ViInt32   index,
                                                 ViInt32   bufferSize,
                                                 ViChar    repCapName[])
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(RsCore_GetAttributeRepCapName(instrSession, attributeId, repCapNameId, index, bufferSize, repCapName));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: Rs_GetAttributeRepCapNameId
 * Purpose:  This function returns the repeated capability id(s) that
 *           belongs to the attribute you specify. More then one id is listed
 *           in comma separated string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                            ViUInt32  attributeID,
                                                            ViInt32   bufferSize,
                                                            ViChar    _VI_FAR repeatedCapabilityIds[])
{
	ViStatus error = VI_SUCCESS;

	viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
			3, "Buffer Size");

	checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeID, bufferSize, repeatedCapabilityIds));

Error:
	return error;
}

/*****************************************************************************
 * Function: Get Attribute Repeated Capability Id Name(s)
 * Purpose:  This function returns the repeated capability name(s) that
 *           belongs to the attribute and single repeated capability id you
 *           may specify. More then one name is listed in comma separated
 *           string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_GetAttributeRepeatedCapabilityIdNames(
							ViSession instrSession,
							ViUInt32  attributeID,
							ViString  repeatedCapabilityId,
							ViInt32   bufferSize,
							ViChar    _VI_FAR repeatedCapabilityIdNames[])
{
	ViStatus error = VI_SUCCESS;

	viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
			4, "Buffer Size");

	checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
        attributeID,
        repeatedCapabilityId,
        bufferSize,
        repeatedCapabilityIdNames));

Error:
	return error;
}

/*****************************************************************************
 * Function: rscmwgs_CheckAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to check
 *           attribute values directly.  These functions check the value you
 *           specify even if you set the rscmwgs_ATTR_RANGE_CHECK
 *           attribute to VI_FALSE.  There are typesafe versions for ViInt32,
 *           ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/

/* ViInt32 */
ViStatus _VI_FUNC rscmwgs_CheckAttributeViInt32(ViSession instrSession,
                                                ViString  channelName,
                                                ViUInt32  attributeId,
                                                ViInt32   value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_CheckAttributeViInt32(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rscmwgs_CheckAttributeViReal64(ViSession instrSession,
                                                 ViString  channelName,
                                                 ViUInt32  attributeId,
                                                 ViReal64  value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_CheckAttributeViReal64(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViString */
ViStatus _VI_FUNC rscmwgs_CheckAttributeViString(ViSession instrSession,
                                                 ViString  channelName,
                                                 ViUInt32  attributeId,
                                                 ViString  value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_CheckAttributeViString(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rscmwgs_CheckAttributeViBoolean(ViSession instrSession,
                                                  ViString  channelName,
                                                  ViUInt32  attributeId,
                                                  ViBoolean value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_CheckAttributeViBoolean(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/* ViSession */
ViStatus _VI_FUNC rscmwgs_CheckAttributeViSession(ViSession instrSession,
                                                  ViString  channelName,
                                                  ViUInt32  attributeId,
                                                  ViSession value)
{
	ViStatus error = VI_SUCCESS;

	(void)RsCore_LockSession(instrSession);

	error = RsCore_CheckAttributeViSession(instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: Reset
 * Purpose:  This function resets the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_reset(ViSession instrSession)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	if (RsCore_Simulating(instrSession) == VI_FALSE)
	{
		checkErr(rscmwgs_ClearStatus(instrSession));
		checkErr(RsCore_Write(instrSession, "*RST")); // IGNORE: Check double write
		checkErr(RsCore_QueryViStringShort(instrSession, "*OPC?", NULL));
	}

	checkErr(rscmwgs_DefaultInstrSetup(instrSession));
	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);

	return error;
}

/*****************************************************************************
 * Function: Self Test
 * Purpose:  This function executes the instrument self-test and returns the
 *           result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_self_test(ViSession instrSession,
                                    ViInt16   *testResult,
                                    ViChar    testMessage[])
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	viCheckParm(RsCore_InvalidNullPointer(instrSession, testResult), 2, "Null address for Test Result");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, testMessage), 3, "Null address for Test Message");

	checkErr(RsCore_SelfTest(instrSession, testResult, 48, testMessage));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: Revision Query
 * Purpose:  This function returns the driver and instrument revisions.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_revision_query(ViSession instrSession,
                                         ViChar    driverRev[],
                                         ViChar    instrRev[])
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	viCheckParm(RsCore_InvalidNullPointer(instrSession, driverRev), 2, "Null address for Instrument Driver Revision");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, instrRev), 3, "Null address for Instrument Revision");

	checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, 256, driverRev));
	checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, 256, instrRev));
	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function:    System Version
 * Purpose:     This function queries the number of the SCPI version, which
 *              is relevant for the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_SystemVersion(ViSession instrSession,
                                        ViInt32   length,
                                        ViChar    systemVersion[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rscmwgs_GetAttributeViString(instrSession, "", RSCMWGS_ATTR_SYSTEM_VERSION,
    		length, systemVersion),
    		2, "System Version");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Error Query
 * Purpose:  This function queries the instrument error queue and returns
 *           the result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_error_query(ViSession instrSession,
                                      ViInt32   *errCode,
                                      ViChar    errMessage[])
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	viCheckParm(RsCore_InvalidNullPointer(instrSession, errCode), 2, "Null address for Error Code");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, errMessage), 3, "Null address for Error Message");

	checkErr(RsCore_ErrorQueryAll(instrSession, errCode, 1024, errMessage));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: Error List
 * Purpose:  This function reads all system messages and returns a list of
 *           comma separated strings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ErrorList(ViSession instrSession,
                                    ViInt32   bufferSize,
                                    ViChar    errors[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 0, 32001),
    		2, "Buffer Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errors), 3, "Null address for Errors");

    checkErr(rscmwgs_GetAttributeViString( instrSession, "", RSCMWGS_ATTR_SYSTEM_ALL_ERRORS,
        bufferSize, errors));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Error Message
 * Purpose:  This function translates the error codes returned by this
 *           instrument driver into user-readable strings.
 *
 *           Note:  The caller can pass NULL for the vi parameter.  This
 *           is useful if one of the init functions fail.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_error_message(ViSession instrSession,
                                        ViStatus  errorCode,
                                        ViChar    errorMessage[])
{
	ViStatus error = VI_SUCCESS;
	static   RsCoreStringValueTable errorTable =
	         {
	         RSCMWGS_ERROR_CODES_AND_MSGS,
	{0,      NULL}
	         };

	(void)(RsCore_LockSession(instrSession));

	// all VISA and RS error codes are handled as well as codes in the table
	viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

	checkErr(RsCore_GetSpecificDriverStatusDesc(instrSession, errorCode, errorMessage, 256, errorTable));

Error:
	(void)RsCore_UnlockSession(instrSession); // IGNORE: ERROR!!! Missing Lock
	return error;
}

/*****************************************************************************
 * Function: Reliability Indicator
 * Purpose:  This function converts a reliability code returned by an
 *           instrument driver function into a user-readable string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ReliabilityIndicator(ViSession instrSession,
                                               ViInt32   reliabilityCode,
                                               ViChar    reliabilityMessage[])
{
    ViStatus  error = VI_SUCCESS;
    ViInt16   cnt = 0;
    ViBoolean found = VI_FALSE;

    static      RsCoreStringValueTable reliabilityTable =
    {
        {0,       "OK"},
        {1,       "Measurement Timeout"},
        {2,       "Capture Buffer Overflow"},
        {3,       "Overdriven"},
        {4,       "Underdriven"},
        {6,       "Trigger Timeout"},
        {7,       "Acquisition Error"},
        {8,       "Sync Error"},
        {9,       "Uncal"},
        {15,       "Reference Frequency Error"},
        {16,       "RF Not Available"},
        {17,       "RF Level not Settled"},
        {18,       "RF Frequency not Settled"},
        {19,       "Call not Established"},
        {20,       "Call Type not Usable"},
        {21,       "Call Lost"},
        {23,       "Missing Option"},
        {24,       "Invalid RF Setting"},
        {26,       "Resource Conflict"},
        {27,       "No Sensor Connected"},
        {28,       "Unexpected Parameter Change"},
        {30,       "File not Found"},
        {31,       "No DTM reply"},
        {32,       "ACL Disconnected"},
        {40,       "ARB File CRC Error"},
        {42,       "ARB Header Tag Invalid"},
        {43,       "ARB Segment Overflow"},
        {44,       "ARB File not Found"},
        {45,       "ARB Memory Overflow"},
        {46,       "ARB Sample Rate out of Range"},
        {47,       "ARB Cycles out of Range"},
        {50,       "Startup Error"},
        {51,       "No Reply"},
        {52,       "Connection Error"},
        {53,       "Configuration Error"},
        {54,       "Filesystem Error"},
        {60,       "Invalid RF-Connector Setting"},
        {93,       "OCXO Oven Temperature too low"},
        {101,       "Firmware Error"},
        {102,       "Unidentified Error"},
        {103,       "Parameter Error"},
        {104,       "Not Functional"},
        {0, NULL}
    };

	(void)RsCore_LockSession(instrSession);

	for (cnt = 0; reliabilityTable[cnt].string; cnt++)
	{
		if (reliabilityTable[cnt].value == reliabilityCode)
		{
			sprintf(reliabilityMessage, "%s", reliabilityTable[cnt].string);
			if (reliabilityCode)
				error = RSCMWGS_ERROR_RELIABILITY_INDICATOR;
			found = VI_TRUE;
		}
	}

	if (!found)
	{
		sprintf(reliabilityMessage, "Unrecognized reliability indicator! Report problem to R&S support!");
		error = RS_WARN_UNKNOWN_INSTRUMENT_STATUS;
	}

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: Preset
 * Purpose:  This function initiates an instrument reset.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_Preset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwgs_SetAttributeViString(instrSession, "", RSCMWGS_ATTR_SYSTEM_PRESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR opcTimeout/This control sets the timeout value.
ViStatus _VI_FUNC rscmwgs_SetOPCTimeout(ViSession instrSession,
                                        ViUInt32  opcTimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_SetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32) opcTimeout));

Error:
    return error;}

/// HIFN  This function returns the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control returns the timeout value.
ViStatus _VI_FUNC rscmwgs_GetOPCTimeout(ViSession instrSession,
                                        ViUInt32  *timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32*) timeout));

Error:
    return error;
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIFN Note that the actual timeout used may be higher than the one
/// HIFN requested.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR VISATimeout/Specifies the minimum timeout value to use (in milliseconds)
/// HIPAR VISATimeout/when accessing the device associated with the given session.
/// HIPAR VISATimeout/Note that the actual timeout used may be higher than the one
/// HIPAR VISATimeout/requested.
ViStatus _VI_FUNC rscmwgs_SetVISATimeout(ViSession instrSession,
                                         ViUInt32  VISATimeout)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(RsCore_SetVisaTimeout(instrSession, VISATimeout));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN This function queries the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR VISATimeout/Queries the minimum timeout value to use (in milliseconds)
/// HIPAR VISATimeout/when accessing the device associated with the given session.
ViStatus _VI_FUNC rscmwgs_GetVISATimeout(ViSession instrSession,
                                         ViUInt32  *VISATimeout)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(RsCore_GetVisaTimeout(instrSession, VISATimeout));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rscmwgs_ClearStatus(ViSession instrSession)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(RsCore_ClearStatus(instrSession));
	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of IDQueryResponse buffer
/// HIPAR idQueryResponse/Returns the ID Query response string. The array should consist of at
/// HIPAR idQueryResponse/least 256 elements.
ViStatus _VI_FUNC rscmwgs_IDQueryResponse(ViSession instrSession,
                                          ViUInt32  bufferSize,
                                          ViChar    IDQueryResponse[])
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(rscmwgs_QueryViString(instrSession, "*IDN?", bufferSize, IDQueryResponse));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN  Stops further command processing until all commands sent before *WAI
/// HIFN  have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rscmwgs_ProcessAllPreviousCommands(ViSession instrSession)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(rscmwgs_WriteInstrData(instrSession, "*WAI"));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR opc/Queries the OPC.
ViStatus _VI_FUNC rscmwgs_QueryOPC(ViSession instrSession,
                                   ViInt32*  opc)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(rscmwgs_QueryViInt32(instrSession, "*OPC?", opc));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rscmwgs_ConfigureErrorChecking(ViSession instrSession,
                                                 ViBoolean optionChecking,
                                                 ViBoolean rangeChecking,
                                                 ViBoolean statusChecking)
{
	ViStatus         error = VI_SUCCESS;
	RsCoreSessionPtr rsSession = NULL;

	checkErr(RsCore_GetRsSession(instrSession, &rsSession));
	rsSession->optionChecking = optionChecking;
	checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));
	checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
	return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rscmwgs_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rscmwgs_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                      ViBoolean autoSystErrQuery)
{
	ViStatus         error = VI_SUCCESS;
	RsCoreSessionPtr rsSession = NULL;

	checkErr(RsCore_GetRsSession(instrSession, &rsSession));
	rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
	return error;
}

/// HIFN Session-related mutex switch.
/// HIFN If TRUE (default after init is FALSE), the driver sets a mutual-exclusion mechanism for every driver's hi-level function and attribute access.
/// HIFN Set this value to TRUE if you plan to use one session in more than one thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR multiThreadLocking/Session-related mutex switch
ViStatus _VI_FUNC rscmwgs_ConfigureMultiThreadLocking(ViSession instrSession,
                                                      ViBoolean multiThreadLocking)
{
	ViStatus         error = VI_SUCCESS;
	RsCoreSessionPtr rsSession = NULL;

	checkErr(RsCore_GetRsSession(instrSession, &rsSession));
	rsSession->multiThreadLocking = multiThreadLocking;

Error:
	return error;
}

/*****************************************************************************
 * Function: Get Error and Clear Error Functions
 * Purpose:  These functions enable the instrument driver user to
 *           get or clear the error information the driver associates with the
 *           RS session.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_GetError(ViSession instrSession,
                                   ViStatus  *errorCode,
                                   ViInt32   bufferSize,
                                   ViChar    description[])
{
	ViStatus error = VI_SUCCESS;

	// Lock Session - do not jump to the end, even with invalid instrSession the function continues further
	(void)(RsCore_LockSession(instrSession));

	// Test for nulls and acquire error data
	viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

	checkErr(RsCore_GetErrorCompleteDescription(instrSession, &rscmwgs_error_message, errorCode, bufferSize, description)
    );

Error:
	// Unlock Session
	// IGNORE: ERROR!!! Missing Lock
	return error;
}

ViStatus _VI_FUNC rscmwgs_ClearError(ViSession instrSession)
{
	return RsCore_ClearErrorInfo(instrSession);
}

/// HIFN This function is used to read data from the instrument and write
/// HIFN it to a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument
/// HIPAR source/to control computer.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from instrument to control computer applies.
ViStatus _VI_FUNC rscmwgs_ReadToFileFromInstrument(ViSession instrSession,
                                                   ViString  source,
                                                   ViString  destination)
{
	ViStatus error = VI_SUCCESS;
	ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

	checkErr(RsCore_LockSession(instrSession));

	snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA? '%s'", source);
	checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN This function is used to read data from the host computer and
/// HIFN write it to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control
/// HIPAR source/computer to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from control computer to instrument applies.
ViStatus _VI_FUNC rscmwgs_WriteFromFileToInstrument(ViSession instrSession,
                                                    ViString  source,
                                                    ViString  destination)
{
	ViStatus error = VI_SUCCESS;
	ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

	checkErr(RsCore_LockSession(instrSession));

	snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", destination);
	checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));
	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: WriteInstrData and ReadInstrData Functions
 * Purpose:  These functions enable the instrument driver user to
 *           write and read commands directly to and from the instrument.
 *
 *           Note:  These functions bypass the RS attribute state caching.
 *                  WriteInstrData invalidates the cached values for all
 *                  attributes.
 *****************************************************************************/

ViStatus _VI_FUNC rscmwgs_WriteInstrData(ViSession instrSession,
                                         ViString  writeBuffer)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	error = RsCore_Write(instrSession, writeBuffer);

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

ViStatus _VI_FUNC rscmwgs_ReadInstrData(ViSession instrSession,
                                        ViInt32   numBytes,
                                        ViChar    rdBuf[],
                                        ViUInt32  *bytesRead)
{
	ViStatus error = VI_SUCCESS;
	ViChar   *responseString = NULL;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(RsCore_ReadViStringUnknownLength(instrSession, &responseString));
	checkErr(RsCore_CopyToUserBufferAsciiData(rdBuf, numBytes, responseString));
	*bytesRead = (ViUInt32)strlen(responseString);

Error:
	if (responseString)
		free(responseString);

	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/// HIFN Sends a command to the instrument synchronised with OPC-polling.
/// HIFN Use this function to wait for an instrument operation that can
/// HIFN take a long time to complete, e.g. self-alignment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rscmwgs_WriteCommandWithOPCSync(ViSession instrSession,
                                                  ViString  writeBuffer,
                                                  ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_WriteWithOpc(instrSession, writeBuffer, timeout));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Sends a query to the instrument synchronised with OPC-polling.
/// HIFN Use this function to wait for a response that can take a long
/// HIFN time to complete e.g. self-alignment, calibration or self-test.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
/// HIPAR timeout/This control sets the timeout value.
/// HIPAR bufferSize/Pass the maximum number of bytes to read from the instruments.
/// HIPAR readBuffer/After this function executes, this parameter contains the data
/// HIPAR readBuffer/that was read from the instrument.
/// HIPAR numBytesRead/Returns the number of bytes actually read from the instrument
/// HIPAR numBytesRead/and stored in the Read Buffer.
ViStatus _VI_FUNC rscmwgs_QueryWithOPCSync(ViSession instrSession,
                                           ViString  writeBuffer,
                                           ViUInt32  timeout,
                                           ViInt32   bufferSize,
                                           ViChar    readBuffer[],
                                           ViUInt32  *numBytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, strlen(writeBuffer), 1, 32001),
    	2, "Write Buffer (string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, readBuffer),
    	5, "Read Buffer");

    checkErr(RsCore_QueryViStringUnknownLengthToUserBufferWithOpc(instrSession, writeBuffer, timeout, bufferSize, readBuffer, (ViInt32*)numBytesRead));

    checkErr(rscmwgs_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViBoolean
 * Purpose:  This function queries the ViBoolean value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryViBoolean(ViSession instrSession,
                                         ViString  cmd,
                                         ViBoolean *value)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(cmd), 1, 2147483647), 2,
        "Command (null string length)");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

	checkErr(RsCore_QueryViBoolean(instrSession, cmd, value));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: Query ViInt32
 * Purpose:  This function queries the ViInt32 value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryViInt32(ViSession instrSession,
                                       ViString  cmd,
                                       ViInt32   *value)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(cmd), 1, 2147483647), 2,
        "Command (null string length)");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

	checkErr(RsCore_QueryViInt32(instrSession, cmd, value));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: Query ViReal64
 * Purpose:  This function queries the ViReal64 value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryViReal64(ViSession instrSession,
                                        ViString  cmd,
                                        ViReal64  *value)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(cmd), 1, 2147483647), 2,
        "Command (null string length)");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

	checkErr(RsCore_QueryViReal64(instrSession, cmd, value));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}


/*****************************************************************************
 * Function: Query ViString
 * Purpose:  This function queries the ViString value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryViString(ViSession instrSession,
                                        ViString  cmd,
                                        ViInt32   bufferSize,
                                        ViChar    _VI_FAR value[])
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(cmd), 1, 2147483647), 2,
        "Command (null string length)");
	viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

	checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, cmd, bufferSize, value, NULL));

	checkErr(rscmwgs_CheckStatus(instrSession));

Error:
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 * Function: rscmwgs_close
 * Purpose:  This function closes the instrument.
 *
 *           Note:  This function must unlock the session before calling
 *           Rs_Dispose.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_close(ViSession instrSession)
{
	ViStatus error = VI_SUCCESS;

	checkErr(RsCore_LockSession(instrSession));

	checkErr(RsCore_ViClose(instrSession));

Error:
	(void)RsCore_Dispose(instrSession);
	(void)RsCore_UnlockSession(instrSession);
	return error;
}

/*****************************************************************************
 *------------------------ Obsolete funcions --------------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function: Read BLER Results Single Carrier
 * Purpose:  Starts a new single shot measurement and returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ReadBLERResultsSingleCarrier(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   carrier,
                                                       ViInt32   *reliability,
                                                       ViReal64  *bler,
                                                       ViReal64  *blerAll,
                                                       ViInt32   *rlcBlocks,
                                                       ViInt32   *rlcBlocksAll,
                                                       ViReal64  *rlcDataRate,
                                                       ViReal64  *rlcDataRateAll)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[6];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, bler), 5, "BLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, blerAll), 6, "BLER All");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcBlocks), 7, "RLC Blocks");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcBlocksAll), 8, "RLC Blocks All");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcDataRate), 9, "RLC Data Rate");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcDataRateAll), 10, "RLC Data Rate All");

    sprintf (buffer, "READ:GSM:SIGN%ld:BLER:CARR%ld?\n", instance, carrier);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, 6, reliability, dbl_res, &count));

    *bler           = dbl_res[0];
    *blerAll        = dbl_res[1];
    *rlcBlocks      = (dbl_res[2] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[2];
    *rlcBlocksAll   = (dbl_res[3] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[3];
    *rlcDataRate    = dbl_res[4];
    *rlcDataRateAll = dbl_res[5];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Fetch BLER Results Single Carrier
 * Purpose:  Returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_FetchBLERResultsSingleCarrier(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   carrier,
                                                        ViInt32   *reliability,
                                                        ViReal64  *bler,
                                                        ViReal64  *blerAll,
                                                        ViInt32   *rlcBlocks,
                                                        ViInt32   *rlcBlocksAll,
                                                        ViReal64  *rlcDataRate,
                                                        ViReal64  *rlcDataRateAll)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[6];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, carrier, 1, 2),
    		3, "Carrier");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 4, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, bler), 5, "BLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, blerAll), 6, "BLER All");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcBlocks), 7, "RLC Blocks");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcBlocksAll), 8, "RLC Blocks All");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcDataRate), 9, "RLC Data Rate");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcDataRateAll), 10, "RLC Data Rate All");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BLER:CARR%ld?\n", instance, carrier);

    checkErr(rscmwgs_GetMeas(instrSession, buffer, 6, reliability, dbl_res, &count));

    *bler           = dbl_res[0];
    *blerAll        = dbl_res[1];
    *rlcBlocks      = (dbl_res[2] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[2];
    *rlcBlocksAll   = (dbl_res[3] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[3];
    *rlcDataRate    = dbl_res[4];
    *rlcDataRateAll = dbl_res[5];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Read BLER Results All Carriers
 * Purpose:  Starts a new single shot measurement and returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_ReadBLERResultsAllCarriers(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   *reliability,
                                                     ViReal64  *bler,
                                                     ViInt32   *rlcBlocks,
                                                     ViReal64  *rlcDataRate,
                                                     ViReal64  *throughput,
                                                     ViReal64  *throughputSlot)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[5];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 3, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, bler), 4, "BLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcBlocks), 5, "RLC Blocks");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcDataRate), 6, "RLC Data Rate");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, throughput), 7, "Throughput");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, throughputSlot), 8, "Throughput Slot");

    sprintf (buffer, "READ:GSM:SIGN%ld:BLER:OALL?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, 5, reliability, dbl_res, &count));

    *bler           = dbl_res[0];
    *rlcBlocks      = (dbl_res[1] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[1];
    *rlcDataRate    = dbl_res[2];
    *throughput     = dbl_res[3];
    *throughputSlot = dbl_res[4];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Fetch BLER Results All Carriers
 * Purpose:  Returns the results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_FetchBLERResultsAllCarriers(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   *reliability,
                                                      ViReal64  *bler,
                                                      ViInt32   *rlcBlocks,
                                                      ViReal64  *rlcDataRate,
                                                      ViReal64  *throughput,
                                                      ViReal64  *throughputSlot)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[1024];
    ViReal64 dbl_res[5];
    ViInt32  count = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
    		2, "Instance");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, reliability), 3, "Reliability");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, bler), 4, "BLER");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcBlocks), 5, "RLC Blocks");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, rlcDataRate), 6, "RLC Data Rate");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, throughput), 7, "Throughput");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, throughputSlot), 8, "Throughput Slot");

    sprintf (buffer, "FETC:GSM:SIGN%ld:BLER:OALL?\n", instance);
    checkErr(rscmwgs_GetMeas(instrSession, buffer, 5, reliability, dbl_res, &count));

    *bler           = dbl_res[0];
    *rlcBlocks      = (dbl_res[1] == RSCMW_NAN) ? RSCMW_NAN_VI_INT32 : (ViInt32) dbl_res[1];
    *rlcDataRate    = dbl_res[2];
    *throughput     = dbl_res[3];
    *throughputSlot = dbl_res[4];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Generator State
 * Purpose:  Returns detailed information about the "GSM Signaling"
 *           generator state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwgs_QueryGeneratorState(ViSession  instrSession,
                                              ViInt32    instance,
                                              ViBoolean* mainState,
                                              ViInt32*   syncState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[RS_MAX_SHORT_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR:GSM:SIGN%ld:CELL:STAT:ALL?\n", instance);
    checkErr(RsCore_QueryViStringShort(instrSession, cmd, buffer));
    checkErr(rscmwgs_CheckStatus(instrSession));

    p2buf = strtok (buffer, ",");
    *mainState = (ViBoolean)(RsCore_FindStringIndex(mainStateArr, p2buf) != 0);
    p2buf = strtok (NULL, ",\r\n");
    *syncState = RsCore_FindStringIndex(syncStateArr, p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}
